# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/privacy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/app/distribution/setting/privacy.proto\x12)bilibili.app.distribution.setting.privacy\x1a/bilibili/app/distribution/v1/distribution.proto\"_\n\x18MidPrivacySettingsConfig\x12\x43\n\x12recommend_to_known\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"\x9c\x01\n\x15PrivacySettingsConfig\x12\x43\n\x12\x61\x64_recommand_store\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12>\n\rsensor_access\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.privacy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MIDPRIVACYSETTINGSCONFIG']._serialized_start=143
  _globals['_MIDPRIVACYSETTINGSCONFIG']._serialized_end=238
  _globals['_PRIVACYSETTINGSCONFIG']._serialized_start=241
  _globals['_PRIVACYSETTINGSCONFIG']._serialized_end=397
# @@protoc_insertion_point(module_scope)
