"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.avatar_pb2
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AddButtonBgStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AddButtonBgStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AddButtonBgStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    fill: _AddButtonBgStyle.ValueType  # 0
    """默认填充"""
    stroke: _AddButtonBgStyle.ValueType  # 1
    """描边"""
    gray: _AddButtonBgStyle.ValueType  # 2
    """置灰"""

class AddButtonBgStyle(_AddButtonBgStyle, metaclass=_AddButtonBgStyleEnumTypeWrapper):
    """"""

fill: AddButtonBgStyle.ValueType  # 0
"""默认填充"""
stroke: AddButtonBgStyle.ValueType  # 1
"""描边"""
gray: AddButtonBgStyle.ValueType  # 2
"""置灰"""
global___AddButtonBgStyle = AddButtonBgStyle

class _AddButtonType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AddButtonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AddButtonType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    bt_none: _AddButtonType.ValueType  # 0
    """占位"""
    bt_jump: _AddButtonType.ValueType  # 1
    """跳转"""
    bt_button: _AddButtonType.ValueType  # 2
    """按钮"""

class AddButtonType(_AddButtonType, metaclass=_AddButtonTypeEnumTypeWrapper):
    """按钮类型"""

bt_none: AddButtonType.ValueType  # 0
"""占位"""
bt_jump: AddButtonType.ValueType  # 1
"""跳转"""
bt_button: AddButtonType.ValueType  # 2
"""按钮"""
global___AddButtonType = AddButtonType

class _AdditionalButtonClickType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalButtonClickTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalButtonClickType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    click_none: _AdditionalButtonClickType.ValueType  # 0
    """通用按钮"""
    click_up: _AdditionalButtonClickType.ValueType  # 1
    """预约卡按钮"""

class AdditionalButtonClickType(_AdditionalButtonClickType, metaclass=_AdditionalButtonClickTypeEnumTypeWrapper):
    """附加卡按钮点击类型"""

click_none: AdditionalButtonClickType.ValueType  # 0
"""通用按钮"""
click_up: AdditionalButtonClickType.ValueType  # 1
"""预约卡按钮"""
global___AdditionalButtonClickType = AdditionalButtonClickType

class _AdditionalButtonStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalButtonStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalButtonStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    none: _AdditionalButtonStatus.ValueType  # 0
    """"""
    uncheck: _AdditionalButtonStatus.ValueType  # 1
    """"""
    check: _AdditionalButtonStatus.ValueType  # 2
    """"""

class AdditionalButtonStatus(_AdditionalButtonStatus, metaclass=_AdditionalButtonStatusEnumTypeWrapper):
    """附加卡按钮状态"""

none: AdditionalButtonStatus.ValueType  # 0
""""""
uncheck: AdditionalButtonStatus.ValueType  # 1
""""""
check: AdditionalButtonStatus.ValueType  # 2
""""""
global___AdditionalButtonStatus = AdditionalButtonStatus

class _AdditionalShareShowType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalShareShowTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalShareShowType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    st_none: _AdditionalShareShowType.ValueType  # 0
    """"""
    st_show: _AdditionalShareShowType.ValueType  # 1
    """"""

class AdditionalShareShowType(_AdditionalShareShowType, metaclass=_AdditionalShareShowTypeEnumTypeWrapper):
    """"""

st_none: AdditionalShareShowType.ValueType  # 0
""""""
st_show: AdditionalShareShowType.ValueType  # 1
""""""
global___AdditionalShareShowType = AdditionalShareShowType

class _AdditionalType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionalTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionalType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    additional_none: _AdditionalType.ValueType  # 0
    """占位"""
    additional_type_pgc: _AdditionalType.ValueType  # 1
    """附加卡-追番"""
    additional_type_goods: _AdditionalType.ValueType  # 2
    """附加卡-商品"""
    additional_type_vote: _AdditionalType.ValueType  # 3
    """附加卡投票"""
    additional_type_common: _AdditionalType.ValueType  # 4
    """附加通用卡"""
    additional_type_esport: _AdditionalType.ValueType  # 5
    """附加电竞卡"""
    additional_type_up_rcmd: _AdditionalType.ValueType  # 6
    """附加UP主推荐卡"""
    additional_type_ugc: _AdditionalType.ValueType  # 7
    """附加卡-ugc"""
    additional_type_up_reservation: _AdditionalType.ValueType  # 8
    """UP主预约卡"""

class AdditionalType(_AdditionalType, metaclass=_AdditionalTypeEnumTypeWrapper):
    """枚举-动态附加卡"""

additional_none: AdditionalType.ValueType  # 0
"""占位"""
additional_type_pgc: AdditionalType.ValueType  # 1
"""附加卡-追番"""
additional_type_goods: AdditionalType.ValueType  # 2
"""附加卡-商品"""
additional_type_vote: AdditionalType.ValueType  # 3
"""附加卡投票"""
additional_type_common: AdditionalType.ValueType  # 4
"""附加通用卡"""
additional_type_esport: AdditionalType.ValueType  # 5
"""附加电竞卡"""
additional_type_up_rcmd: AdditionalType.ValueType  # 6
"""附加UP主推荐卡"""
additional_type_ugc: AdditionalType.ValueType  # 7
"""附加卡-ugc"""
additional_type_up_reservation: AdditionalType.ValueType  # 8
"""UP主预约卡"""
global___AdditionalType = AdditionalType

class _AdditionVoteState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionVoteStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionVoteState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    addition_vote_state_none: _AdditionVoteState.ValueType  # 0
    """"""
    addition_vote_state_open: _AdditionVoteState.ValueType  # 1
    """"""
    addition_vote_state_close: _AdditionVoteState.ValueType  # 2
    """"""

class AdditionVoteState(_AdditionVoteState, metaclass=_AdditionVoteStateEnumTypeWrapper):
    """投票状态"""

addition_vote_state_none: AdditionVoteState.ValueType  # 0
""""""
addition_vote_state_open: AdditionVoteState.ValueType  # 1
""""""
addition_vote_state_close: AdditionVoteState.ValueType  # 2
""""""
global___AdditionVoteState = AdditionVoteState

class _AdditionVoteType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AdditionVoteTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AdditionVoteType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    addition_vote_type_none: _AdditionVoteType.ValueType  # 0
    """"""
    addition_vote_type_word: _AdditionVoteType.ValueType  # 1
    """"""
    addition_vote_type_pic: _AdditionVoteType.ValueType  # 2
    """"""
    addition_vote_type_default: _AdditionVoteType.ValueType  # 3
    """"""

class AdditionVoteType(_AdditionVoteType, metaclass=_AdditionVoteTypeEnumTypeWrapper):
    """投票类型"""

addition_vote_type_none: AdditionVoteType.ValueType  # 0
""""""
addition_vote_type_word: AdditionVoteType.ValueType  # 1
""""""
addition_vote_type_pic: AdditionVoteType.ValueType  # 2
""""""
addition_vote_type_default: AdditionVoteType.ValueType  # 3
""""""
global___AdditionVoteType = AdditionVoteType

class _CampusEntryType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusEntryTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusEntryType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NONE: _CampusEntryType.ValueType  # 0
    """"""
    ENTRY_DYNAMIC: _CampusEntryType.ValueType  # 1
    """"""
    ENTRY_HOME: _CampusEntryType.ValueType  # 2
    """"""

class CampusEntryType(_CampusEntryType, metaclass=_CampusEntryTypeEnumTypeWrapper):
    """"""

NONE: CampusEntryType.ValueType  # 0
""""""
ENTRY_DYNAMIC: CampusEntryType.ValueType  # 1
""""""
ENTRY_HOME: CampusEntryType.ValueType  # 2
""""""
global___CampusEntryType = CampusEntryType

class _CampusRcmdReqFrom:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusRcmdReqFromEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusRcmdReqFrom.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CAMPUS_RCMD_FROM_UNKNOWN: _CampusRcmdReqFrom.ValueType  # 0
    CAMPUS_RCMD_FROM_HOME_UN_OPEN: _CampusRcmdReqFrom.ValueType  # 1
    CAMPUS_RCMD_FROM_VISIT_OTHER: _CampusRcmdReqFrom.ValueType  # 2
    CAMPUS_RCMD_FROM_HOME_MOMENT: _CampusRcmdReqFrom.ValueType  # 3
    CAMPUS_RCMD_FROM_DYN_MOMENT: _CampusRcmdReqFrom.ValueType  # 4
    CAMPUS_RCMD_FROM_PAGE_SUBORDINATE_MOMENT: _CampusRcmdReqFrom.ValueType  # 5

class CampusRcmdReqFrom(_CampusRcmdReqFrom, metaclass=_CampusRcmdReqFromEnumTypeWrapper):
    """"""

CAMPUS_RCMD_FROM_UNKNOWN: CampusRcmdReqFrom.ValueType  # 0
CAMPUS_RCMD_FROM_HOME_UN_OPEN: CampusRcmdReqFrom.ValueType  # 1
CAMPUS_RCMD_FROM_VISIT_OTHER: CampusRcmdReqFrom.ValueType  # 2
CAMPUS_RCMD_FROM_HOME_MOMENT: CampusRcmdReqFrom.ValueType  # 3
CAMPUS_RCMD_FROM_DYN_MOMENT: CampusRcmdReqFrom.ValueType  # 4
CAMPUS_RCMD_FROM_PAGE_SUBORDINATE_MOMENT: CampusRcmdReqFrom.ValueType  # 5
global___CampusRcmdReqFrom = CampusRcmdReqFrom

class _CampusHomePageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusHomePageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusHomePageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PAGE_MAJOR: _CampusHomePageType.ValueType  # 0
    """"""
    PAGE_SUBORDINATE: _CampusHomePageType.ValueType  # 1
    """"""
    PAGE_MAJOR_DETAIL: _CampusHomePageType.ValueType  # 2
    """"""

class CampusHomePageType(_CampusHomePageType, metaclass=_CampusHomePageTypeEnumTypeWrapper):
    """"""

PAGE_MAJOR: CampusHomePageType.ValueType  # 0
""""""
PAGE_SUBORDINATE: CampusHomePageType.ValueType  # 1
""""""
PAGE_MAJOR_DETAIL: CampusHomePageType.ValueType  # 2
""""""
global___CampusHomePageType = CampusHomePageType

class _CampusMngAuditStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusMngAuditStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusMngAuditStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    campus_mng_audit_none: _CampusMngAuditStatus.ValueType  # 0
    """"""
    campus_mng_audit_in_process: _CampusMngAuditStatus.ValueType  # 1
    """"""
    campus_mng_audit_failed: _CampusMngAuditStatus.ValueType  # 2
    """"""

class CampusMngAuditStatus(_CampusMngAuditStatus, metaclass=_CampusMngAuditStatusEnumTypeWrapper):
    """"""

campus_mng_audit_none: CampusMngAuditStatus.ValueType  # 0
""""""
campus_mng_audit_in_process: CampusMngAuditStatus.ValueType  # 1
""""""
campus_mng_audit_failed: CampusMngAuditStatus.ValueType  # 2
""""""
global___CampusMngAuditStatus = CampusMngAuditStatus

class _CampusMngItemType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusMngItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusMngItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    campus_mng_none: _CampusMngItemType.ValueType  # 0
    """"""
    campus_mng_basic_info: _CampusMngItemType.ValueType  # 1
    """"""
    campus_mng_badge: _CampusMngItemType.ValueType  # 2
    """"""
    campus_mng_slogan: _CampusMngItemType.ValueType  # 3
    """"""
    campus_mng_quiz: _CampusMngItemType.ValueType  # 4
    """"""

class CampusMngItemType(_CampusMngItemType, metaclass=_CampusMngItemTypeEnumTypeWrapper):
    """"""

campus_mng_none: CampusMngItemType.ValueType  # 0
""""""
campus_mng_basic_info: CampusMngItemType.ValueType  # 1
""""""
campus_mng_badge: CampusMngItemType.ValueType  # 2
""""""
campus_mng_slogan: CampusMngItemType.ValueType  # 3
""""""
campus_mng_quiz: CampusMngItemType.ValueType  # 4
""""""
global___CampusMngItemType = CampusMngItemType

class _CampusMngQuizAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusMngQuizActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusMngQuizAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    campus_mng_quiz_act_list: _CampusMngQuizAction.ValueType  # 0
    """"""
    campus_mng_quiz_act_add: _CampusMngQuizAction.ValueType  # 1
    """"""
    campus_mng_quiz_act_del: _CampusMngQuizAction.ValueType  # 2
    """"""

class CampusMngQuizAction(_CampusMngQuizAction, metaclass=_CampusMngQuizActionEnumTypeWrapper):
    """"""

campus_mng_quiz_act_list: CampusMngQuizAction.ValueType  # 0
""""""
campus_mng_quiz_act_add: CampusMngQuizAction.ValueType  # 1
""""""
campus_mng_quiz_act_del: CampusMngQuizAction.ValueType  # 2
""""""
global___CampusMngQuizAction = CampusMngQuizAction

class _CampusOnlineStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusOnlineStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusOnlineStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    campus_online_offline: _CampusOnlineStatus.ValueType  # 0
    """"""
    campus_online_online: _CampusOnlineStatus.ValueType  # 1
    """"""

class CampusOnlineStatus(_CampusOnlineStatus, metaclass=_CampusOnlineStatusEnumTypeWrapper):
    """"""

campus_online_offline: CampusOnlineStatus.ValueType  # 0
""""""
campus_online_online: CampusOnlineStatus.ValueType  # 1
""""""
global___CampusOnlineStatus = CampusOnlineStatus

class _CampusReqFromType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusReqFromTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusReqFromType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DYNAMIC: _CampusReqFromType.ValueType  # 0
    """"""
    HOME: _CampusReqFromType.ValueType  # 1
    """"""

class CampusReqFromType(_CampusReqFromType, metaclass=_CampusReqFromTypeEnumTypeWrapper):
    """"""

DYNAMIC: CampusReqFromType.ValueType  # 0
""""""
HOME: CampusReqFromType.ValueType  # 1
""""""
global___CampusReqFromType = CampusReqFromType

class _CampusTabType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CampusTabTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CampusTabType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    campus_none: _CampusTabType.ValueType  # 0
    """"""
    campus_school: _CampusTabType.ValueType  # 1
    """"""
    campus_dynamic: _CampusTabType.ValueType  # 2
    """"""
    campus_account: _CampusTabType.ValueType  # 3
    """"""
    campus_billboard: _CampusTabType.ValueType  # 4
    """"""
    campus_topic: _CampusTabType.ValueType  # 5
    """"""
    campues_other: _CampusTabType.ValueType  # 6
    """"""

class CampusTabType(_CampusTabType, metaclass=_CampusTabTypeEnumTypeWrapper):
    """"""

campus_none: CampusTabType.ValueType  # 0
""""""
campus_school: CampusTabType.ValueType  # 1
""""""
campus_dynamic: CampusTabType.ValueType  # 2
""""""
campus_account: CampusTabType.ValueType  # 3
""""""
campus_billboard: CampusTabType.ValueType  # 4
""""""
campus_topic: CampusTabType.ValueType  # 5
""""""
campues_other: CampusTabType.ValueType  # 6
""""""
global___CampusTabType = CampusTabType

class _CoverIcon:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CoverIconEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CoverIcon.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    cover_icon_none: _CoverIcon.ValueType  # 0
    """占位 啥都不展示"""
    cover_icon_play: _CoverIcon.ValueType  # 1
    """播放icon"""
    cover_icon_danmaku: _CoverIcon.ValueType  # 2
    """"""
    cover_icon_up: _CoverIcon.ValueType  # 3
    """"""
    cover_icon_vt: _CoverIcon.ValueType  # 4
    """? 竖屏模式 icon"""

class CoverIcon(_CoverIcon, metaclass=_CoverIconEnumTypeWrapper):
    """"""

cover_icon_none: CoverIcon.ValueType  # 0
"""占位 啥都不展示"""
cover_icon_play: CoverIcon.ValueType  # 1
"""播放icon"""
cover_icon_danmaku: CoverIcon.ValueType  # 2
""""""
cover_icon_up: CoverIcon.ValueType  # 3
""""""
cover_icon_vt: CoverIcon.ValueType  # 4
"""? 竖屏模式 icon"""
global___CoverIcon = CoverIcon

class _DescType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DescTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DescType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    desc_type_none: _DescType.ValueType  # 0
    """占位"""
    desc_type_text: _DescType.ValueType  # 1
    """文本"""
    desc_type_aite: _DescType.ValueType  # 2
    """@"""
    desc_type_lottery: _DescType.ValueType  # 3
    """抽奖"""
    desc_type_vote: _DescType.ValueType  # 4
    """投票"""
    desc_type_topic: _DescType.ValueType  # 5
    """话题"""
    desc_type_goods: _DescType.ValueType  # 6
    """商品"""
    desc_type_bv: _DescType.ValueType  # 7
    """bv"""
    desc_type_av: _DescType.ValueType  # 8
    """av"""
    desc_type_emoji: _DescType.ValueType  # 9
    """表情"""
    desc_type_user: _DescType.ValueType  # 10
    """外露用户"""
    desc_type_cv: _DescType.ValueType  # 11
    """专栏"""
    desc_type_vc: _DescType.ValueType  # 12
    """小视频"""
    desc_type_web: _DescType.ValueType  # 13
    """网址"""
    desc_type_taobao: _DescType.ValueType  # 14
    """淘宝"""
    desc_type_mail: _DescType.ValueType  # 15
    """邮箱"""
    desc_type_ogv_season: _DescType.ValueType  # 16
    """番剧season"""
    desc_type_ogv_ep: _DescType.ValueType  # 17
    """番剧ep"""
    desc_type_search_word: _DescType.ValueType  # 18
    """"""

class DescType(_DescType, metaclass=_DescTypeEnumTypeWrapper):
    """文本类型"""

desc_type_none: DescType.ValueType  # 0
"""占位"""
desc_type_text: DescType.ValueType  # 1
"""文本"""
desc_type_aite: DescType.ValueType  # 2
"""@"""
desc_type_lottery: DescType.ValueType  # 3
"""抽奖"""
desc_type_vote: DescType.ValueType  # 4
"""投票"""
desc_type_topic: DescType.ValueType  # 5
"""话题"""
desc_type_goods: DescType.ValueType  # 6
"""商品"""
desc_type_bv: DescType.ValueType  # 7
"""bv"""
desc_type_av: DescType.ValueType  # 8
"""av"""
desc_type_emoji: DescType.ValueType  # 9
"""表情"""
desc_type_user: DescType.ValueType  # 10
"""外露用户"""
desc_type_cv: DescType.ValueType  # 11
"""专栏"""
desc_type_vc: DescType.ValueType  # 12
"""小视频"""
desc_type_web: DescType.ValueType  # 13
"""网址"""
desc_type_taobao: DescType.ValueType  # 14
"""淘宝"""
desc_type_mail: DescType.ValueType  # 15
"""邮箱"""
desc_type_ogv_season: DescType.ValueType  # 16
"""番剧season"""
desc_type_ogv_ep: DescType.ValueType  # 17
"""番剧ep"""
desc_type_search_word: DescType.ValueType  # 18
""""""
global___DescType = DescType

class _DisableState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DisableStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DisableState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    highlight: _DisableState.ValueType  # 0
    """高亮"""
    gary: _DisableState.ValueType  # 1
    """置灰(按钮不可点击)"""

class DisableState(_DisableState, metaclass=_DisableStateEnumTypeWrapper):
    """"""

highlight: DisableState.ValueType  # 0
"""高亮"""
gary: DisableState.ValueType  # 1
"""置灰(按钮不可点击)"""
global___DisableState = DisableState

class _DynamicType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynamicTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynamicType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    dyn_none: _DynamicType.ValueType  # 0
    """占位"""
    forward: _DynamicType.ValueType  # 1
    """转发"""
    av: _DynamicType.ValueType  # 2
    """稿件: ugc、小视频、短视频、UGC转PGC"""
    pgc: _DynamicType.ValueType  # 3
    """pgc：番剧、PGC番剧、PGC电影、PGC电视剧、PGC国创、PGC纪录片"""
    courses: _DynamicType.ValueType  # 4
    """付费更新批次"""
    fold: _DynamicType.ValueType  # 5
    """折叠"""
    word: _DynamicType.ValueType  # 6
    """纯文字"""
    draw: _DynamicType.ValueType  # 7
    """图文"""
    article: _DynamicType.ValueType  # 8
    """专栏 原仅phone端"""
    music: _DynamicType.ValueType  # 9
    """音频 原仅phone端"""
    common_square: _DynamicType.ValueType  # 10
    """通用卡 方形"""
    common_vertical: _DynamicType.ValueType  # 11
    """通用卡 竖形"""
    live: _DynamicType.ValueType  # 12
    """直播卡 只有转发态"""
    medialist: _DynamicType.ValueType  # 13
    """播单 原仅phone端 只有转发态"""
    courses_season: _DynamicType.ValueType  # 14
    """付费更新批次 只有转发态"""
    ad: _DynamicType.ValueType  # 15
    """广告卡"""
    applet: _DynamicType.ValueType  # 16
    """小程序卡"""
    subscription: _DynamicType.ValueType  # 17
    """订阅卡"""
    live_rcmd: _DynamicType.ValueType  # 18
    """直播推荐卡"""
    banner: _DynamicType.ValueType  # 19
    """通栏"""
    ugc_season: _DynamicType.ValueType  # 20
    """合集卡"""
    subscription_new: _DynamicType.ValueType  # 21
    """新订阅卡"""
    story: _DynamicType.ValueType  # 22
    """"""
    topic_rcmd: _DynamicType.ValueType  # 23
    """"""
    cour_up: _DynamicType.ValueType  # 24
    """"""
    topic_set: _DynamicType.ValueType  # 25
    """"""
    notice: _DynamicType.ValueType  # 26
    """"""
    text_notice: _DynamicType.ValueType  # 27
    """"""

class DynamicType(_DynamicType, metaclass=_DynamicTypeEnumTypeWrapper):
    """枚举-动态类型"""

dyn_none: DynamicType.ValueType  # 0
"""占位"""
forward: DynamicType.ValueType  # 1
"""转发"""
av: DynamicType.ValueType  # 2
"""稿件: ugc、小视频、短视频、UGC转PGC"""
pgc: DynamicType.ValueType  # 3
"""pgc：番剧、PGC番剧、PGC电影、PGC电视剧、PGC国创、PGC纪录片"""
courses: DynamicType.ValueType  # 4
"""付费更新批次"""
fold: DynamicType.ValueType  # 5
"""折叠"""
word: DynamicType.ValueType  # 6
"""纯文字"""
draw: DynamicType.ValueType  # 7
"""图文"""
article: DynamicType.ValueType  # 8
"""专栏 原仅phone端"""
music: DynamicType.ValueType  # 9
"""音频 原仅phone端"""
common_square: DynamicType.ValueType  # 10
"""通用卡 方形"""
common_vertical: DynamicType.ValueType  # 11
"""通用卡 竖形"""
live: DynamicType.ValueType  # 12
"""直播卡 只有转发态"""
medialist: DynamicType.ValueType  # 13
"""播单 原仅phone端 只有转发态"""
courses_season: DynamicType.ValueType  # 14
"""付费更新批次 只有转发态"""
ad: DynamicType.ValueType  # 15
"""广告卡"""
applet: DynamicType.ValueType  # 16
"""小程序卡"""
subscription: DynamicType.ValueType  # 17
"""订阅卡"""
live_rcmd: DynamicType.ValueType  # 18
"""直播推荐卡"""
banner: DynamicType.ValueType  # 19
"""通栏"""
ugc_season: DynamicType.ValueType  # 20
"""合集卡"""
subscription_new: DynamicType.ValueType  # 21
"""新订阅卡"""
story: DynamicType.ValueType  # 22
""""""
topic_rcmd: DynamicType.ValueType  # 23
""""""
cour_up: DynamicType.ValueType  # 24
""""""
topic_set: DynamicType.ValueType  # 25
""""""
notice: DynamicType.ValueType  # 26
""""""
text_notice: DynamicType.ValueType  # 27
""""""
global___DynamicType = DynamicType

class _DynExtendType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynExtendTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynExtendType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    dyn_ext_type_none: _DynExtendType.ValueType  # 0
    """占位"""
    dyn_ext_type_topic: _DynExtendType.ValueType  # 1
    """话题小卡"""
    dyn_ext_type_lbs: _DynExtendType.ValueType  # 2
    """lbs小卡"""
    dyn_ext_type_hot: _DynExtendType.ValueType  # 3
    """热门小卡"""
    dyn_ext_type_game: _DynExtendType.ValueType  # 4
    """游戏小卡"""
    dyn_ext_type_common: _DynExtendType.ValueType  # 5
    """通用小卡"""
    dyn_ext_type_biliCut: _DynExtendType.ValueType  # 6
    """必剪小卡"""
    dyn_ext_type_ogv: _DynExtendType.ValueType  # 7
    """ogv小卡"""
    dyn_ext_type_auto_ogv: _DynExtendType.ValueType  # 8
    """自动附加ogv小卡"""

class DynExtendType(_DynExtendType, metaclass=_DynExtendTypeEnumTypeWrapper):
    """动态小卡类型"""

dyn_ext_type_none: DynExtendType.ValueType  # 0
"""占位"""
dyn_ext_type_topic: DynExtendType.ValueType  # 1
"""话题小卡"""
dyn_ext_type_lbs: DynExtendType.ValueType  # 2
"""lbs小卡"""
dyn_ext_type_hot: DynExtendType.ValueType  # 3
"""热门小卡"""
dyn_ext_type_game: DynExtendType.ValueType  # 4
"""游戏小卡"""
dyn_ext_type_common: DynExtendType.ValueType  # 5
"""通用小卡"""
dyn_ext_type_biliCut: DynExtendType.ValueType  # 6
"""必剪小卡"""
dyn_ext_type_ogv: DynExtendType.ValueType  # 7
"""ogv小卡"""
dyn_ext_type_auto_ogv: DynExtendType.ValueType  # 8
"""自动附加ogv小卡"""
global___DynExtendType = DynExtendType

class _DynModuleType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynModuleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynModuleType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    module_none: _DynModuleType.ValueType  # 0
    """占位"""
    module_author: _DynModuleType.ValueType  # 1
    """发布人模块"""
    module_dispute: _DynModuleType.ValueType  # 2
    """争议小黄条"""
    module_desc: _DynModuleType.ValueType  # 3
    """描述文案"""
    module_dynamic: _DynModuleType.ValueType  # 4
    """动态卡片"""
    module_forward: _DynModuleType.ValueType  # 5
    """转发模块"""
    module_likeUser: _DynModuleType.ValueType  # 6
    """点赞用户(废弃)"""
    module_extend: _DynModuleType.ValueType  # 7
    """小卡模块"""
    module_additional: _DynModuleType.ValueType  # 8
    """附加卡"""
    module_stat: _DynModuleType.ValueType  # 9
    """计数信息"""
    module_fold: _DynModuleType.ValueType  # 10
    """折叠"""
    module_comment: _DynModuleType.ValueType  # 11
    """评论外露(废弃)"""
    module_interaction: _DynModuleType.ValueType  # 12
    """外露交互模块(点赞、评论)"""
    module_author_forward: _DynModuleType.ValueType  # 13
    """转发卡的发布人模块"""
    module_ad: _DynModuleType.ValueType  # 14
    """广告卡模块"""
    module_banner: _DynModuleType.ValueType  # 15
    """通栏模块"""
    module_item_null: _DynModuleType.ValueType  # 16
    """获取物料失败模块"""
    module_share_info: _DynModuleType.ValueType  # 17
    """分享组件"""
    module_recommend: _DynModuleType.ValueType  # 18
    """相关推荐模块"""
    module_stat_forward: _DynModuleType.ValueType  # 19
    """转发卡计数信息"""
    module_top: _DynModuleType.ValueType  # 20
    """顶部模块"""
    module_bottom: _DynModuleType.ValueType  # 21
    """底部模块"""
    module_story: _DynModuleType.ValueType  # 22
    """"""
    module_topic: _DynModuleType.ValueType  # 23
    """"""
    module_topic_details_ext: _DynModuleType.ValueType  # 24
    """"""
    module_top_tag: _DynModuleType.ValueType  # 25
    """"""
    module_topic_brief: _DynModuleType.ValueType  # 26
    """"""
    module_title: _DynModuleType.ValueType  # 27
    """"""
    module_button: _DynModuleType.ValueType  # 28
    module_notice: _DynModuleType.ValueType  # 29
    module_opus_summary: _DynModuleType.ValueType  # 30
    module_copyright: _DynModuleType.ValueType  # 31
    module_paragraph: _DynModuleType.ValueType  # 32
    module_blocked: _DynModuleType.ValueType  # 33
    module_text_notice: _DynModuleType.ValueType  # 34
    module_opus_collection: _DynModuleType.ValueType  # 35

class DynModuleType(_DynModuleType, metaclass=_DynModuleTypeEnumTypeWrapper):
    """动态模块类型"""

module_none: DynModuleType.ValueType  # 0
"""占位"""
module_author: DynModuleType.ValueType  # 1
"""发布人模块"""
module_dispute: DynModuleType.ValueType  # 2
"""争议小黄条"""
module_desc: DynModuleType.ValueType  # 3
"""描述文案"""
module_dynamic: DynModuleType.ValueType  # 4
"""动态卡片"""
module_forward: DynModuleType.ValueType  # 5
"""转发模块"""
module_likeUser: DynModuleType.ValueType  # 6
"""点赞用户(废弃)"""
module_extend: DynModuleType.ValueType  # 7
"""小卡模块"""
module_additional: DynModuleType.ValueType  # 8
"""附加卡"""
module_stat: DynModuleType.ValueType  # 9
"""计数信息"""
module_fold: DynModuleType.ValueType  # 10
"""折叠"""
module_comment: DynModuleType.ValueType  # 11
"""评论外露(废弃)"""
module_interaction: DynModuleType.ValueType  # 12
"""外露交互模块(点赞、评论)"""
module_author_forward: DynModuleType.ValueType  # 13
"""转发卡的发布人模块"""
module_ad: DynModuleType.ValueType  # 14
"""广告卡模块"""
module_banner: DynModuleType.ValueType  # 15
"""通栏模块"""
module_item_null: DynModuleType.ValueType  # 16
"""获取物料失败模块"""
module_share_info: DynModuleType.ValueType  # 17
"""分享组件"""
module_recommend: DynModuleType.ValueType  # 18
"""相关推荐模块"""
module_stat_forward: DynModuleType.ValueType  # 19
"""转发卡计数信息"""
module_top: DynModuleType.ValueType  # 20
"""顶部模块"""
module_bottom: DynModuleType.ValueType  # 21
"""底部模块"""
module_story: DynModuleType.ValueType  # 22
""""""
module_topic: DynModuleType.ValueType  # 23
""""""
module_topic_details_ext: DynModuleType.ValueType  # 24
""""""
module_top_tag: DynModuleType.ValueType  # 25
""""""
module_topic_brief: DynModuleType.ValueType  # 26
""""""
module_title: DynModuleType.ValueType  # 27
""""""
module_button: DynModuleType.ValueType  # 28
module_notice: DynModuleType.ValueType  # 29
module_opus_summary: DynModuleType.ValueType  # 30
module_copyright: DynModuleType.ValueType  # 31
module_paragraph: DynModuleType.ValueType  # 32
module_blocked: DynModuleType.ValueType  # 33
module_text_notice: DynModuleType.ValueType  # 34
module_opus_collection: DynModuleType.ValueType  # 35
global___DynModuleType = DynModuleType

class _EmojiType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EmojiTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EmojiType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    emoji_none: _EmojiType.ValueType  # 0
    """占位"""
    emoji_old: _EmojiType.ValueType  # 1
    """emoji旧类型"""
    emoji_new: _EmojiType.ValueType  # 2
    """emoji新类型"""
    vip: _EmojiType.ValueType  # 3
    """大会员表情"""

class EmojiType(_EmojiType, metaclass=_EmojiTypeEnumTypeWrapper):
    """表情包类型"""

emoji_none: EmojiType.ValueType  # 0
"""占位"""
emoji_old: EmojiType.ValueType  # 1
"""emoji旧类型"""
emoji_new: EmojiType.ValueType  # 2
"""emoji新类型"""
vip: EmojiType.ValueType  # 3
"""大会员表情"""
global___EmojiType = EmojiType

class _EspaceStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EspaceStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EspaceStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    moba: _EspaceStyle.ValueType  # 0
    """moba类"""

class EspaceStyle(_EspaceStyle, metaclass=_EspaceStyleEnumTypeWrapper):
    """附加大卡-电竞卡样式"""

moba: EspaceStyle.ValueType  # 0
"""moba类"""
global___EspaceStyle = EspaceStyle

class _FoldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FoldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FoldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FoldTypeZore: _FoldType.ValueType  # 0
    """占位"""
    FoldTypePublish: _FoldType.ValueType  # 1
    """用户发布折叠"""
    FoldTypeFrequent: _FoldType.ValueType  # 2
    """转发超频折叠"""
    FoldTypeUnite: _FoldType.ValueType  # 3
    """联合投稿折叠"""
    FoldTypeLimit: _FoldType.ValueType  # 4
    """动态受限折叠"""
    FoldTypeTopicMerged: _FoldType.ValueType  # 5

class FoldType(_FoldType, metaclass=_FoldTypeEnumTypeWrapper):
    """折叠类型"""

FoldTypeZore: FoldType.ValueType  # 0
"""占位"""
FoldTypePublish: FoldType.ValueType  # 1
"""用户发布折叠"""
FoldTypeFrequent: FoldType.ValueType  # 2
"""转发超频折叠"""
FoldTypeUnite: FoldType.ValueType  # 3
"""联合投稿折叠"""
FoldTypeLimit: FoldType.ValueType  # 4
"""动态受限折叠"""
FoldTypeTopicMerged: FoldType.ValueType  # 5
global___FoldType = FoldType

class _FollowType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FollowTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FollowType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ft_not_follow: _FollowType.ValueType  # 0
    """"""
    ft_follow: _FollowType.ValueType  # 1
    """"""

class FollowType(_FollowType, metaclass=_FollowTypeEnumTypeWrapper):
    """"""

ft_not_follow: FollowType.ValueType  # 0
""""""
ft_follow: FollowType.ValueType  # 1
""""""
global___FollowType = FollowType

class _GoodsJumpType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GoodsJumpTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GoodsJumpType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    goods_none: _GoodsJumpType.ValueType  # 0
    goods_schema: _GoodsJumpType.ValueType  # 1
    goods_url: _GoodsJumpType.ValueType  # 2

class GoodsJumpType(_GoodsJumpType, metaclass=_GoodsJumpTypeEnumTypeWrapper):
    """"""

goods_none: GoodsJumpType.ValueType  # 0
goods_schema: GoodsJumpType.ValueType  # 1
goods_url: GoodsJumpType.ValueType  # 2
global___GoodsJumpType = GoodsJumpType

class _HighlightTextStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HighlightTextStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HighlightTextStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    style_none: _HighlightTextStyle.ValueType  # 0
    """默认"""
    style_highlight: _HighlightTextStyle.ValueType  # 1
    """高亮"""

class HighlightTextStyle(_HighlightTextStyle, metaclass=_HighlightTextStyleEnumTypeWrapper):
    """文本高亮枚举"""

style_none: HighlightTextStyle.ValueType  # 0
"""默认"""
style_highlight: HighlightTextStyle.ValueType  # 1
"""高亮"""
global___HighlightTextStyle = HighlightTextStyle

class _HomePageTabSttingStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HomePageTabSttingStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HomePageTabSttingStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SETTING_INVALID: _HomePageTabSttingStatus.ValueType  # 0
    SETTING_OPEN: _HomePageTabSttingStatus.ValueType  # 1
    SETTING_CLOSE: _HomePageTabSttingStatus.ValueType  # 2

class HomePageTabSttingStatus(_HomePageTabSttingStatus, metaclass=_HomePageTabSttingStatusEnumTypeWrapper):
    """"""

SETTING_INVALID: HomePageTabSttingStatus.ValueType  # 0
SETTING_OPEN: HomePageTabSttingStatus.ValueType  # 1
SETTING_CLOSE: HomePageTabSttingStatus.ValueType  # 2
global___HomePageTabSttingStatus = HomePageTabSttingStatus

class _IconResLocal:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IconResLocalEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IconResLocal.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ICON_RES_LOCAL_NONE: _IconResLocal.ValueType  # 0
    ICON_RES_LOCAL_LIVE: _IconResLocal.ValueType  # 1

class IconResLocal(_IconResLocal, metaclass=_IconResLocalEnumTypeWrapper):
    """"""

ICON_RES_LOCAL_NONE: IconResLocal.ValueType  # 0
ICON_RES_LOCAL_LIVE: IconResLocal.ValueType  # 1
global___IconResLocal = IconResLocal

class _ImageStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ImageStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ImageStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    add_style_vertical: _ImageStyle.ValueType  # 0
    """"""
    add_style_square: _ImageStyle.ValueType  # 1
    """"""

class ImageStyle(_ImageStyle, metaclass=_ImageStyleEnumTypeWrapper):
    """枚举-附加卡样式"""

add_style_vertical: ImageStyle.ValueType  # 0
""""""
add_style_square: ImageStyle.ValueType  # 1
""""""
global___ImageStyle = ImageStyle

class _LightFromType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LightFromTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LightFromType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    from_login: _LightFromType.ValueType  # 0
    """"""
    from_unlogin: _LightFromType.ValueType  # 1
    """"""

class LightFromType(_LightFromType, metaclass=_LightFromTypeEnumTypeWrapper):
    """"""

from_login: LightFromType.ValueType  # 0
""""""
from_unlogin: LightFromType.ValueType  # 1
""""""
global___LightFromType = LightFromType

class _LinkNodeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LinkNodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LinkNodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _LinkNodeType.ValueType  # 0
    VIDEO: _LinkNodeType.ValueType  # 1
    RESERVE: _LinkNodeType.ValueType  # 2
    VOTE: _LinkNodeType.ValueType  # 3
    LIVE: _LinkNodeType.ValueType  # 4
    LOTTERY: _LinkNodeType.ValueType  # 5
    MATCH: _LinkNodeType.ValueType  # 6
    GOODS: _LinkNodeType.ValueType  # 7
    OGV_SS: _LinkNodeType.ValueType  # 8
    OGV_EP: _LinkNodeType.ValueType  # 9
    MANGA: _LinkNodeType.ValueType  # 10
    CHEESE: _LinkNodeType.ValueType  # 11
    VIDEO_TS: _LinkNodeType.ValueType  # 12
    AT: _LinkNodeType.ValueType  # 13
    HASH_TAG: _LinkNodeType.ValueType  # 14
    ARTICLE: _LinkNodeType.ValueType  # 15
    URL: _LinkNodeType.ValueType  # 16
    MAIL: _LinkNodeType.ValueType  # 17
    LBS: _LinkNodeType.ValueType  # 18
    ACTIVITY: _LinkNodeType.ValueType  # 19
    ATTACH_CARD_OFFICIAL_ACTIVITY: _LinkNodeType.ValueType  # 20
    GAME: _LinkNodeType.ValueType  # 21
    DECORATION: _LinkNodeType.ValueType  # 22
    UP_TOPIC: _LinkNodeType.ValueType  # 23
    UP_ACTIVITY: _LinkNodeType.ValueType  # 24
    UP_MAOER: _LinkNodeType.ValueType  # 25
    MEMBER_GOODS: _LinkNodeType.ValueType  # 26
    OPENMALL_UP_ITEMS: _LinkNodeType.ValueType  # 27
    SEARCH: _LinkNodeType.ValueType  # 28

class LinkNodeType(_LinkNodeType, metaclass=_LinkNodeTypeEnumTypeWrapper):
    """"""

INVALID: LinkNodeType.ValueType  # 0
VIDEO: LinkNodeType.ValueType  # 1
RESERVE: LinkNodeType.ValueType  # 2
VOTE: LinkNodeType.ValueType  # 3
LIVE: LinkNodeType.ValueType  # 4
LOTTERY: LinkNodeType.ValueType  # 5
MATCH: LinkNodeType.ValueType  # 6
GOODS: LinkNodeType.ValueType  # 7
OGV_SS: LinkNodeType.ValueType  # 8
OGV_EP: LinkNodeType.ValueType  # 9
MANGA: LinkNodeType.ValueType  # 10
CHEESE: LinkNodeType.ValueType  # 11
VIDEO_TS: LinkNodeType.ValueType  # 12
AT: LinkNodeType.ValueType  # 13
HASH_TAG: LinkNodeType.ValueType  # 14
ARTICLE: LinkNodeType.ValueType  # 15
URL: LinkNodeType.ValueType  # 16
MAIL: LinkNodeType.ValueType  # 17
LBS: LinkNodeType.ValueType  # 18
ACTIVITY: LinkNodeType.ValueType  # 19
ATTACH_CARD_OFFICIAL_ACTIVITY: LinkNodeType.ValueType  # 20
GAME: LinkNodeType.ValueType  # 21
DECORATION: LinkNodeType.ValueType  # 22
UP_TOPIC: LinkNodeType.ValueType  # 23
UP_ACTIVITY: LinkNodeType.ValueType  # 24
UP_MAOER: LinkNodeType.ValueType  # 25
MEMBER_GOODS: LinkNodeType.ValueType  # 26
OPENMALL_UP_ITEMS: LinkNodeType.ValueType  # 27
SEARCH: LinkNodeType.ValueType  # 28
global___LinkNodeType = LinkNodeType

class _LiveState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LiveStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LiveState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    live_none: _LiveState.ValueType  # 0
    """未直播"""
    live_live: _LiveState.ValueType  # 1
    """直播中"""
    live_rotation: _LiveState.ValueType  # 2
    """轮播中"""

class LiveState(_LiveState, metaclass=_LiveStateEnumTypeWrapper):
    """直播状态"""

live_none: LiveState.ValueType  # 0
"""未直播"""
live_live: LiveState.ValueType  # 1
"""直播中"""
live_rotation: LiveState.ValueType  # 2
"""轮播中"""
global___LiveState = LiveState

class _LocalIconType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LocalIconTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LocalIconType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    local_icon_comment: _LocalIconType.ValueType  # 0
    """"""
    local_icon_like: _LocalIconType.ValueType  # 1
    """"""
    local_icon_avatar: _LocalIconType.ValueType  # 2
    local_icon_cover: _LocalIconType.ValueType  # 3
    local_icon_like_and_forward: _LocalIconType.ValueType  # 4

class LocalIconType(_LocalIconType, metaclass=_LocalIconTypeEnumTypeWrapper):
    """外露模块类型"""

local_icon_comment: LocalIconType.ValueType  # 0
""""""
local_icon_like: LocalIconType.ValueType  # 1
""""""
local_icon_avatar: LocalIconType.ValueType  # 2
local_icon_cover: LocalIconType.ValueType  # 3
local_icon_like_and_forward: LocalIconType.ValueType  # 4
global___LocalIconType = LocalIconType

class _MdlBlockedStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlBlockedStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlBlockedStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BLOCKED_STYLE_DEFAULT: _MdlBlockedStyle.ValueType  # 0
    BLOCKED_STYLE_IN_AUDIT: _MdlBlockedStyle.ValueType  # 1
    BLOCKED_STYLE_ONLY_FANS_LIST: _MdlBlockedStyle.ValueType  # 2
    BLOCKED_STYLE_ONLY_FANS_VIDEO: _MdlBlockedStyle.ValueType  # 3

class MdlBlockedStyle(_MdlBlockedStyle, metaclass=_MdlBlockedStyleEnumTypeWrapper):
    """"""

BLOCKED_STYLE_DEFAULT: MdlBlockedStyle.ValueType  # 0
BLOCKED_STYLE_IN_AUDIT: MdlBlockedStyle.ValueType  # 1
BLOCKED_STYLE_ONLY_FANS_LIST: MdlBlockedStyle.ValueType  # 2
BLOCKED_STYLE_ONLY_FANS_VIDEO: MdlBlockedStyle.ValueType  # 3
global___MdlBlockedStyle = MdlBlockedStyle

class _MdlDynCommonType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlDynCommonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlDynCommonType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_dyn_common_none: _MdlDynCommonType.ValueType  # 0
    """"""
    mdl_dyn_common_square: _MdlDynCommonType.ValueType  # 1
    """"""
    mdl_dyn_common_vertica: _MdlDynCommonType.ValueType  # 2
    """"""

class MdlDynCommonType(_MdlDynCommonType, metaclass=_MdlDynCommonTypeEnumTypeWrapper):
    """"""

mdl_dyn_common_none: MdlDynCommonType.ValueType  # 0
""""""
mdl_dyn_common_square: MdlDynCommonType.ValueType  # 1
""""""
mdl_dyn_common_vertica: MdlDynCommonType.ValueType  # 2
""""""
global___MdlDynCommonType = MdlDynCommonType

class _MdlDynDrawTagType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlDynDrawTagTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlDynDrawTagType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_draw_tag_none: _MdlDynDrawTagType.ValueType  # 0
    """占位"""
    mdl_draw_tag_common: _MdlDynDrawTagType.ValueType  # 1
    """普通标签"""
    mdl_draw_tag_goods: _MdlDynDrawTagType.ValueType  # 2
    """商品标签"""
    mdl_draw_tag_user: _MdlDynDrawTagType.ValueType  # 3
    """用户昵称"""
    mdl_draw_tag_topic: _MdlDynDrawTagType.ValueType  # 4
    """话题名称"""
    mdl_draw_tag_lbs: _MdlDynDrawTagType.ValueType  # 5
    """lbs标签"""

class MdlDynDrawTagType(_MdlDynDrawTagType, metaclass=_MdlDynDrawTagTypeEnumTypeWrapper):
    """图文标签类型"""

mdl_draw_tag_none: MdlDynDrawTagType.ValueType  # 0
"""占位"""
mdl_draw_tag_common: MdlDynDrawTagType.ValueType  # 1
"""普通标签"""
mdl_draw_tag_goods: MdlDynDrawTagType.ValueType  # 2
"""商品标签"""
mdl_draw_tag_user: MdlDynDrawTagType.ValueType  # 3
"""用户昵称"""
mdl_draw_tag_topic: MdlDynDrawTagType.ValueType  # 4
"""话题名称"""
mdl_draw_tag_lbs: MdlDynDrawTagType.ValueType  # 5
"""lbs标签"""
global___MdlDynDrawTagType = MdlDynDrawTagType

class _MdlDynSubscriptionNewStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MdlDynSubscriptionNewStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MdlDynSubscriptionNewStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_dyn_subscription_new_style_nont: _MdlDynSubscriptionNewStyle.ValueType  # 0
    """占位"""
    mdl_dyn_subscription_new_style_live: _MdlDynSubscriptionNewStyle.ValueType  # 1
    """直播"""
    mdl_dyn_subscription_new_style_draw: _MdlDynSubscriptionNewStyle.ValueType  # 2
    """图文"""

class MdlDynSubscriptionNewStyle(_MdlDynSubscriptionNewStyle, metaclass=_MdlDynSubscriptionNewStyleEnumTypeWrapper):
    """"""

mdl_dyn_subscription_new_style_nont: MdlDynSubscriptionNewStyle.ValueType  # 0
"""占位"""
mdl_dyn_subscription_new_style_live: MdlDynSubscriptionNewStyle.ValueType  # 1
"""直播"""
mdl_dyn_subscription_new_style_draw: MdlDynSubscriptionNewStyle.ValueType  # 2
"""图文"""
global___MdlDynSubscriptionNewStyle = MdlDynSubscriptionNewStyle

class _MediaType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MediaTypeNone: _MediaType.ValueType  # 0
    """本地"""
    MediaTypeUGC: _MediaType.ValueType  # 1
    """UGC"""
    MediaTypePGC: _MediaType.ValueType  # 2
    """PGC"""
    MediaTypeLive: _MediaType.ValueType  # 3
    """直播"""
    MediaTypeVCS: _MediaType.ValueType  # 4
    """小视频"""

class MediaType(_MediaType, metaclass=_MediaTypeEnumTypeWrapper):
    """播放器类型"""

MediaTypeNone: MediaType.ValueType  # 0
"""本地"""
MediaTypeUGC: MediaType.ValueType  # 1
"""UGC"""
MediaTypePGC: MediaType.ValueType  # 2
"""PGC"""
MediaTypeLive: MediaType.ValueType  # 3
"""直播"""
MediaTypeVCS: MediaType.ValueType  # 4
"""小视频"""
global___MediaType = MediaType

class _ModuleAuthorBadgeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModuleAuthorBadgeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModuleAuthorBadgeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    module_author_badge_type_none: _ModuleAuthorBadgeType.ValueType  # 0
    """占位"""
    module_author_badge_type_threePoint: _ModuleAuthorBadgeType.ValueType  # 1
    """三点"""
    module_author_badge_type_button: _ModuleAuthorBadgeType.ValueType  # 2
    """按钮类型"""
    module_author_badge_type_weight: _ModuleAuthorBadgeType.ValueType  # 3
    """提权"""

class ModuleAuthorBadgeType(_ModuleAuthorBadgeType, metaclass=_ModuleAuthorBadgeTypeEnumTypeWrapper):
    """右侧操作区域样式枚举"""

module_author_badge_type_none: ModuleAuthorBadgeType.ValueType  # 0
"""占位"""
module_author_badge_type_threePoint: ModuleAuthorBadgeType.ValueType  # 1
"""三点"""
module_author_badge_type_button: ModuleAuthorBadgeType.ValueType  # 2
"""按钮类型"""
module_author_badge_type_weight: ModuleAuthorBadgeType.ValueType  # 3
"""提权"""
global___ModuleAuthorBadgeType = ModuleAuthorBadgeType

class _ModuleBannerType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModuleBannerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModuleBannerType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    module_banner_type_none: _ModuleBannerType.ValueType  # 0
    """"""
    module_banner_type_user: _ModuleBannerType.ValueType  # 1
    """"""

class ModuleBannerType(_ModuleBannerType, metaclass=_ModuleBannerTypeEnumTypeWrapper):
    """动态列表-通栏类型"""

module_banner_type_none: ModuleBannerType.ValueType  # 0
""""""
module_banner_type_user: ModuleBannerType.ValueType  # 1
""""""
global___ModuleBannerType = ModuleBannerType

class _ModuleDynamicType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModuleDynamicTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModuleDynamicType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    mdl_dyn_archive: _ModuleDynamicType.ValueType  # 0
    """稿件"""
    mdl_dyn_pgc: _ModuleDynamicType.ValueType  # 1
    """pgc"""
    mdl_dyn_cour_season: _ModuleDynamicType.ValueType  # 2
    """付费课程-系列"""
    mdl_dyn_cour_batch: _ModuleDynamicType.ValueType  # 3
    """付费课程-批次"""
    mdl_dyn_forward: _ModuleDynamicType.ValueType  # 4
    """转发卡"""
    mdl_dyn_draw: _ModuleDynamicType.ValueType  # 5
    """图文"""
    mdl_dyn_article: _ModuleDynamicType.ValueType  # 6
    """专栏"""
    mdl_dyn_music: _ModuleDynamicType.ValueType  # 7
    """音频"""
    mdl_dyn_common: _ModuleDynamicType.ValueType  # 8
    """通用卡方"""
    mdl_dyn_live: _ModuleDynamicType.ValueType  # 9
    """直播卡"""
    mdl_dyn_medialist: _ModuleDynamicType.ValueType  # 10
    """播单"""
    mdl_dyn_applet: _ModuleDynamicType.ValueType  # 11
    """小程序卡"""
    mdl_dyn_subscription: _ModuleDynamicType.ValueType  # 12
    """订阅卡"""
    mdl_dyn_live_rcmd: _ModuleDynamicType.ValueType  # 13
    """直播推荐卡"""
    mdl_dyn_ugc_season: _ModuleDynamicType.ValueType  # 14
    """UGC合集"""
    mdl_dyn_subscription_new: _ModuleDynamicType.ValueType  # 15
    """订阅卡"""
    mdl_dyn_cour_batch_up: _ModuleDynamicType.ValueType  # 16
    """课程"""
    mdl_dyn_topic_set: _ModuleDynamicType.ValueType  # 17
    """话题集合"""

class ModuleDynamicType(_ModuleDynamicType, metaclass=_ModuleDynamicTypeEnumTypeWrapper):
    """动态详情模块类型"""

mdl_dyn_archive: ModuleDynamicType.ValueType  # 0
"""稿件"""
mdl_dyn_pgc: ModuleDynamicType.ValueType  # 1
"""pgc"""
mdl_dyn_cour_season: ModuleDynamicType.ValueType  # 2
"""付费课程-系列"""
mdl_dyn_cour_batch: ModuleDynamicType.ValueType  # 3
"""付费课程-批次"""
mdl_dyn_forward: ModuleDynamicType.ValueType  # 4
"""转发卡"""
mdl_dyn_draw: ModuleDynamicType.ValueType  # 5
"""图文"""
mdl_dyn_article: ModuleDynamicType.ValueType  # 6
"""专栏"""
mdl_dyn_music: ModuleDynamicType.ValueType  # 7
"""音频"""
mdl_dyn_common: ModuleDynamicType.ValueType  # 8
"""通用卡方"""
mdl_dyn_live: ModuleDynamicType.ValueType  # 9
"""直播卡"""
mdl_dyn_medialist: ModuleDynamicType.ValueType  # 10
"""播单"""
mdl_dyn_applet: ModuleDynamicType.ValueType  # 11
"""小程序卡"""
mdl_dyn_subscription: ModuleDynamicType.ValueType  # 12
"""订阅卡"""
mdl_dyn_live_rcmd: ModuleDynamicType.ValueType  # 13
"""直播推荐卡"""
mdl_dyn_ugc_season: ModuleDynamicType.ValueType  # 14
"""UGC合集"""
mdl_dyn_subscription_new: ModuleDynamicType.ValueType  # 15
"""订阅卡"""
mdl_dyn_cour_batch_up: ModuleDynamicType.ValueType  # 16
"""课程"""
mdl_dyn_topic_set: ModuleDynamicType.ValueType  # 17
"""话题集合"""
global___ModuleDynamicType = ModuleDynamicType

class _NetworkType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NetworkTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NetworkType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NT_UNKNOWN: _NetworkType.ValueType  # 0
    """"""
    WIFI: _NetworkType.ValueType  # 1
    """"""
    CELLULAR: _NetworkType.ValueType  # 2
    """"""
    OFFLINE: _NetworkType.ValueType  # 3
    """"""
    OTHERNET: _NetworkType.ValueType  # 4
    """"""
    ETHERNET: _NetworkType.ValueType  # 5
    """"""

class NetworkType(_NetworkType, metaclass=_NetworkTypeEnumTypeWrapper): ...

NT_UNKNOWN: NetworkType.ValueType  # 0
""""""
WIFI: NetworkType.ValueType  # 1
""""""
CELLULAR: NetworkType.ValueType  # 2
""""""
OFFLINE: NetworkType.ValueType  # 3
""""""
OTHERNET: NetworkType.ValueType  # 4
""""""
ETHERNET: NetworkType.ValueType  # 5
""""""
global___NetworkType = NetworkType

class _NFTRegionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NFTRegionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NFTRegionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    nft_region_default: _NFTRegionType.ValueType  # 0
    nft_region_mainlang: _NFTRegionType.ValueType  # 1
    nft_region_gat: _NFTRegionType.ValueType  # 2

class NFTRegionType(_NFTRegionType, metaclass=_NFTRegionTypeEnumTypeWrapper):
    """"""

nft_region_default: NFTRegionType.ValueType  # 0
nft_region_mainlang: NFTRegionType.ValueType  # 1
nft_region_gat: NFTRegionType.ValueType  # 2
global___NFTRegionType = NFTRegionType

class _NFTShowStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NFTShowStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NFTShowStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    nft_show_default: _NFTShowStatus.ValueType  # 0
    nft_show_zoominmainlang: _NFTShowStatus.ValueType  # 1
    nft_show_raw: _NFTShowStatus.ValueType  # 2

class NFTShowStatus(_NFTShowStatus, metaclass=_NFTShowStatusEnumTypeWrapper):
    """"""

nft_show_default: NFTShowStatus.ValueType  # 0
nft_show_zoominmainlang: NFTShowStatus.ValueType  # 1
nft_show_raw: NFTShowStatus.ValueType  # 2
global___NFTShowStatus = NFTShowStatus

class _RcmdReasonStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RcmdReasonStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RcmdReasonStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    rcmd_reason_style_none: _RcmdReasonStyle.ValueType  # 0
    rcmd_reason_style_campus_nearby: _RcmdReasonStyle.ValueType  # 1
    rcmd_reason_style_campus_up: _RcmdReasonStyle.ValueType  # 2
    rcmd_reason_style_campus_near_up_mix: _RcmdReasonStyle.ValueType  # 3

class RcmdReasonStyle(_RcmdReasonStyle, metaclass=_RcmdReasonStyleEnumTypeWrapper):
    """"""

rcmd_reason_style_none: RcmdReasonStyle.ValueType  # 0
rcmd_reason_style_campus_nearby: RcmdReasonStyle.ValueType  # 1
rcmd_reason_style_campus_up: RcmdReasonStyle.ValueType  # 2
rcmd_reason_style_campus_near_up_mix: RcmdReasonStyle.ValueType  # 3
global___RcmdReasonStyle = RcmdReasonStyle

class _RcmdType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RcmdTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RcmdType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    rcmd_archive: _RcmdType.ValueType  # 0
    """稿件"""
    rcmd_dynamic: _RcmdType.ValueType  # 1
    """动态"""

class RcmdType(_RcmdType, metaclass=_RcmdTypeEnumTypeWrapper):
    """推荐模块数据类型"""

rcmd_archive: RcmdType.ValueType  # 0
"""稿件"""
rcmd_dynamic: RcmdType.ValueType  # 1
"""动态"""
global___RcmdType = RcmdType

class _Refresh:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RefreshEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Refresh.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    refresh_new: _Refresh.ValueType  # 0
    """刷新列表"""
    refresh_history: _Refresh.ValueType  # 1
    """请求历史"""

class Refresh(_Refresh, metaclass=_RefreshEnumTypeWrapper):
    """刷新方式"""

refresh_new: Refresh.ValueType  # 0
"""刷新列表"""
refresh_history: Refresh.ValueType  # 1
"""请求历史"""
global___Refresh = Refresh

class _RelationStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RelationStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RelationStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    relation_status_none: _RelationStatus.ValueType  # 0
    """1-未关注 2-关注 3-被关注 4-互相关注 5-特别关注"""
    relation_status_nofollow: _RelationStatus.ValueType  # 1
    relation_status_follow: _RelationStatus.ValueType  # 2
    relation_status_followed: _RelationStatus.ValueType  # 3
    relation_status_mutual_concern: _RelationStatus.ValueType  # 4
    relation_status_special: _RelationStatus.ValueType  # 5

class RelationStatus(_RelationStatus, metaclass=_RelationStatusEnumTypeWrapper):
    """关注关系 枚举"""

relation_status_none: RelationStatus.ValueType  # 0
"""1-未关注 2-关注 3-被关注 4-互相关注 5-特别关注"""
relation_status_nofollow: RelationStatus.ValueType  # 1
relation_status_follow: RelationStatus.ValueType  # 2
relation_status_followed: RelationStatus.ValueType  # 3
relation_status_mutual_concern: RelationStatus.ValueType  # 4
relation_status_special: RelationStatus.ValueType  # 5
global___RelationStatus = RelationStatus

class _RepostType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RepostTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RepostType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    repost_hot: _RepostType.ValueType  # 0
    """热门评论"""
    repost_general: _RepostType.ValueType  # 1
    """普通评论"""

class RepostType(_RepostType, metaclass=_RepostTypeEnumTypeWrapper):
    """评论类型"""

repost_hot: RepostType.ValueType  # 0
"""热门评论"""
repost_general: RepostType.ValueType  # 1
"""普通评论"""
global___RepostType = RepostType

class _ReserveRelationLotteryType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveRelationLotteryTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveRelationLotteryType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    reserve_relation_lottery_type_default: _ReserveRelationLotteryType.ValueType  # 0
    """"""
    reserve_relation_lottery_type_cron: _ReserveRelationLotteryType.ValueType  # 1
    """"""

class ReserveRelationLotteryType(_ReserveRelationLotteryType, metaclass=_ReserveRelationLotteryTypeEnumTypeWrapper):
    """"""

reserve_relation_lottery_type_default: ReserveRelationLotteryType.ValueType  # 0
""""""
reserve_relation_lottery_type_cron: ReserveRelationLotteryType.ValueType  # 1
""""""
global___ReserveRelationLotteryType = ReserveRelationLotteryType

class _ReserveType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    reserve_none: _ReserveType.ValueType  # 0
    """占位"""
    reserve_recall: _ReserveType.ValueType  # 1
    """预约召回"""

class ReserveType(_ReserveType, metaclass=_ReserveTypeEnumTypeWrapper):
    """"""

reserve_none: ReserveType.ValueType  # 0
"""占位"""
reserve_recall: ReserveType.ValueType  # 1
"""预约召回"""
global___ReserveType = ReserveType

class _RouterAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RouterActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RouterAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    OPEN: _RouterAction.ValueType  # 0
    EMBED: _RouterAction.ValueType  # 1

class RouterAction(_RouterAction, metaclass=_RouterActionEnumTypeWrapper): ...

OPEN: RouterAction.ValueType  # 0
EMBED: RouterAction.ValueType  # 1
global___RouterAction = RouterAction

class _ShowType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ShowTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ShowType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    show_type_none: _ShowType.ValueType  # 0
    """"""
    show_type_backup: _ShowType.ValueType  # 1
    """"""

class ShowType(_ShowType, metaclass=_ShowTypeEnumTypeWrapper):
    """"""

show_type_none: ShowType.ValueType  # 0
""""""
show_type_backup: ShowType.ValueType  # 1
""""""
global___ShowType = ShowType

class _StyleType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StyleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StyleType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STYLE_TYPE_NONE: _StyleType.ValueType  # 0
    """"""
    STYLE_TYPE_LIVE: _StyleType.ValueType  # 1
    """"""
    STYLE_TYPE_DYN_UP: _StyleType.ValueType  # 2
    """"""

class StyleType(_StyleType, metaclass=_StyleTypeEnumTypeWrapper):
    """"""

STYLE_TYPE_NONE: StyleType.ValueType  # 0
""""""
STYLE_TYPE_LIVE: StyleType.ValueType  # 1
""""""
STYLE_TYPE_DYN_UP: StyleType.ValueType  # 2
""""""
global___StyleType = StyleType

class _TFType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TFTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TFType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TF_UNKNOWN: _TFType.ValueType  # 0
    """未知"""
    U_CARD: _TFType.ValueType  # 1
    """联通卡"""
    U_PKG: _TFType.ValueType  # 2
    """联通免流包"""
    C_CARD: _TFType.ValueType  # 3
    """移动卡"""
    C_PKG: _TFType.ValueType  # 4
    """移动免流包"""
    T_CARD: _TFType.ValueType  # 5
    """电信卡"""
    T_PKG: _TFType.ValueType  # 6
    """电信免流包"""

class TFType(_TFType, metaclass=_TFTypeEnumTypeWrapper):
    """免流类型"""

TF_UNKNOWN: TFType.ValueType  # 0
"""未知"""
U_CARD: TFType.ValueType  # 1
"""联通卡"""
U_PKG: TFType.ValueType  # 2
"""联通免流包"""
C_CARD: TFType.ValueType  # 3
"""移动卡"""
C_PKG: TFType.ValueType  # 4
"""移动免流包"""
T_CARD: TFType.ValueType  # 5
"""电信卡"""
T_PKG: TFType.ValueType  # 6
"""电信免流包"""
global___TFType = TFType

class _ThreePointAttentionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThreePointAttentionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThreePointAttentionStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    tp_not_attention: _ThreePointAttentionStatus.ValueType  # 0
    """"""
    tp_attention: _ThreePointAttentionStatus.ValueType  # 1
    """"""

class ThreePointAttentionStatus(_ThreePointAttentionStatus, metaclass=_ThreePointAttentionStatusEnumTypeWrapper):
    """枚举-三点关注状态"""

tp_not_attention: ThreePointAttentionStatus.ValueType  # 0
""""""
tp_attention: ThreePointAttentionStatus.ValueType  # 1
""""""
global___ThreePointAttentionStatus = ThreePointAttentionStatus

class _ThreePointType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThreePointTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThreePointType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    tp_none: _ThreePointType.ValueType  # 0
    """占位"""
    background: _ThreePointType.ValueType  # 1
    """使用此背景"""
    auto_play: _ThreePointType.ValueType  # 2
    """自动播放"""
    share: _ThreePointType.ValueType  # 3
    """分享"""
    wait: _ThreePointType.ValueType  # 4
    """稍后再播"""
    attention: _ThreePointType.ValueType  # 5
    """关注"""
    report: _ThreePointType.ValueType  # 6
    """举报"""
    delete: _ThreePointType.ValueType  # 7
    """删除"""
    dislike: _ThreePointType.ValueType  # 8
    """不感兴趣"""
    favorite: _ThreePointType.ValueType  # 9
    """收藏"""
    top: _ThreePointType.ValueType  # 10
    """置顶"""
    comment: _ThreePointType.ValueType  # 11
    """评论"""
    hide: _ThreePointType.ValueType  # 12
    """"""
    campus_delete: _ThreePointType.ValueType  # 13
    """"""
    topic_irrelevant: _ThreePointType.ValueType  # 14
    """"""

class ThreePointType(_ThreePointType, metaclass=_ThreePointTypeEnumTypeWrapper):
    """三点类型"""

tp_none: ThreePointType.ValueType  # 0
"""占位"""
background: ThreePointType.ValueType  # 1
"""使用此背景"""
auto_play: ThreePointType.ValueType  # 2
"""自动播放"""
share: ThreePointType.ValueType  # 3
"""分享"""
wait: ThreePointType.ValueType  # 4
"""稍后再播"""
attention: ThreePointType.ValueType  # 5
"""关注"""
report: ThreePointType.ValueType  # 6
"""举报"""
delete: ThreePointType.ValueType  # 7
"""删除"""
dislike: ThreePointType.ValueType  # 8
"""不感兴趣"""
favorite: ThreePointType.ValueType  # 9
"""收藏"""
top: ThreePointType.ValueType  # 10
"""置顶"""
comment: ThreePointType.ValueType  # 11
"""评论"""
hide: ThreePointType.ValueType  # 12
""""""
campus_delete: ThreePointType.ValueType  # 13
""""""
topic_irrelevant: ThreePointType.ValueType  # 14
""""""
global___ThreePointType = ThreePointType

class _ThumbType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThumbTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThumbType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    cancel: _ThumbType.ValueType  # 0
    """"""
    thumb: _ThumbType.ValueType  # 1
    """"""

class ThumbType(_ThumbType, metaclass=_ThumbTypeEnumTypeWrapper):
    """"""

cancel: ThumbType.ValueType  # 0
""""""
thumb: ThumbType.ValueType  # 1
""""""
global___ThumbType = ThumbType

class _TopType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    top_none: _TopType.ValueType  # 0
    """默认 置顶"""
    top_cancel: _TopType.ValueType  # 1
    """取消置顶"""

class TopType(_TopType, metaclass=_TopTypeEnumTypeWrapper):
    """状态"""

top_none: TopType.ValueType  # 0
"""默认 置顶"""
top_cancel: TopType.ValueType  # 1
"""取消置顶"""
global___TopType = TopType

class _UserItemType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    user_item_type_none: _UserItemType.ValueType  # 0
    """"""
    user_item_type_live: _UserItemType.ValueType  # 1
    """"""
    user_item_type_live_custom: _UserItemType.ValueType  # 2
    """"""
    user_item_type_normal: _UserItemType.ValueType  # 3
    """"""
    user_item_type_extend: _UserItemType.ValueType  # 4
    """"""
    user_item_type_premiere_reserve: _UserItemType.ValueType  # 5
    user_item_type_premiere: _UserItemType.ValueType  # 6
    user_item_type_live_card: _UserItemType.ValueType  # 7
    user_item_type_ogv_season: _UserItemType.ValueType  # 8
    user_item_type_ugc_season: _UserItemType.ValueType  # 9

class UserItemType(_UserItemType, metaclass=_UserItemTypeEnumTypeWrapper):
    """用户类型"""

user_item_type_none: UserItemType.ValueType  # 0
""""""
user_item_type_live: UserItemType.ValueType  # 1
""""""
user_item_type_live_custom: UserItemType.ValueType  # 2
""""""
user_item_type_normal: UserItemType.ValueType  # 3
""""""
user_item_type_extend: UserItemType.ValueType  # 4
""""""
user_item_type_premiere_reserve: UserItemType.ValueType  # 5
user_item_type_premiere: UserItemType.ValueType  # 6
user_item_type_live_card: UserItemType.ValueType  # 7
user_item_type_ogv_season: UserItemType.ValueType  # 8
user_item_type_ugc_season: UserItemType.ValueType  # 9
global___UserItemType = UserItemType

class _VideoSubType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoSubTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoSubType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VideoSubTypeNone: _VideoSubType.ValueType  # 0
    """没有子类型"""
    VideoSubTypeBangumi: _VideoSubType.ValueType  # 1
    """番剧"""
    VideoSubTypeMovie: _VideoSubType.ValueType  # 2
    """电影"""
    VideoSubTypeDocumentary: _VideoSubType.ValueType  # 3
    """纪录片"""
    VideoSubTypeDomestic: _VideoSubType.ValueType  # 4
    """国创"""
    VideoSubTypeTeleplay: _VideoSubType.ValueType  # 5
    """电视剧"""

class VideoSubType(_VideoSubType, metaclass=_VideoSubTypeEnumTypeWrapper):
    """番剧类型"""

VideoSubTypeNone: VideoSubType.ValueType  # 0
"""没有子类型"""
VideoSubTypeBangumi: VideoSubType.ValueType  # 1
"""番剧"""
VideoSubTypeMovie: VideoSubType.ValueType  # 2
"""电影"""
VideoSubTypeDocumentary: VideoSubType.ValueType  # 3
"""纪录片"""
VideoSubTypeDomestic: VideoSubType.ValueType  # 4
"""国创"""
VideoSubTypeTeleplay: VideoSubType.ValueType  # 5
"""电视剧"""
global___VideoSubType = VideoSubType

class _VideoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    video_type_general: _VideoType.ValueType  # 0
    """普通视频"""
    video_type_dynamic: _VideoType.ValueType  # 1
    """动态视频"""
    video_type_playback: _VideoType.ValueType  # 2
    """直播回放视频"""
    video_type_story: _VideoType.ValueType  # 3
    """"""

class VideoType(_VideoType, metaclass=_VideoTypeEnumTypeWrapper):
    """视频类型"""

video_type_general: VideoType.ValueType  # 0
"""普通视频"""
video_type_dynamic: VideoType.ValueType  # 1
"""动态视频"""
video_type_playback: VideoType.ValueType  # 2
"""直播回放视频"""
video_type_story: VideoType.ValueType  # 3
""""""
global___VideoType = VideoType

class _VoteStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VoteStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VoteStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    normal: _VoteStatus.ValueType  # 0
    """正常"""
    anonymous: _VoteStatus.ValueType  # 1
    """匿名"""

class VoteStatus(_VoteStatus, metaclass=_VoteStatusEnumTypeWrapper):
    """状态"""

normal: VoteStatus.ValueType  # 0
"""正常"""
anonymous: VoteStatus.ValueType  # 1
"""匿名"""
global___VoteStatus = VoteStatus

class _WeightType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WeightTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WeightType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    weight_none: _WeightType.ValueType  # 0
    """默认 占位"""
    weight_dislike: _WeightType.ValueType  # 1
    """不感兴趣"""
    weight_jump: _WeightType.ValueType  # 2
    """跳链"""

class WeightType(_WeightType, metaclass=_WeightTypeEnumTypeWrapper):
    """枚举-提权类型"""

weight_none: WeightType.ValueType  # 0
"""默认 占位"""
weight_dislike: WeightType.ValueType  # 1
"""不感兴趣"""
weight_jump: WeightType.ValueType  # 2
"""跳链"""
global___WeightType = WeightType

class _WFItemType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WFItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WFItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATER_FLOW_TYPE_NONE: _WFItemType.ValueType  # 0
    WATER_FLOW_TYPE_ARCHIVE: _WFItemType.ValueType  # 1
    WATER_FLOW_TYPE_DYNAMIC: _WFItemType.ValueType  # 2

class WFItemType(_WFItemType, metaclass=_WFItemTypeEnumTypeWrapper):
    """"""

WATER_FLOW_TYPE_NONE: WFItemType.ValueType  # 0
WATER_FLOW_TYPE_ARCHIVE: WFItemType.ValueType  # 1
WATER_FLOW_TYPE_DYNAMIC: WFItemType.ValueType  # 2
global___WFItemType = WFItemType

@typing_extensions.final
class AdditionalActSkin(google.protobuf.message.Message):
    """活动皮肤"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SVGA_FIELD_NUMBER: builtins.int
    LAST_IMAGE_FIELD_NUMBER: builtins.int
    PLAY_TIMES_FIELD_NUMBER: builtins.int
    svga: builtins.str
    """动画SVGA资源"""
    last_image: builtins.str
    """动画SVGA最后一帧图片资源"""
    play_times: builtins.int
    """动画播放次数"""
    def __init__(
        self,
        *,
        svga: builtins.str = ...,
        last_image: builtins.str = ...,
        play_times: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_image", b"last_image", "play_times", b"play_times", "svga", b"svga"]) -> None: ...

global___AdditionalActSkin = AdditionalActSkin

@typing_extensions.final
class AdditionalButton(google.protobuf.message.Message):
    """动态-附加卡-按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    JUMP_STYLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    UNCHECK_FIELD_NUMBER: builtins.int
    CHECK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CLICK_TYPE_FIELD_NUMBER: builtins.int
    type: global___AddButtonType.ValueType
    """按钮类型"""
    @property
    def jump_style(self) -> global___AdditionalButtonStyle:
        """jump-跳转样式"""
    jump_url: builtins.str
    """jump-跳转链接"""
    @property
    def uncheck(self) -> global___AdditionalButtonStyle:
        """button-未点样式"""
    @property
    def check(self) -> global___AdditionalButtonStyle:
        """button-已点样式"""
    status: global___AdditionalButtonStatus.ValueType
    """button-当前状态"""
    click_type: global___AdditionalButtonClickType.ValueType
    """按钮点击样式"""
    def __init__(
        self,
        *,
        type: global___AddButtonType.ValueType = ...,
        jump_style: global___AdditionalButtonStyle | None = ...,
        jump_url: builtins.str = ...,
        uncheck: global___AdditionalButtonStyle | None = ...,
        check: global___AdditionalButtonStyle | None = ...,
        status: global___AdditionalButtonStatus.ValueType = ...,
        click_type: global___AdditionalButtonClickType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["check", b"check", "jump_style", b"jump_style", "uncheck", b"uncheck"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check", b"check", "click_type", b"click_type", "jump_style", b"jump_style", "jump_url", b"jump_url", "status", b"status", "type", b"type", "uncheck", b"uncheck"]) -> None: ...

global___AdditionalButton = AdditionalButton

@typing_extensions.final
class AdditionalButtonInteractive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POPUPS_FIELD_NUMBER: builtins.int
    CONFIRM_FIELD_NUMBER: builtins.int
    CANCEL_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    popups: builtins.str
    """是否弹窗"""
    confirm: builtins.str
    """弹窗确认文案"""
    cancel: builtins.str
    """弹窗取消文案"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        popups: builtins.str = ...,
        confirm: builtins.str = ...,
        cancel: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cancel", b"cancel", "confirm", b"confirm", "desc", b"desc", "popups", b"popups"]) -> None: ...

global___AdditionalButtonInteractive = AdditionalButtonInteractive

@typing_extensions.final
class AdditionalButtonShare(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    show: builtins.int
    """"""
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        show: builtins.int = ...,
        icon: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "show", b"show", "text", b"text"]) -> None: ...

global___AdditionalButtonShare = AdditionalButtonShare

@typing_extensions.final
class AdditionalButtonStyle(google.protobuf.message.Message):
    """动态-附加卡-按钮样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    INTERACTIVE_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    DISABLE_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    text: builtins.str
    """文案"""
    @property
    def interactive(self) -> global___AdditionalButtonInteractive:
        """按钮点击交互"""
    bg_style: global___AddButtonBgStyle.ValueType
    """当前按钮填充样式"""
    toast: builtins.str
    """toast文案, 当disable=1时有效"""
    disable: global___DisableState.ValueType
    """当前按钮样式,
    0:高亮 1:置灰(按钮不可点击)
    """
    @property
    def share(self) -> global___AdditionalButtonShare:
        """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        interactive: global___AdditionalButtonInteractive | None = ...,
        bg_style: global___AddButtonBgStyle.ValueType = ...,
        toast: builtins.str = ...,
        disable: global___DisableState.ValueType = ...,
        share: global___AdditionalButtonShare | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interactive", b"interactive", "share", b"share"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_style", b"bg_style", "disable", b"disable", "icon", b"icon", "interactive", b"interactive", "share", b"share", "text", b"text", "toast", b"toast"]) -> None: ...

global___AdditionalButtonStyle = AdditionalButtonStyle

@typing_extensions.final
class AdditionalPGC(google.protobuf.message.Message):
    """动态-附加卡-番剧卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    HEAD_ICON_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """头部说明文案"""
    title: builtins.str
    """标题"""
    image_url: builtins.str
    """展示图"""
    desc_text_1: builtins.str
    """描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    url: builtins.str
    """点击跳转链接"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    head_icon: builtins.str
    """头部icon"""
    style: global___ImageStyle.ValueType
    """style"""
    type: builtins.str
    """动态本身的类型 type"""
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        image_url: builtins.str = ...,
        desc_text_1: builtins.str = ...,
        desc_text_2: builtins.str = ...,
        url: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        head_icon: builtins.str = ...,
        style: global___ImageStyle.ValueType = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "head_icon", b"head_icon", "head_text", b"head_text", "image_url", b"image_url", "style", b"style", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...

global___AdditionalPGC = AdditionalPGC

@typing_extensions.final
class AdditionArticle(google.protobuf.message.Message):
    """动态-附加卡-专栏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DESC_TEXT_LEFT_FIELD_NUMBER: builtins.int
    DESC_TEXT_RIGHT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def cover(self) -> global___MdlDynDrawItem:
        """"""
    desc_text_left: builtins.str
    """"""
    desc_text_right: builtins.str
    """"""
    uri: builtins.str
    """"""
    card_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: global___MdlDynDrawItem | None = ...,
        desc_text_left: builtins.str = ...,
        desc_text_right: builtins.str = ...,
        uri: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cover", b"cover"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "cover", b"cover", "desc_text_left", b"desc_text_left", "desc_text_right", b"desc_text_right", "title", b"title", "uri", b"uri"]) -> None: ...

global___AdditionArticle = AdditionArticle

@typing_extensions.final
class AdditionCommon(google.protobuf.message.Message):
    """动态-附加卡-通用卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    HEAD_ICON_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """头部说明文案"""
    title: builtins.str
    """标题"""
    image_url: builtins.str
    """展示图"""
    desc_text_1: builtins.str
    """描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    url: builtins.str
    """点击跳转链接"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    head_icon: builtins.str
    """头部icon"""
    style: global___ImageStyle.ValueType
    """style"""
    type: builtins.str
    """动态本身的类型 type"""
    card_type: builtins.str
    """附加卡类型
    ogv manga
    """
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        image_url: builtins.str = ...,
        desc_text_1: builtins.str = ...,
        desc_text_2: builtins.str = ...,
        url: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        head_icon: builtins.str = ...,
        style: global___ImageStyle.ValueType = ...,
        type: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "card_type", b"card_type", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "head_icon", b"head_icon", "head_text", b"head_text", "image_url", b"image_url", "style", b"style", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...

global___AdditionCommon = AdditionCommon

@typing_extensions.final
class AdditionEsport(google.protobuf.message.Message):
    """动态-附加卡-电竞卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_FIELD_NUMBER: builtins.int
    ADDITION_ESPORT_MOBA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    style: global___EspaceStyle.ValueType
    """电竞类型"""
    @property
    def addition_esport_moba(self) -> global___AdditionEsportMoba:
        """moba类"""
    type: builtins.str
    """动态本身的类型 type"""
    card_type: builtins.str
    """附加卡类型
    ogv manga
    """
    def __init__(
        self,
        *,
        style: global___EspaceStyle.ValueType = ...,
        addition_esport_moba: global___AdditionEsportMoba | None = ...,
        type: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_esport_moba", b"addition_esport_moba", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_esport_moba", b"addition_esport_moba", "card_type", b"card_type", "item", b"item", "style", b"style", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["addition_esport_moba"] | None: ...

global___AdditionEsport = AdditionEsport

@typing_extensions.final
class AdditionEsportMoba(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-moba类"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    MATCH_TEAM_FIELD_NUMBER: builtins.int
    ADDITION_ESPORT_MOBA_STATUS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    HEAD_ICON_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """头部说明文案"""
    title: builtins.str
    """标题"""
    @property
    def match_team(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchTeam]:
        """战队列表"""
    @property
    def addition_esport_moba_status(self) -> global___AdditionEsportMobaStatus:
        """比赛信息"""
    uri: builtins.str
    """卡片跳转"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    sub_title: builtins.str
    """副标题"""
    type: builtins.str
    """动态本身的类型 type"""
    card_type: builtins.str
    """附加卡类型"""
    head_icon: builtins.str
    """附加卡图标"""
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        match_team: collections.abc.Iterable[global___MatchTeam] | None = ...,
        addition_esport_moba_status: global___AdditionEsportMobaStatus | None = ...,
        uri: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        sub_title: builtins.str = ...,
        type: builtins.str = ...,
        card_type: builtins.str = ...,
        head_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_esport_moba_status", b"addition_esport_moba_status", "button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_esport_moba_status", b"addition_esport_moba_status", "button", b"button", "card_type", b"card_type", "head_icon", b"head_icon", "head_text", b"head_text", "match_team", b"match_team", "sub_title", b"sub_title", "title", b"title", "type", b"type", "uri", b"uri"]) -> None: ...

global___AdditionEsportMoba = AdditionEsportMoba

@typing_extensions.final
class AdditionEsportMobaStatus(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-moba类-比赛信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITION_ESPORT_MOBA_STATUS_DESC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    NIGHT_COLOR_FIELD_NUMBER: builtins.int
    @property
    def addition_esport_moba_status_desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionEsportMobaStatusDesc]:
        """文案类"""
    title: builtins.str
    """比赛状态文案"""
    status: builtins.int
    """比赛状态状态"""
    color: builtins.str
    """日间色值"""
    night_color: builtins.str
    """夜间色值"""
    def __init__(
        self,
        *,
        addition_esport_moba_status_desc: collections.abc.Iterable[global___AdditionEsportMobaStatusDesc] | None = ...,
        title: builtins.str = ...,
        status: builtins.int = ...,
        color: builtins.str = ...,
        night_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_esport_moba_status_desc", b"addition_esport_moba_status_desc", "color", b"color", "night_color", b"night_color", "status", b"status", "title", b"title"]) -> None: ...

global___AdditionEsportMobaStatus = AdditionEsportMobaStatus

@typing_extensions.final
class AdditionEsportMobaStatusDesc(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-moba类-比赛信息-文案类"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    NIGHT_COLOR_FIELD_NUMBER: builtins.int
    title: builtins.str
    """文案"""
    color: builtins.str
    """日间色值"""
    night_color: builtins.str
    """夜间色值"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        color: builtins.str = ...,
        night_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "night_color", b"night_color", "title", b"title"]) -> None: ...

global___AdditionEsportMobaStatusDesc = AdditionEsportMobaStatusDesc

@typing_extensions.final
class AdditionGoods(google.protobuf.message.Message):
    """动态-附加卡-商品卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RCMD_DESC_FIELD_NUMBER: builtins.int
    GOODS_ITEMS_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    AD_MARK_ICON_FIELD_NUMBER: builtins.int
    rcmd_desc: builtins.str
    """推荐文案"""
    @property
    def goods_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GoodsItem]:
        """商品信息"""
    card_type: builtins.str
    """附加卡类型"""
    icon: builtins.str
    """头部icon"""
    uri: builtins.str
    """商品附加卡整卡跳转"""
    source_type: builtins.int
    """商品类型
    1:淘宝 2:会员购，注：实际是获取的goods_items里面的第一个source_type
    """
    jump_type: builtins.int
    """"""
    app_name: builtins.str
    """"""
    ad_mark_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        rcmd_desc: builtins.str = ...,
        goods_items: collections.abc.Iterable[global___GoodsItem] | None = ...,
        card_type: builtins.str = ...,
        icon: builtins.str = ...,
        uri: builtins.str = ...,
        source_type: builtins.int = ...,
        jump_type: builtins.int = ...,
        app_name: builtins.str = ...,
        ad_mark_icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_mark_icon", b"ad_mark_icon", "app_name", b"app_name", "card_type", b"card_type", "goods_items", b"goods_items", "icon", b"icon", "jump_type", b"jump_type", "rcmd_desc", b"rcmd_desc", "source_type", b"source_type", "uri", b"uri"]) -> None: ...

global___AdditionGoods = AdditionGoods

@typing_extensions.final
class AdditionLiveRoom(google.protobuf.message.Message):
    """动态-附加卡-直播附加卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    DESC_TEXT_UPPER_FIELD_NUMBER: builtins.int
    DESC_TEXT_LOWER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def badge(self) -> global___VideoBadge:
        """"""
    @property
    def desc_text_upper(self) -> global___CoverIconWithText:
        """"""
    desc_text_lower: builtins.str
    """"""
    uri: builtins.str
    """"""
    card_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        desc_text_upper: global___CoverIconWithText | None = ...,
        desc_text_lower: builtins.str = ...,
        uri: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge", "desc_text_upper", b"desc_text_upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "card_type", b"card_type", "cover", b"cover", "desc_text_lower", b"desc_text_lower", "desc_text_upper", b"desc_text_upper", "title", b"title", "uri", b"uri"]) -> None: ...

global___AdditionLiveRoom = AdditionLiveRoom

@typing_extensions.final
class AdditionUgc(google.protobuf.message.Message):
    """动态-附加卡-UGC视频附加卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEAD_TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    LINE_FEED_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    head_text: builtins.str
    """说明文案"""
    title: builtins.str
    """稿件标题"""
    cover: builtins.str
    """封面"""
    desc_text_1: builtins.str
    """描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    uri: builtins.str
    """接秒开"""
    duration: builtins.str
    """时长"""
    line_feed: builtins.bool
    """标题支持换行-标题支持单行和双行，本期不支持填充up昵称，支持双行展示，字段默认为true"""
    card_type: builtins.str
    """附加卡类型"""
    def __init__(
        self,
        *,
        head_text: builtins.str = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        desc_text_1: builtins.str = ...,
        desc_text_2: builtins.str = ...,
        uri: builtins.str = ...,
        duration: builtins.str = ...,
        line_feed: builtins.bool = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "cover", b"cover", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "duration", b"duration", "head_text", b"head_text", "line_feed", b"line_feed", "title", b"title", "uri", b"uri"]) -> None: ...

global___AdditionUgc = AdditionUgc

@typing_extensions.final
class AdditionUP(google.protobuf.message.Message):
    """up主预约发布卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_TOTAL_FIELD_NUMBER: builtins.int
    ACT_SKIN_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    LOTTERY_TYPE_FIELD_NUMBER: builtins.int
    DESC_TEXT3_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    USER_INFO_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    SHOW_TEXT2_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    BUSINESS_ID_FIELD_NUMBER: builtins.int
    BADGE_TEXT_FIELD_NUMBER: builtins.int
    IS_PREMIERE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    @property
    def desc_text_1(self) -> global___HighlightText:
        """高亮文本，描述文字1"""
    desc_text_2: builtins.str
    """描述文字2"""
    url: builtins.str
    """点击跳转链接"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    card_type: builtins.str
    """附加卡类型"""
    reserve_total: builtins.int
    """预约人数(用于预约人数变化)"""
    @property
    def act_skin(self) -> global___AdditionalActSkin:
        """活动皮肤"""
    rid: builtins.int
    """预约id"""
    lottery_type: builtins.int
    """"""
    @property
    def desc_text3(self) -> global___HighlightText:
        """"""
    up_mid: builtins.int
    """"""
    @property
    def user_info(self) -> global___AdditionUserInfo:
        """"""
    dynamic_id: builtins.str
    """"""
    show_text2: builtins.bool
    """"""
    dyn_type: builtins.int
    """"""
    business_id: builtins.str
    """"""
    badge_text: builtins.str
    """"""
    is_premiere: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc_text_1: global___HighlightText | None = ...,
        desc_text_2: builtins.str = ...,
        url: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        card_type: builtins.str = ...,
        reserve_total: builtins.int = ...,
        act_skin: global___AdditionalActSkin | None = ...,
        rid: builtins.int = ...,
        lottery_type: builtins.int = ...,
        desc_text3: global___HighlightText | None = ...,
        up_mid: builtins.int = ...,
        user_info: global___AdditionUserInfo | None = ...,
        dynamic_id: builtins.str = ...,
        show_text2: builtins.bool = ...,
        dyn_type: builtins.int = ...,
        business_id: builtins.str = ...,
        badge_text: builtins.str = ...,
        is_premiere: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["act_skin", b"act_skin", "button", b"button", "desc_text3", b"desc_text3", "desc_text_1", b"desc_text_1", "user_info", b"user_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_skin", b"act_skin", "badge_text", b"badge_text", "business_id", b"business_id", "button", b"button", "card_type", b"card_type", "desc_text3", b"desc_text3", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2", "dyn_type", b"dyn_type", "dynamic_id", b"dynamic_id", "is_premiere", b"is_premiere", "lottery_type", b"lottery_type", "reserve_total", b"reserve_total", "rid", b"rid", "show_text2", b"show_text2", "title", b"title", "up_mid", b"up_mid", "url", b"url", "user_info", b"user_info"]) -> None: ...

global___AdditionUP = AdditionUP

@typing_extensions.final
class AdditionUserInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    face: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        face: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "name", b"name"]) -> None: ...

global___AdditionUserInfo = AdditionUserInfo

@typing_extensions.final
class AdditionVote(google.protobuf.message.Message):
    """动态-附加卡-投票"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """封面图"""
    title: builtins.str
    """标题"""
    text_1: builtins.str
    """展示项1"""
    button_text: builtins.str
    """button文案"""
    url: builtins.str
    """点击跳转链接"""
    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        title: builtins.str = ...,
        text_1: builtins.str = ...,
        button_text: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text", b"button_text", "image_url", b"image_url", "text_1", b"text_1", "title", b"title", "url", b"url"]) -> None: ...

global___AdditionVote = AdditionVote

@typing_extensions.final
class AdditionVote2(google.protobuf.message.Message):
    """动态模块-投票"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITION_VOTE_TYPE_FIELD_NUMBER: builtins.int
    VOTE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    DEADLINE_FIELD_NUMBER: builtins.int
    OPEN_TEXT_FIELD_NUMBER: builtins.int
    CLOSE_TEXT_FIELD_NUMBER: builtins.int
    VOTED_TEXT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ADDITION_VOTE_WORD_FIELD_NUMBER: builtins.int
    ADDITION_VOTE_PIC_FIELD_NUMBER: builtins.int
    ADDITION_VOTE_DEFAULE_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    TIPS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    IS_VOTED_FIELD_NUMBER: builtins.int
    CHOICE_CNT_FIELD_NUMBER: builtins.int
    DEFAULE_SELECT_SHARE_FIELD_NUMBER: builtins.int
    addition_vote_type: global___AdditionVoteType.ValueType
    """投票类型"""
    vote_id: builtins.int
    """投票ID"""
    title: builtins.str
    """标题"""
    label: builtins.str
    """已过期： xxx人参与· 投票已过期。button 展示去查看
    未过期： xxx人参与· 剩xx天xx时xx分。button展示去投票
    """
    deadline: builtins.int
    """剩余时间"""
    open_text: builtins.str
    """生效文案"""
    close_text: builtins.str
    """过期文案"""
    voted_text: builtins.str
    """已投票"""
    state: global___AdditionVoteState.ValueType
    """投票状态"""
    @property
    def addition_vote_word(self) -> global___AdditionVoteWord:
        """"""
    @property
    def addition_vote_pic(self) -> global___AdditionVotePic:
        """"""
    @property
    def addition_vote_defaule(self) -> global___AdditionVoteDefaule:
        """"""
    biz_type: builtins.int
    """业务类型
    0:动态投票 1:话题h5组件
    """
    total: builtins.int
    """投票总人数"""
    card_type: builtins.str
    """附加卡类型"""
    tips: builtins.str
    """异常提示"""
    uri: builtins.str
    """跳转地址"""
    is_voted: builtins.bool
    """是否投票"""
    choice_cnt: builtins.int
    """投票最多多选个数，单选为1"""
    defaule_select_share: builtins.bool
    """是否默认选中分享到动态"""
    def __init__(
        self,
        *,
        addition_vote_type: global___AdditionVoteType.ValueType = ...,
        vote_id: builtins.int = ...,
        title: builtins.str = ...,
        label: builtins.str = ...,
        deadline: builtins.int = ...,
        open_text: builtins.str = ...,
        close_text: builtins.str = ...,
        voted_text: builtins.str = ...,
        state: global___AdditionVoteState.ValueType = ...,
        addition_vote_word: global___AdditionVoteWord | None = ...,
        addition_vote_pic: global___AdditionVotePic | None = ...,
        addition_vote_defaule: global___AdditionVoteDefaule | None = ...,
        biz_type: builtins.int = ...,
        total: builtins.int = ...,
        card_type: builtins.str = ...,
        tips: builtins.str = ...,
        uri: builtins.str = ...,
        is_voted: builtins.bool = ...,
        choice_cnt: builtins.int = ...,
        defaule_select_share: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_vote_defaule", b"addition_vote_defaule", "addition_vote_pic", b"addition_vote_pic", "addition_vote_word", b"addition_vote_word", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_vote_defaule", b"addition_vote_defaule", "addition_vote_pic", b"addition_vote_pic", "addition_vote_type", b"addition_vote_type", "addition_vote_word", b"addition_vote_word", "biz_type", b"biz_type", "card_type", b"card_type", "choice_cnt", b"choice_cnt", "close_text", b"close_text", "deadline", b"deadline", "defaule_select_share", b"defaule_select_share", "is_voted", b"is_voted", "item", b"item", "label", b"label", "open_text", b"open_text", "state", b"state", "tips", b"tips", "title", b"title", "total", b"total", "uri", b"uri", "vote_id", b"vote_id", "voted_text", b"voted_text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["addition_vote_word", "addition_vote_pic", "addition_vote_defaule"] | None: ...

global___AdditionVote2 = AdditionVote2

@typing_extensions.final
class AdditionVoteDefaule(google.protobuf.message.Message):
    """外露投票"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    @property
    def cover(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """图片 多张"""
    def __init__(
        self,
        *,
        cover: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover"]) -> None: ...

global___AdditionVoteDefaule = AdditionVoteDefaule

@typing_extensions.final
class AdditionVotePic(google.protobuf.message.Message):
    """外露图片类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionVotePicItem]:
        """图片投票详情"""
    def __init__(
        self,
        *,
        item: collections.abc.Iterable[global___AdditionVotePicItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___AdditionVotePic = AdditionVotePic

@typing_extensions.final
class AdditionVotePicItem(google.protobuf.message.Message):
    """图片投票详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPT_IDX_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    IS_VOTE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    PERSENT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IS_MAX_OPTION_FIELD_NUMBER: builtins.int
    opt_idx: builtins.int
    """选项索引，从1开始"""
    cover: builtins.str
    """图片"""
    is_vote: builtins.bool
    """选中状态"""
    total: builtins.int
    """人数"""
    persent: builtins.float
    """占比"""
    title: builtins.str
    """标题文案"""
    is_max_option: builtins.bool
    """是否投票人数最多的选项"""
    def __init__(
        self,
        *,
        opt_idx: builtins.int = ...,
        cover: builtins.str = ...,
        is_vote: builtins.bool = ...,
        total: builtins.int = ...,
        persent: builtins.float = ...,
        title: builtins.str = ...,
        is_max_option: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "is_max_option", b"is_max_option", "is_vote", b"is_vote", "opt_idx", b"opt_idx", "persent", b"persent", "title", b"title", "total", b"total"]) -> None: ...

global___AdditionVotePicItem = AdditionVotePicItem

@typing_extensions.final
class AdditionVoteWord(google.protobuf.message.Message):
    """外露文字类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionVoteWordItem]:
        """外露文字投票详情"""
    def __init__(
        self,
        *,
        item: collections.abc.Iterable[global___AdditionVoteWordItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___AdditionVoteWord = AdditionVoteWord

@typing_extensions.final
class AdditionVoteWordItem(google.protobuf.message.Message):
    """外露文字投票详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPT_IDX_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    IS_VOTE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    PERSENT_FIELD_NUMBER: builtins.int
    IS_MAX_OPTION_FIELD_NUMBER: builtins.int
    opt_idx: builtins.int
    """选项索引，从1开始"""
    title: builtins.str
    """文案"""
    is_vote: builtins.bool
    """选中状态"""
    total: builtins.int
    """人数"""
    persent: builtins.float
    """占比"""
    is_max_option: builtins.bool
    """是否投票人数最多的选项"""
    def __init__(
        self,
        *,
        opt_idx: builtins.int = ...,
        title: builtins.str = ...,
        is_vote: builtins.bool = ...,
        total: builtins.int = ...,
        persent: builtins.float = ...,
        is_max_option: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_max_option", b"is_max_option", "is_vote", b"is_vote", "opt_idx", b"opt_idx", "persent", b"persent", "title", b"title", "total", b"total"]) -> None: ...

global___AdditionVoteWordItem = AdditionVoteWordItem

@typing_extensions.final
class AdParam(google.protobuf.message.Message):
    """综合页请求广告所需字段，由客户端-网关透传"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AD_EXTRA_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    ad_extra: builtins.str
    """综合页请求广告所需字段，由客户端-网关透传"""
    request_id: builtins.str
    """request_id"""
    def __init__(
        self,
        *,
        ad_extra: builtins.str = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "request_id", b"request_id"]) -> None: ...

global___AdParam = AdParam

@typing_extensions.final
class AlumniDynamicsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "toast", b"toast"]) -> None: ...

global___AlumniDynamicsReply = AlumniDynamicsReply

@typing_extensions.final
class AlumniDynamicsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    FIRST_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    first_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    local_time: builtins.int
    """"""
    page: builtins.int
    """"""
    from_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        first_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        local_time: builtins.int = ...,
        page: builtins.int = ...,
        from_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "first_time", b"first_time", "from_type", b"from_type", "local_time", b"local_time", "page", b"page", "player_args", b"player_args"]) -> None: ...

global___AlumniDynamicsReq = AlumniDynamicsReq

@typing_extensions.final
class CampusBannerInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    image: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "jump_url", b"jump_url"]) -> None: ...

global___CampusBannerInfo = CampusBannerInfo

@typing_extensions.final
class CampusBillboardInternalReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    CAMPUS_ID_FIELD_NUMBER: builtins.int
    VERSION_CODE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    campus_id: builtins.int
    """"""
    version_code: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        campus_id: builtins.int = ...,
        version_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "mid", b"mid", "version_code", b"version_code"]) -> None: ...

global___CampusBillboardInternalReq = CampusBillboardInternalReq

@typing_extensions.final
class CampusBillBoardReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    HELP_URI_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    BUILD_TIME_FIELD_NUMBER: builtins.int
    VERSION_CODE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    SHARE_URI_FIELD_NUMBER: builtins.int
    BIND_NOTICE_FIELD_NUMBER: builtins.int
    UPDATE_TOAST_FIELD_NUMBER: builtins.int
    CAMPUS_ID_FIELD_NUMBER: builtins.int
    OPEN_PROGRESS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    help_uri: builtins.str
    """"""
    campus_name: builtins.str
    """"""
    build_time: builtins.int
    """"""
    version_code: builtins.str
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OfficialItem]:
        """"""
    share_uri: builtins.str
    """"""
    bind_notice: builtins.int
    """"""
    update_toast: builtins.str
    """"""
    campus_id: builtins.int
    """"""
    @property
    def open_progress(self) -> global___CampusFeatureProgress:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        help_uri: builtins.str = ...,
        campus_name: builtins.str = ...,
        build_time: builtins.int = ...,
        version_code: builtins.str = ...,
        list: collections.abc.Iterable[global___OfficialItem] | None = ...,
        share_uri: builtins.str = ...,
        bind_notice: builtins.int = ...,
        update_toast: builtins.str = ...,
        campus_id: builtins.int = ...,
        open_progress: global___CampusFeatureProgress | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["open_progress", b"open_progress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bind_notice", b"bind_notice", "build_time", b"build_time", "campus_id", b"campus_id", "campus_name", b"campus_name", "help_uri", b"help_uri", "list", b"list", "open_progress", b"open_progress", "share_uri", b"share_uri", "title", b"title", "update_toast", b"update_toast", "version_code", b"version_code"]) -> None: ...

global___CampusBillBoardReply = CampusBillBoardReply

@typing_extensions.final
class CampusBillBoardReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    VERSION_CODE_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    version_code: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        version_code: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "from_type", b"from_type", "player_args", b"player_args", "version_code", b"version_code"]) -> None: ...

global___CampusBillBoardReq = CampusBillBoardReq

@typing_extensions.final
class CampusEntryTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id"]) -> None: ...

global___CampusEntryTabReq = CampusEntryTabReq

@typing_extensions.final
class CampusEntryTabResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRY_TYPE_FIELD_NUMBER: builtins.int
    entry_type: global___CampusEntryType.ValueType
    """"""
    def __init__(
        self,
        *,
        entry_type: global___CampusEntryType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entry_type", b"entry_type"]) -> None: ...

global___CampusEntryTabResp = CampusEntryTabResp

@typing_extensions.final
class CampusFeatureProgress(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_FULL_FIELD_NUMBER: builtins.int
    PROGRESS_ACHIEVED_FIELD_NUMBER: builtins.int
    DESC_TITLE_FIELD_NUMBER: builtins.int
    DESC_1_FIELD_NUMBER: builtins.int
    BTN_FIELD_NUMBER: builtins.int
    progress_full: builtins.int
    """"""
    progress_achieved: builtins.int
    """"""
    desc_title: builtins.str
    """"""
    desc_1: builtins.str
    """"""
    @property
    def btn(self) -> global___CampusLabel:
        """"""
    def __init__(
        self,
        *,
        progress_full: builtins.int = ...,
        progress_achieved: builtins.int = ...,
        desc_title: builtins.str = ...,
        desc_1: builtins.str = ...,
        btn: global___CampusLabel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["btn", b"btn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["btn", b"btn", "desc_1", b"desc_1", "desc_title", b"desc_title", "progress_achieved", b"progress_achieved", "progress_full", b"progress_full"]) -> None: ...

global___CampusFeatureProgress = CampusFeatureProgress

@typing_extensions.final
class CampusFeedbackInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    CAMPUS_ID_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    biz_type: builtins.int
    """"""
    biz_id: builtins.int
    """"""
    campus_id: builtins.int
    """"""
    reason: builtins.str
    """"""
    def __init__(
        self,
        *,
        biz_type: builtins.int = ...,
        biz_id: builtins.int = ...,
        campus_id: builtins.int = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "campus_id", b"campus_id", "reason", b"reason"]) -> None: ...

global___CampusFeedbackInfo = CampusFeedbackInfo

@typing_extensions.final
class CampusFeedbackReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___CampusFeedbackReply = CampusFeedbackReply

@typing_extensions.final
class CampusFeedbackReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFOS_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    @property
    def infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusFeedbackInfo]:
        """"""
    def __init__(
        self,
        *,
        infos: collections.abc.Iterable[global___CampusFeedbackInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "infos", b"infos"]) -> None: ...

global___CampusFeedbackReq = CampusFeedbackReq

@typing_extensions.final
class CampusHomePagesReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_FIELD_NUMBER: builtins.int
    CAMPUS_TOP_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def top(self) -> global___CampusRcmdTop:
        """"""
    @property
    def campus_top(self) -> global___CampusTop:
        """"""
    page_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        top: global___CampusRcmdTop | None = ...,
        campus_top: global___CampusTop | None = ...,
        page_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["campus_top", b"campus_top", "top", b"top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_top", b"campus_top", "page_type", b"page_type", "top", b"top"]) -> None: ...

global___CampusHomePagesReply = CampusHomePagesReply

@typing_extensions.final
class CampusHomePagesReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    lat: builtins.float
    """"""
    lng: builtins.float
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    page_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        page_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "lat", b"lat", "lng", b"lng", "page_type", b"page_type", "player_args", b"player_args"]) -> None: ...

global___CampusHomePagesReq = CampusHomePagesReq

@typing_extensions.final
class CampusHomeRcmdTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> global___ModuleTitle:
        """"""
    @property
    def topic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicItem]:
        """"""
    def __init__(
        self,
        *,
        title: global___ModuleTitle | None = ...,
        topic: collections.abc.Iterable[global___TopicItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "topic", b"topic"]) -> None: ...

global___CampusHomeRcmdTopic = CampusHomeRcmdTopic

@typing_extensions.final
class CampusInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    desc: builtins.str
    """"""
    online: builtins.int
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        desc: builtins.str = ...,
        online: builtins.int = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "desc", b"desc", "online", b"online", "url", b"url"]) -> None: ...

global___CampusInfo = CampusInfo

@typing_extensions.final
class CampusLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "text", b"text", "url", b"url"]) -> None: ...

global___CampusLabel = CampusLabel

@typing_extensions.final
class CampusMateLikeListReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleAuthor]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___ModuleAuthor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___CampusMateLikeListReply = CampusMateLikeListReply

@typing_extensions.final
class CampusMateLikeListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    dynamic_id: builtins.int
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        dynamic_id: builtins.int = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_id", b"dynamic_id", "from_type", b"from_type"]) -> None: ...

global___CampusMateLikeListReq = CampusMateLikeListReq

@typing_extensions.final
class CampusMngBadge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    BADGE_URL_FIELD_NUMBER: builtins.int
    UPLOAD_HINT_MSG_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    badge_url: builtins.str
    """"""
    upload_hint_msg: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        badge_url: builtins.str = ...,
        upload_hint_msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge_url", b"badge_url", "title", b"title", "upload_hint_msg", b"upload_hint_msg"]) -> None: ...

global___CampusMngBadge = CampusMngBadge

@typing_extensions.final
class CampusMngBasicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    HINT_MSG_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    hint_msg: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        hint_msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "hint_msg", b"hint_msg"]) -> None: ...

global___CampusMngBasicInfo = CampusMngBasicInfo

@typing_extensions.final
class CampusMngDetailReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    TOP_HINT_BAR_MSG_FIELD_NUMBER: builtins.int
    BOTTOM_SUBMIT_HINT_MSG_FIELD_NUMBER: builtins.int
    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusMngItem]:
        """"""
    top_hint_bar_msg: builtins.str
    """"""
    bottom_submit_hint_msg: builtins.str
    """"""
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CampusMngItem] | None = ...,
        top_hint_bar_msg: builtins.str = ...,
        bottom_submit_hint_msg: builtins.str = ...,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_submit_hint_msg", b"bottom_submit_hint_msg", "campus_id", b"campus_id", "campus_name", b"campus_name", "items", b"items", "top_hint_bar_msg", b"top_hint_bar_msg"]) -> None: ...

global___CampusMngDetailReply = CampusMngDetailReply

@typing_extensions.final
class CampusMngDetailReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id"]) -> None: ...

global___CampusMngDetailReq = CampusMngDetailReq

@typing_extensions.final
class CampusMngItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIT_STATUS_FIELD_NUMBER: builtins.int
    AUDIT_MESSAGE_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    MNG_ITEM_ID_FIELD_NUMBER: builtins.int
    IS_DEL_FIELD_NUMBER: builtins.int
    BASIC_INFO_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    SLOGAN_FIELD_NUMBER: builtins.int
    QUIZ_FIELD_NUMBER: builtins.int
    audit_status: builtins.int
    """"""
    audit_message: builtins.str
    """"""
    item_type: builtins.int
    """"""
    mng_item_id: builtins.str
    """"""
    is_del: builtins.bool
    """"""
    @property
    def basic_info(self) -> global___CampusMngBasicInfo:
        """"""
    @property
    def badge(self) -> global___CampusMngBadge:
        """"""
    slogan: builtins.str
    """"""
    @property
    def quiz(self) -> global___CampusMngQuiz:
        """"""
    def __init__(
        self,
        *,
        audit_status: builtins.int = ...,
        audit_message: builtins.str = ...,
        item_type: builtins.int = ...,
        mng_item_id: builtins.str = ...,
        is_del: builtins.bool = ...,
        basic_info: global___CampusMngBasicInfo | None = ...,
        badge: global___CampusMngBadge | None = ...,
        slogan: builtins.str = ...,
        quiz: global___CampusMngQuiz | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge", "basic_info", b"basic_info", "item", b"item", "quiz", b"quiz", "slogan", b"slogan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_message", b"audit_message", "audit_status", b"audit_status", "badge", b"badge", "basic_info", b"basic_info", "is_del", b"is_del", "item", b"item", "item_type", b"item_type", "mng_item_id", b"mng_item_id", "quiz", b"quiz", "slogan", b"slogan"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["basic_info", "badge", "slogan", "quiz"] | None: ...

global___CampusMngItem = CampusMngItem

@typing_extensions.final
class CampusMngQuiz(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    MORE_LABEL_FIELD_NUMBER: builtins.int
    ADD_LABEL_FIELD_NUMBER: builtins.int
    SUBMIT_LABEL_FIELD_NUMBER: builtins.int
    QUIZ_COUNT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def more_label(self) -> global___CampusLabel:
        """"""
    add_label: builtins.str
    """"""
    submit_label: builtins.str
    """"""
    quiz_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        more_label: global___CampusLabel | None = ...,
        add_label: builtins.str = ...,
        submit_label: builtins.str = ...,
        quiz_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["more_label", b"more_label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["add_label", b"add_label", "more_label", b"more_label", "quiz_count", b"quiz_count", "submit_label", b"submit_label", "title", b"title"]) -> None: ...

global___CampusMngQuiz = CampusMngQuiz

@typing_extensions.final
class CampusMngQuizDetail(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUIZ_ID_FIELD_NUMBER: builtins.int
    QUESTION_FIELD_NUMBER: builtins.int
    CORRECT_ANSWER_FIELD_NUMBER: builtins.int
    WRONG_ANSWER_LIST_FIELD_NUMBER: builtins.int
    AUDIT_STATUS_FIELD_NUMBER: builtins.int
    AUDIT_MESSAGE_FIELD_NUMBER: builtins.int
    quiz_id: builtins.int
    """"""
    question: builtins.str
    """"""
    correct_answer: builtins.str
    """"""
    @property
    def wrong_answer_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    audit_status: builtins.int
    """"""
    audit_message: builtins.str
    """"""
    def __init__(
        self,
        *,
        quiz_id: builtins.int = ...,
        question: builtins.str = ...,
        correct_answer: builtins.str = ...,
        wrong_answer_list: collections.abc.Iterable[builtins.str] | None = ...,
        audit_status: builtins.int = ...,
        audit_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_message", b"audit_message", "audit_status", b"audit_status", "correct_answer", b"correct_answer", "question", b"question", "quiz_id", b"quiz_id", "wrong_answer_list", b"wrong_answer_list"]) -> None: ...

global___CampusMngQuizDetail = CampusMngQuizDetail

@typing_extensions.final
class CampusMngQuizOperateReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOAST_FIELD_NUMBER: builtins.int
    QUIZ_FIELD_NUMBER: builtins.int
    QUIZ_TOTAL_FIELD_NUMBER: builtins.int
    toast: builtins.str
    """"""
    @property
    def quiz(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusMngQuizDetail]:
        """"""
    quiz_total: builtins.int
    """"""
    def __init__(
        self,
        *,
        toast: builtins.str = ...,
        quiz: collections.abc.Iterable[global___CampusMngQuizDetail] | None = ...,
        quiz_total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["quiz", b"quiz", "quiz_total", b"quiz_total", "toast", b"toast"]) -> None: ...

global___CampusMngQuizOperateReply = CampusMngQuizOperateReply

@typing_extensions.final
class CampusMngQuizOperateReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    CAMPUS_ID_FIELD_NUMBER: builtins.int
    QUIZ_FIELD_NUMBER: builtins.int
    action: builtins.int
    """"""
    campus_id: builtins.int
    """"""
    @property
    def quiz(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusMngQuizDetail]:
        """"""
    def __init__(
        self,
        *,
        action: builtins.int = ...,
        campus_id: builtins.int = ...,
        quiz: collections.abc.Iterable[global___CampusMngQuizDetail] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "campus_id", b"campus_id", "quiz", b"quiz"]) -> None: ...

global___CampusMngQuizOperateReq = CampusMngQuizOperateReq

@typing_extensions.final
class CampusMngSlogan(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SLOGAN_FIELD_NUMBER: builtins.int
    INPUT_HINT_MSG_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    slogan: builtins.str
    """"""
    input_hint_msg: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        slogan: builtins.str = ...,
        input_hint_msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_hint_msg", b"input_hint_msg", "slogan", b"slogan", "title", b"title"]) -> None: ...

global___CampusMngSlogan = CampusMngSlogan

@typing_extensions.final
class CampusMngSubmitReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOAST_FIELD_NUMBER: builtins.int
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["toast", b"toast"]) -> None: ...

global___CampusMngSubmitReply = CampusMngSubmitReply

@typing_extensions.final
class CampusMngSubmitReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    MODIFIED_ITEMS_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    @property
    def modified_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusMngItem]:
        """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        modified_items: collections.abc.Iterable[global___CampusMngItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "modified_items", b"modified_items"]) -> None: ...

global___CampusMngSubmitReq = CampusMngSubmitReq

@typing_extensions.final
class CampusNoticeInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    @property
    def button(self) -> global___CampusLabel:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        button: global___CampusLabel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "desc", b"desc", "title", b"title"]) -> None: ...

global___CampusNoticeInfo = CampusNoticeInfo

@typing_extensions.final
class CampusRcmdFeedReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    GUIDE_BAR_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    toast: builtins.str
    """"""
    @property
    def guide_bar(self) -> global___GuideBarInfo:
        """"""
    has_more: builtins.bool
    """"""
    update: builtins.bool
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        toast: builtins.str = ...,
        guide_bar: global___GuideBarInfo | None = ...,
        has_more: builtins.bool = ...,
        update: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["guide_bar", b"guide_bar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["guide_bar", b"guide_bar", "has_more", b"has_more", "list", b"list", "toast", b"toast", "update", b"update"]) -> None: ...

global___CampusRcmdFeedReply = CampusRcmdFeedReply

@typing_extensions.final
class CampusRcmdFeedReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    FIRST_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    SCROLL_FIELD_NUMBER: builtins.int
    VIEW_DYN_ID_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    first_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    local_time: builtins.int
    """"""
    page: builtins.int
    """"""
    scroll: builtins.int
    """"""
    view_dyn_id: builtins.str
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        first_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        local_time: builtins.int = ...,
        page: builtins.int = ...,
        scroll: builtins.int = ...,
        view_dyn_id: builtins.str = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "first_time", b"first_time", "from_type", b"from_type", "local_time", b"local_time", "page", b"page", "player_args", b"player_args", "scroll", b"scroll", "view_dyn_id", b"view_dyn_id"]) -> None: ...

global___CampusRcmdFeedReq = CampusRcmdFeedReq

@typing_extensions.final
class CampusRcmdInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusRcmdItem]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        items: collections.abc.Iterable[global___CampusRcmdItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "title", b"title"]) -> None: ...

global___CampusRcmdInfo = CampusRcmdInfo

@typing_extensions.final
class CampusRcmdItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    CAMPUS_ID_FIELD_NUMBER: builtins.int
    ENTRY_LABEL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RcmdItem]:
        """"""
    campus_id: builtins.int
    """"""
    @property
    def entry_label(self) -> global___CampusLabel:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        items: collections.abc.Iterable[global___RcmdItem] | None = ...,
        campus_id: builtins.int = ...,
        entry_label: global___CampusLabel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entry_label", b"entry_label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "entry_label", b"entry_label", "items", b"items", "title", b"title"]) -> None: ...

global___CampusRcmdItem = CampusRcmdItem

@typing_extensions.final
class CampusRcmdReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_FIELD_NUMBER: builtins.int
    RCMD_FIELD_NUMBER: builtins.int
    CAMPUS_TOP_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    JUMP_HOME_POP_FIELD_NUMBER: builtins.int
    @property
    def top(self) -> global___CampusRcmdTop:
        """"""
    @property
    def rcmd(self) -> global___CampusRcmdInfo:
        """"""
    @property
    def campus_top(self) -> global___CampusTop:
        """"""
    page_type: builtins.int
    """"""
    jump_home_pop: builtins.int
    """"""
    def __init__(
        self,
        *,
        top: global___CampusRcmdTop | None = ...,
        rcmd: global___CampusRcmdInfo | None = ...,
        campus_top: global___CampusTop | None = ...,
        page_type: builtins.int = ...,
        jump_home_pop: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["campus_top", b"campus_top", "rcmd", b"rcmd", "top", b"top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_top", b"campus_top", "jump_home_pop", b"jump_home_pop", "page_type", b"page_type", "rcmd", b"rcmd", "top", b"top"]) -> None: ...

global___CampusRcmdReply = CampusRcmdReply

@typing_extensions.final
class CampusRcmdReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    lat: builtins.float
    """"""
    lng: builtins.float
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    page_type: global___CampusHomePageType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
        page_type: global___CampusHomePageType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "from_type", b"from_type", "lat", b"lat", "lng", b"lng", "page_type", b"page_type", "player_args", b"player_args"]) -> None: ...

global___CampusRcmdReq = CampusRcmdReq

@typing_extensions.final
class CampusRcmdTop(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    SWITCH_LABEL_FIELD_NUMBER: builtins.int
    NOTICE_LABEL_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    DESC3_FIELD_NUMBER: builtins.int
    INVITE_LABEL_FIELD_NUMBER: builtins.int
    RESERVE_LABEL_FIELD_NUMBER: builtins.int
    RESERVE_NUMBER_FIELD_NUMBER: builtins.int
    MAX_RESERVE_FIELD_NUMBER: builtins.int
    SCHOOL_LABEL_FIELD_NUMBER: builtins.int
    MNG_LABEL_FIELD_NUMBER: builtins.int
    RCMD_TOPIC_FIELD_NUMBER: builtins.int
    AUDIT_BEFORE_OPEN_FIELD_NUMBER: builtins.int
    AUDIT_MESSAGE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    type: builtins.int
    """"""
    @property
    def button(self) -> global___RcmdTopButton:
        """"""
    @property
    def switch_label(self) -> global___CampusLabel:
        """"""
    @property
    def notice_label(self) -> global___CampusLabel:
        """"""
    desc2: builtins.str
    """"""
    desc3: builtins.str
    """"""
    @property
    def invite_label(self) -> global___CampusLabel:
        """"""
    @property
    def reserve_label(self) -> global___CampusLabel:
        """"""
    reserve_number: builtins.int
    """"""
    max_reserve: builtins.int
    """"""
    @property
    def school_label(self) -> global___CampusLabel:
        """"""
    @property
    def mng_label(self) -> global___CampusLabel:
        """"""
    @property
    def rcmd_topic(self) -> global___CampusHomeRcmdTopic:
        """"""
    audit_before_open: builtins.bool
    """"""
    audit_message: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        type: builtins.int = ...,
        button: global___RcmdTopButton | None = ...,
        switch_label: global___CampusLabel | None = ...,
        notice_label: global___CampusLabel | None = ...,
        desc2: builtins.str = ...,
        desc3: builtins.str = ...,
        invite_label: global___CampusLabel | None = ...,
        reserve_label: global___CampusLabel | None = ...,
        reserve_number: builtins.int = ...,
        max_reserve: builtins.int = ...,
        school_label: global___CampusLabel | None = ...,
        mng_label: global___CampusLabel | None = ...,
        rcmd_topic: global___CampusHomeRcmdTopic | None = ...,
        audit_before_open: builtins.bool = ...,
        audit_message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "invite_label", b"invite_label", "mng_label", b"mng_label", "notice_label", b"notice_label", "rcmd_topic", b"rcmd_topic", "reserve_label", b"reserve_label", "school_label", b"school_label", "switch_label", b"switch_label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_before_open", b"audit_before_open", "audit_message", b"audit_message", "button", b"button", "campus_id", b"campus_id", "campus_name", b"campus_name", "desc", b"desc", "desc2", b"desc2", "desc3", b"desc3", "invite_label", b"invite_label", "max_reserve", b"max_reserve", "mng_label", b"mng_label", "notice_label", b"notice_label", "rcmd_topic", b"rcmd_topic", "reserve_label", b"reserve_label", "reserve_number", b"reserve_number", "school_label", b"school_label", "switch_label", b"switch_label", "title", b"title", "type", b"type"]) -> None: ...

global___CampusRcmdTop = CampusRcmdTop

@typing_extensions.final
class CampusRecommendReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RcmdItem]:
        """"""
    has_more: builtins.bool
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___RcmdItem] | None = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "items", b"items"]) -> None: ...

global___CampusRecommendReply = CampusRecommendReply

@typing_extensions.final
class CampusRecommendReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    page_no: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        page_no: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "from", b"from", "page_no", b"page_no", "player_args", b"player_args"]) -> None: ...

global___CampusRecommendReq = CampusRecommendReq

@typing_extensions.final
class CampusRedDotReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RED_DOT_FIELD_NUMBER: builtins.int
    red_dot: builtins.int
    """"""
    def __init__(
        self,
        *,
        red_dot: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["red_dot", b"red_dot"]) -> None: ...

global___CampusRedDotReply = CampusRedDotReply

@typing_extensions.final
class CampusRedDotReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "from_type", b"from_type"]) -> None: ...

global___CampusRedDotReq = CampusRedDotReq

@typing_extensions.final
class CampusShowTabInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RED_DOT_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    url: builtins.str
    """"""
    type: builtins.int
    """"""
    red_dot: builtins.int
    """"""
    icon_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        url: builtins.str = ...,
        type: builtins.int = ...,
        red_dot: builtins.int = ...,
        icon_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_url", b"icon_url", "name", b"name", "red_dot", b"red_dot", "type", b"type", "url", b"url"]) -> None: ...

global___CampusShowTabInfo = CampusShowTabInfo

@typing_extensions.final
class CampusSquareReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RcmdCampusBrief]:
        """"""
    @property
    def button(self) -> global___CampusLabel:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___RcmdCampusBrief] | None = ...,
        button: global___CampusLabel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "list", b"list", "title", b"title"]) -> None: ...

global___CampusSquareReply = CampusSquareReply

@typing_extensions.final
class CampusSquareReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    lat: builtins.float
    """"""
    lng: builtins.float
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "lat", b"lat", "lng", b"lng"]) -> None: ...

global___CampusSquareReq = CampusSquareReq

@typing_extensions.final
class CampusTop(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    TABS_FIELD_NUMBER: builtins.int
    SWITCH_LABEL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BANNER_FIELD_NUMBER: builtins.int
    INVITE_LABEL_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    TOPIC_SQUARE_FIELD_NUMBER: builtins.int
    CAMPUS_BADGE_FIELD_NUMBER: builtins.int
    CAMPUS_BACKGROUND_FIELD_NUMBER: builtins.int
    CAMPUS_MOTTO_FIELD_NUMBER: builtins.int
    MNG_ENTRY_FIELD_NUMBER: builtins.int
    CAMPUS_INTRO_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_LINK_FIELD_NUMBER: builtins.int
    BOTTOM_LEFT_TEXT_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    @property
    def tabs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusShowTabInfo]:
        """"""
    @property
    def switch_label(self) -> global___CampusLabel:
        """"""
    title: builtins.str
    """"""
    @property
    def banner(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusBannerInfo]:
        """"""
    @property
    def invite_label(self) -> global___CampusLabel:
        """"""
    @property
    def notice(self) -> global___CampusNoticeInfo:
        """"""
    @property
    def topic_square(self) -> global___TopicSquareInfo:
        """"""
    campus_badge: builtins.str
    """"""
    campus_background: builtins.str
    """"""
    campus_motto: builtins.str
    """"""
    @property
    def mng_entry(self) -> global___CampusLabel:
        """"""
    campus_intro: builtins.str
    """"""
    campus_name_link: builtins.str
    """"""
    bottom_left_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        tabs: collections.abc.Iterable[global___CampusShowTabInfo] | None = ...,
        switch_label: global___CampusLabel | None = ...,
        title: builtins.str = ...,
        banner: collections.abc.Iterable[global___CampusBannerInfo] | None = ...,
        invite_label: global___CampusLabel | None = ...,
        notice: global___CampusNoticeInfo | None = ...,
        topic_square: global___TopicSquareInfo | None = ...,
        campus_badge: builtins.str = ...,
        campus_background: builtins.str = ...,
        campus_motto: builtins.str = ...,
        mng_entry: global___CampusLabel | None = ...,
        campus_intro: builtins.str = ...,
        campus_name_link: builtins.str = ...,
        bottom_left_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["invite_label", b"invite_label", "mng_entry", b"mng_entry", "notice", b"notice", "switch_label", b"switch_label", "topic_square", b"topic_square"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["banner", b"banner", "bottom_left_text", b"bottom_left_text", "campus_background", b"campus_background", "campus_badge", b"campus_badge", "campus_id", b"campus_id", "campus_intro", b"campus_intro", "campus_motto", b"campus_motto", "campus_name", b"campus_name", "campus_name_link", b"campus_name_link", "invite_label", b"invite_label", "mng_entry", b"mng_entry", "notice", b"notice", "switch_label", b"switch_label", "tabs", b"tabs", "title", b"title", "topic_square", b"topic_square"]) -> None: ...

global___CampusTop = CampusTop

@typing_extensions.final
class CampusTopicRcmdFeedReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    JOIN_DISCUSS_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    toast: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    @property
    def join_discuss(self) -> global___IconButton:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        toast: builtins.str = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
        join_discuss: global___IconButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["join_discuss", b"join_discuss"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "join_discuss", b"join_discuss", "list", b"list", "offset", b"offset", "toast", b"toast"]) -> None: ...

global___CampusTopicRcmdFeedReply = CampusTopicRcmdFeedReply

@typing_extensions.final
class CampusTopicRcmdFeedReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    local_time: builtins.int
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        offset: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        local_time: builtins.int = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "from_type", b"from_type", "local_time", b"local_time", "offset", b"offset", "player_args", b"player_args"]) -> None: ...

global___CampusTopicRcmdFeedReq = CampusTopicRcmdFeedReq

@typing_extensions.final
class CardParagraph(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_CARD_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    @property
    def additional_card(self) -> global___ModuleAdditional:
        """"""
    biz_id: builtins.str
    """"""
    biz_type: global___LinkNodeType.ValueType
    """"""
    def __init__(
        self,
        *,
        additional_card: global___ModuleAdditional | None = ...,
        biz_id: builtins.str = ...,
        biz_type: global___LinkNodeType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_card", b"additional_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_card", b"additional_card", "biz_id", b"biz_id", "biz_type", b"biz_type"]) -> None: ...

global___CardParagraph = CardParagraph

@typing_extensions.final
class CardVideoDynList(google.protobuf.message.Message):
    """动态卡片列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    UPDATE_NUM_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    update_num: builtins.int
    """更新的动态数"""
    history_offset: builtins.str
    """历史偏移"""
    update_baseline: builtins.str
    """更新基础信息"""
    has_more: builtins.bool
    """是否还有更多数据"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        update_num: builtins.int = ...,
        history_offset: builtins.str = ...,
        update_baseline: builtins.str = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "history_offset", b"history_offset", "list", b"list", "update_baseline", b"update_baseline", "update_num", b"update_num"]) -> None: ...

global___CardVideoDynList = CardVideoDynList

@typing_extensions.final
class CardVideoFollowList(google.protobuf.message.Message):
    """视频页-我的追番"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_ALL_LINK_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    view_all_link: builtins.str
    """查看全部(跳转链接)"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FollowListItem]:
        """追番列表"""
    def __init__(
        self,
        *,
        view_all_link: builtins.str = ...,
        list: collections.abc.Iterable[global___FollowListItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "view_all_link", b"view_all_link"]) -> None: ...

global___CardVideoFollowList = CardVideoFollowList

@typing_extensions.final
class CardVideoUpList(google.protobuf.message.Message):
    """视频页-最近访问"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    SHOW_LIVE_NUM_FIELD_NUMBER: builtins.int
    MORE_LABEL_FIELD_NUMBER: builtins.int
    TITLE_SWITCH_FIELD_NUMBER: builtins.int
    SHOW_MORE_LABEL_FIELD_NUMBER: builtins.int
    SHOW_IN_PERSONAL_FIELD_NUMBER: builtins.int
    SHOW_MORE_BUTTON_FIELD_NUMBER: builtins.int
    LIST_SECOND_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题展示文案"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpListItem]:
        """up主列表"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    show_live_num: builtins.int
    """直播数"""
    @property
    def more_label(self) -> global___UpListMoreLabel:
        """跳转label"""
    title_switch: builtins.int
    """标题开关(综合页)"""
    show_more_label: builtins.bool
    """是否展示右上角查看更多label"""
    show_in_personal: builtins.bool
    """是否在快速消费页查看更多按钮"""
    show_more_button: builtins.bool
    """是否展示右侧查看更多按钮"""
    @property
    def list_second(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpListItem]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___UpListItem] | None = ...,
        footprint: builtins.str = ...,
        show_live_num: builtins.int = ...,
        more_label: global___UpListMoreLabel | None = ...,
        title_switch: builtins.int = ...,
        show_more_label: builtins.bool = ...,
        show_in_personal: builtins.bool = ...,
        show_more_button: builtins.bool = ...,
        list_second: collections.abc.Iterable[global___UpListItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["more_label", b"more_label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "list", b"list", "list_second", b"list_second", "more_label", b"more_label", "show_in_personal", b"show_in_personal", "show_live_num", b"show_live_num", "show_more_button", b"show_more_button", "show_more_label", b"show_more_label", "title", b"title", "title_switch", b"title_switch"]) -> None: ...

global___CardVideoUpList = CardVideoUpList

@typing_extensions.final
class ChannelInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    TYPE_ICON_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    channel_id: builtins.int
    """"""
    channel_name: builtins.str
    """"""
    desc: builtins.str
    """"""
    is_atten: builtins.bool
    """"""
    type_icon: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RcmdItem]:
        """"""
    icon: builtins.str
    """"""
    jump_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        channel_id: builtins.int = ...,
        channel_name: builtins.str = ...,
        desc: builtins.str = ...,
        is_atten: builtins.bool = ...,
        type_icon: builtins.str = ...,
        items: collections.abc.Iterable[global___RcmdItem] | None = ...,
        icon: builtins.str = ...,
        jump_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id", b"channel_id", "channel_name", b"channel_name", "desc", b"desc", "icon", b"icon", "is_atten", b"is_atten", "items", b"items", "jump_uri", b"jump_uri", "type_icon", b"type_icon"]) -> None: ...

global___ChannelInfo = ChannelInfo

@typing_extensions.final
class CmtShowItem(google.protobuf.message.Message):
    """评论外露展示项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    UNAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    uname: builtins.str
    """用户昵称"""
    uri: builtins.str
    """点击跳转链接"""
    comment: builtins.str
    """评论内容"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        uname: builtins.str = ...,
        uri: builtins.str = ...,
        comment: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "uid", b"uid", "uname", b"uname", "uri", b"uri"]) -> None: ...

global___CmtShowItem = CmtShowItem

@typing_extensions.final
class Colors(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_DAY_FIELD_NUMBER: builtins.int
    COLOR_NIGHT_FIELD_NUMBER: builtins.int
    color_day: builtins.str
    """"""
    color_night: builtins.str
    """"""
    def __init__(
        self,
        *,
        color_day: builtins.str = ...,
        color_night: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color_day", b"color_day", "color_night", b"color_night"]) -> None: ...

global___Colors = Colors

@typing_extensions.final
class CommentDetail(google.protobuf.message.Message):
    """精选评论区"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_MODIFY_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    can_modify: builtins.bool
    """该功能能不能用"""
    status: builtins.int
    """up关闭评论区功能 1允许关闭 0允许开放
    精选评论区功能 1允许停止评论精选 0允许评论精选
    """
    def __init__(
        self,
        *,
        can_modify: builtins.bool = ...,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_modify", b"can_modify", "status", b"status"]) -> None: ...

global___CommentDetail = CommentDetail

@typing_extensions.final
class Config(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORY_VERTICAL_EXP_FIELD_NUMBER: builtins.int
    DETAIL_VIEW_BITS_FIELD_NUMBER: builtins.int
    story_vertical_exp: builtins.bool
    """"""
    detail_view_bits: builtins.int
    """"""
    def __init__(
        self,
        *,
        story_vertical_exp: builtins.bool = ...,
        detail_view_bits: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_view_bits", b"detail_view_bits", "story_vertical_exp", b"story_vertical_exp"]) -> None: ...

global___Config = Config

@typing_extensions.final
class CoverIconWithText(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: builtins.int
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.int = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text"]) -> None: ...

global___CoverIconWithText = CoverIconWithText

@typing_extensions.final
class DecoCardFan(google.protobuf.message.Message):
    """装扮卡片-粉丝勋章信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FAN_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    NUMBER_STR_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    is_fan: builtins.int
    """是否是粉丝"""
    number: builtins.int
    """数量"""
    number_str: builtins.str
    """数量 str"""
    color: builtins.str
    """颜色"""
    def __init__(
        self,
        *,
        is_fan: builtins.int = ...,
        number: builtins.int = ...,
        number_str: builtins.str = ...,
        color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "is_fan", b"is_fan", "number", b"number", "number_str", b"number_str"]) -> None: ...

global___DecoCardFan = DecoCardFan

@typing_extensions.final
class DecorateCard(google.protobuf.message.Message):
    """装扮卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CARD_URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    FAN_FIELD_NUMBER: builtins.int
    id: builtins.int
    """装扮卡片id"""
    card_url: builtins.str
    """装扮卡片链接"""
    jump_url: builtins.str
    """装扮卡片点击跳转链接"""
    @property
    def fan(self) -> global___DecoCardFan:
        """粉丝样式"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        card_url: builtins.str = ...,
        jump_url: builtins.str = ...,
        fan: global___DecoCardFan | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fan", b"fan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_url", b"card_url", "fan", b"fan", "id", b"id", "jump_url", b"jump_url"]) -> None: ...

global___DecorateCard = DecorateCard

@typing_extensions.final
class Description(google.protobuf.message.Message):
    """文本描述"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    EMOJI_TYPE_FIELD_NUMBER: builtins.int
    GOODS_TYPE_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    ICON_NAME_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    ORIG_TEXT_FIELD_NUMBER: builtins.int
    EMOJI_SIZE_FIELD_NUMBER: builtins.int
    EMOJI_SIZE_SPEC_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文本内容"""
    type: global___DescType.ValueType
    """文本类型"""
    uri: builtins.str
    """点击跳转链接"""
    emoji_type: global___EmojiType.ValueType
    """emoji类型"""
    goods_type: builtins.str
    """商品类型"""
    icon_url: builtins.str
    """前置Icon"""
    icon_name: builtins.str
    """icon_name"""
    rid: builtins.str
    """资源ID"""
    @property
    def goods(self) -> global___ModuleDescGoods:
        """商品卡特殊字段"""
    orig_text: builtins.str
    """文本原始文案"""
    emoji_size: builtins.int
    """"""
    @property
    def emoji_size_spec(self) -> global___EmojiSizeSpec:
        """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        type: global___DescType.ValueType = ...,
        uri: builtins.str = ...,
        emoji_type: global___EmojiType.ValueType = ...,
        goods_type: builtins.str = ...,
        icon_url: builtins.str = ...,
        icon_name: builtins.str = ...,
        rid: builtins.str = ...,
        goods: global___ModuleDescGoods | None = ...,
        orig_text: builtins.str = ...,
        emoji_size: builtins.int = ...,
        emoji_size_spec: global___EmojiSizeSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["emoji_size_spec", b"emoji_size_spec", "goods", b"goods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emoji_size", b"emoji_size", "emoji_size_spec", b"emoji_size_spec", "emoji_type", b"emoji_type", "goods", b"goods", "goods_type", b"goods_type", "icon_name", b"icon_name", "icon_url", b"icon_url", "orig_text", b"orig_text", "rid", b"rid", "text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___Description = Description

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """尺寸信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    height: builtins.int
    """"""
    width: builtins.int
    """"""
    rotate: builtins.int
    """"""
    def __init__(
        self,
        *,
        height: builtins.int = ...,
        width: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class DynAdditionCommonFollowReply(google.protobuf.message.Message):
    """动态通用附加卡-follow/取消follow-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: global___AdditionalButtonStatus.ValueType
    """"""
    def __init__(
        self,
        *,
        status: global___AdditionalButtonStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___DynAdditionCommonFollowReply = DynAdditionCommonFollowReply

@typing_extensions.final
class DynAdditionCommonFollowReq(google.protobuf.message.Message):
    """动态通用附加卡-follow/取消follow-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    status: global___AdditionalButtonStatus.ValueType
    """"""
    dyn_id: builtins.str
    """"""
    card_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        status: global___AdditionalButtonStatus.ValueType = ...,
        dyn_id: builtins.str = ...,
        card_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "dyn_id", b"dyn_id", "status", b"status"]) -> None: ...

global___DynAdditionCommonFollowReq = DynAdditionCommonFollowReq

@typing_extensions.final
class DynAllPersonalReply(google.protobuf.message.Message):
    """最近访问-个人feed流列表-返回"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    ADDITION_UP_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TITLE_SUB_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    offset: builtins.str
    """偏移量"""
    has_more: builtins.bool
    """是否还有更多数据"""
    read_offset: builtins.str
    """已读进度"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    @property
    def addition_up(self) -> global___TopAdditionUP:
        """顶部预约卡"""
    title: builtins.str
    """"""
    title_sub: builtins.str
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        read_offset: builtins.str = ...,
        relation: global___Relation | None = ...,
        addition_up: global___TopAdditionUP | None = ...,
        title: builtins.str = ...,
        title_sub: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_up", b"addition_up", "relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_up", b"addition_up", "has_more", b"has_more", "list", b"list", "offset", b"offset", "read_offset", b"read_offset", "relation", b"relation", "title", b"title", "title_sub", b"title_sub"]) -> None: ...

global___DynAllPersonalReply = DynAllPersonalReply

@typing_extensions.final
class DynAllPersonalReq(google.protobuf.message.Message):
    """最近访问-个人feed流列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    IS_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    PERSONAL_EXTRA_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的 UID"""
    offset: builtins.str
    """偏移量 第一页可传空"""
    page: builtins.int
    """标明下拉几次"""
    is_preload: builtins.int
    """是否是预加载 默认是1；客户端预加载。1：是预加载，不更新已读进度，不会影响小红点；0：非预加载，更新已读进度"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开用"""
    personal_extra: builtins.str
    """"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        is_preload: builtins.int = ...,
        playurl_param: global___PlayurlParam | None = ...,
        local_time: builtins.int = ...,
        footprint: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        personal_extra: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "from", b"from", "host_uid", b"host_uid", "is_preload", b"is_preload", "local_time", b"local_time", "offset", b"offset", "page", b"page", "personal_extra", b"personal_extra", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> None: ...

global___DynAllPersonalReq = DynAllPersonalReq

@typing_extensions.final
class DynAllReply(google.protobuf.message.Message):
    """动态综合页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_LIST_FIELD_NUMBER: builtins.int
    UP_LIST_FIELD_NUMBER: builtins.int
    TOPIC_LIST_FIELD_NUMBER: builtins.int
    UNFOLLOW_FIELD_NUMBER: builtins.int
    REGION_RCMD_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def dynamic_list(self) -> global___DynamicList:
        """卡片列表"""
    @property
    def up_list(self) -> global___CardVideoUpList:
        """顶部up list"""
    @property
    def topic_list(self) -> global___TopicList:
        """话题广场"""
    @property
    def unfollow(self) -> global___Unfollow:
        """无关注推荐"""
    @property
    def region_rcmd(self) -> global___DynRegionRcmd:
        """分区UP推荐"""
    @property
    def config(self) -> global___Config:
        """"""
    def __init__(
        self,
        *,
        dynamic_list: global___DynamicList | None = ...,
        up_list: global___CardVideoUpList | None = ...,
        topic_list: global___TopicList | None = ...,
        unfollow: global___Unfollow | None = ...,
        region_rcmd: global___DynRegionRcmd | None = ...,
        config: global___Config | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "dynamic_list", b"dynamic_list", "region_rcmd", b"region_rcmd", "topic_list", b"topic_list", "unfollow", b"unfollow", "up_list", b"up_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "dynamic_list", b"dynamic_list", "region_rcmd", b"region_rcmd", "topic_list", b"topic_list", "unfollow", b"unfollow", "up_list", b"up_list"]) -> None: ...

global___DynAllReply = DynAllReply

@typing_extensions.final
class DynAllReq(google.protobuf.message.Message):
    """动态综合页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    REFRESH_TYPE_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    ASSIST_BASELINE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    RCMD_UPS_PARAM_FIELD_NUMBER: builtins.int
    AD_PARAM_FIELD_NUMBER: builtins.int
    COLD_START_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    TAB_RECALL_UID_FIELD_NUMBER: builtins.int
    TAB_RECALL_TYPE_FIELD_NUMBER: builtins.int
    update_baseline: builtins.str
    """透传 update_baseline"""
    offset: builtins.str
    """透传 history_offset"""
    page: builtins.int
    """向下翻页数"""
    refresh_type: global___Refresh.ValueType
    """刷新方式 1向上刷新 2向下翻页"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    assist_baseline: builtins.str
    """综合页当前更新的最大值"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    @property
    def rcmd_ups_param(self) -> global___RcmdUPsParam:
        """推荐up主入参(new的时候传)"""
    @property
    def ad_param(self) -> global___AdParam:
        """广告参数"""
    cold_start: builtins.int
    """是否冷启"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    tab_recall_uid: builtins.int
    """"""
    tab_recall_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        update_baseline: builtins.str = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        refresh_type: global___Refresh.ValueType = ...,
        playurl_param: global___PlayurlParam | None = ...,
        assist_baseline: builtins.str = ...,
        local_time: builtins.int = ...,
        rcmd_ups_param: global___RcmdUPsParam | None = ...,
        ad_param: global___AdParam | None = ...,
        cold_start: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        tab_recall_uid: builtins.int = ...,
        tab_recall_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "player_args", b"player_args", "playurl_param", b"playurl_param", "rcmd_ups_param", b"rcmd_ups_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "assist_baseline", b"assist_baseline", "cold_start", b"cold_start", "from", b"from", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "playurl_param", b"playurl_param", "rcmd_ups_param", b"rcmd_ups_param", "refresh_type", b"refresh_type", "tab_recall_type", b"tab_recall_type", "tab_recall_uid", b"tab_recall_uid", "update_baseline", b"update_baseline"]) -> None: ...

global___DynAllReq = DynAllReq

@typing_extensions.final
class DynAllUpdOffsetReq(google.protobuf.message.Message):
    """最近访问-标记已读-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    PERSONAL_EXTRA_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的UID"""
    read_offset: builtins.str
    """用户已读进度"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    personal_extra: builtins.str
    """"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        read_offset: builtins.str = ...,
        footprint: builtins.str = ...,
        personal_extra: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "host_uid", b"host_uid", "personal_extra", b"personal_extra", "read_offset", b"read_offset"]) -> None: ...

global___DynAllUpdOffsetReq = DynAllUpdOffsetReq

@typing_extensions.final
class DynamicItem(google.protobuf.message.Message):
    """动态卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_TYPE_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    EXTEND_FIELD_NUMBER: builtins.int
    HAS_FOLD_FIELD_NUMBER: builtins.int
    SERVER_INFO_FIELD_NUMBER: builtins.int
    card_type: global___DynamicType.ValueType
    """动态卡片类型"""
    item_type: global___DynamicType.ValueType
    """转发类型下，源卡片类型"""
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]:
        """模块内容"""
    @property
    def extend(self) -> global___Extend:
        """操作相关字段"""
    has_fold: builtins.int
    """该卡片下面是否含有折叠卡"""
    server_info: builtins.str
    """透传到客户端的埋点字段。"""
    def __init__(
        self,
        *,
        card_type: global___DynamicType.ValueType = ...,
        item_type: global___DynamicType.ValueType = ...,
        modules: collections.abc.Iterable[global___Module] | None = ...,
        extend: global___Extend | None = ...,
        has_fold: builtins.int = ...,
        server_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extend", b"extend"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type", b"card_type", "extend", b"extend", "has_fold", b"has_fold", "item_type", b"item_type", "modules", b"modules", "server_info", b"server_info"]) -> None: ...

global___DynamicItem = DynamicItem

@typing_extensions.final
class DynamicList(google.protobuf.message.Message):
    """动态卡片列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    UPDATE_NUM_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    update_num: builtins.int
    """更新的动态数"""
    history_offset: builtins.str
    """历史偏移"""
    update_baseline: builtins.str
    """更新基础信息"""
    has_more: builtins.bool
    """是否还有更多数据"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        update_num: builtins.int = ...,
        history_offset: builtins.str = ...,
        update_baseline: builtins.str = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "history_offset", b"history_offset", "list", b"list", "update_baseline", b"update_baseline", "update_num", b"update_num"]) -> None: ...

global___DynamicList = DynamicList

@typing_extensions.final
class DynDetailReply(google.protobuf.message.Message):
    """动态详情页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DynamicItem:
        """动态详情"""
    def __init__(
        self,
        *,
        item: global___DynamicItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___DynDetailReply = DynDetailReply

@typing_extensions.final
class DynDetailReq(google.protobuf.message.Message):
    """动态详情页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    AD_PARAM_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    SHARE_ID_FIELD_NUMBER: builtins.int
    SHARE_MODE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """up主uid"""
    dynamic_id: builtins.str
    """动态ID"""
    dyn_type: builtins.int
    """动态类型"""
    rid: builtins.int
    """业务方资源id"""
    @property
    def ad_param(self) -> global___AdParam:
        """广告参数"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    share_id: builtins.str
    """分享id"""
    share_mode: builtins.int
    """分享类型
    1:文字 2:图片 3:链接 4:视频 5:音频
    """
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    pattern: builtins.str
    """pattern"""
    @property
    def config(self) -> global___Config:
        """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        dynamic_id: builtins.str = ...,
        dyn_type: builtins.int = ...,
        rid: builtins.int = ...,
        ad_param: global___AdParam | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        share_id: builtins.str = ...,
        share_mode: builtins.int = ...,
        local_time: builtins.int = ...,
        pattern: builtins.str = ...,
        config: global___Config | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "config", b"config", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "config", b"config", "dyn_type", b"dyn_type", "dynamic_id", b"dynamic_id", "from", b"from", "local_time", b"local_time", "pattern", b"pattern", "player_args", b"player_args", "rid", b"rid", "share_id", b"share_id", "share_mode", b"share_mode", "uid", b"uid"]) -> None: ...

global___DynDetailReq = DynDetailReq

@typing_extensions.final
class DynDetailsReply(google.protobuf.message.Message):
    """批量动态id获取动态详情-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___DynDetailsReply = DynDetailsReply

@typing_extensions.final
class DynDetailsReq(google.protobuf.message.Message):
    """批量动态id获取动态详情-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_IDS_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    dynamic_ids: builtins.str
    """动态id"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    @property
    def config(self) -> global___Config:
        """"""
    def __init__(
        self,
        *,
        dynamic_ids: builtins.str = ...,
        playurl_param: global___PlayurlParam | None = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        config: global___Config | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "dynamic_ids", b"dynamic_ids", "local_time", b"local_time", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> None: ...

global___DynDetailsReq = DynDetailsReq

@typing_extensions.final
class DynFakeCardReply(google.protobuf.message.Message):
    """动态发布生成临时卡-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DynamicItem:
        """动态卡片"""
    def __init__(
        self,
        *,
        item: global___DynamicItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___DynFakeCardReply = DynFakeCardReply

@typing_extensions.final
class DynFakeCardReq(google.protobuf.message.Message):
    """动态发布生成临时卡-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """卡片内容json string"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___DynFakeCardReq = DynFakeCardReq

@typing_extensions.final
class DynFeatureGate(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENHANCED_INTERACTION_FIELD_NUMBER: builtins.int
    enhanced_interaction: builtins.bool
    """"""
    def __init__(
        self,
        *,
        enhanced_interaction: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enhanced_interaction", b"enhanced_interaction"]) -> None: ...

global___DynFeatureGate = DynFeatureGate

@typing_extensions.final
class DynFriendReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    @property
    def dyn_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        dyn_list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_list", b"dyn_list", "has_more", b"has_more", "offset", b"offset"]) -> None: ...

global___DynFriendReply = DynFriendReply

@typing_extensions.final
class DynFriendReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_time", b"local_time", "offset", b"offset", "player_args", b"player_args"]) -> None: ...

global___DynFriendReq = DynFriendReq

@typing_extensions.final
class DynLightReply(google.protobuf.message.Message):
    """轻浏览-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_LIST_FIELD_NUMBER: builtins.int
    @property
    def dynamic_list(self) -> global___DynamicList:
        """卡片列表"""
    def __init__(
        self,
        *,
        dynamic_list: global___DynamicList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list"]) -> None: ...

global___DynLightReply = DynLightReply

@typing_extensions.final
class DynLightReq(google.protobuf.message.Message):
    """轻浏览-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    FAKE_UID_FIELD_NUMBER: builtins.int
    history_offset: builtins.str
    """透传 history_offset"""
    page: builtins.int
    """向下翻页数"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    from_type: builtins.int
    """"""
    fake_uid: builtins.int
    """"""
    def __init__(
        self,
        *,
        history_offset: builtins.str = ...,
        page: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        local_time: builtins.int = ...,
        from_type: builtins.int = ...,
        fake_uid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fake_uid", b"fake_uid", "from", b"from", "from_type", b"from_type", "history_offset", b"history_offset", "local_time", b"local_time", "page", b"page", "player_args", b"player_args"]) -> None: ...

global___DynLightReq = DynLightReq

@typing_extensions.final
class DynMixUpListViewMoreReply(google.protobuf.message.Message):
    """查看更多-列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    SEARCH_DEFAULT_TEXT_FIELD_NUMBER: builtins.int
    SORT_TYPES_FIELD_NUMBER: builtins.int
    SHOW_MORE_SORT_TYPES_FIELD_NUMBER: builtins.int
    DEFAULT_SORT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MixUpListItem]:
        """"""
    search_default_text: builtins.str
    """"""
    @property
    def sort_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortType]:
        """排序类型列表"""
    show_more_sort_types: builtins.bool
    """是否展示更多的排序策略"""
    default_sort_type: builtins.int
    """默认排序策略"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___MixUpListItem] | None = ...,
        search_default_text: builtins.str = ...,
        sort_types: collections.abc.Iterable[global___SortType] | None = ...,
        show_more_sort_types: builtins.bool = ...,
        default_sort_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_sort_type", b"default_sort_type", "items", b"items", "search_default_text", b"search_default_text", "show_more_sort_types", b"show_more_sort_types", "sort_types", b"sort_types"]) -> None: ...

global___DynMixUpListViewMoreReply = DynMixUpListViewMoreReply

@typing_extensions.final
class DynMixUpListViewMoreReq(google.protobuf.message.Message):
    """查看更多-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_TYPE_FIELD_NUMBER: builtins.int
    sort_type: builtins.int
    """排序策略
    1:推荐排序 2:最常访问 3:最近关注，其他值为默认排序
    """
    def __init__(
        self,
        *,
        sort_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_type", b"sort_type"]) -> None: ...

global___DynMixUpListViewMoreReq = DynMixUpListViewMoreReq

@typing_extensions.final
class DynRcmdReply(google.protobuf.message.Message):
    """推荐页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_RCMD_FIELD_NUMBER: builtins.int
    DYNAMIC_LIST_FIELD_NUMBER: builtins.int
    @property
    def region_rcmd(self) -> global___DynRegionRcmd:
        """推荐页返回参数"""
    @property
    def dynamic_list(self) -> global___DynamicList:
        """"""
    def __init__(
        self,
        *,
        region_rcmd: global___DynRegionRcmd | None = ...,
        dynamic_list: global___DynamicList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "region_rcmd", b"region_rcmd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "region_rcmd", b"region_rcmd"]) -> None: ...

global___DynRcmdReply = DynRcmdReply

@typing_extensions.final
class DynRcmdReq(google.protobuf.message.Message):
    """推荐页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FAKE_UID_FIELD_NUMBER: builtins.int
    IS_REFRESH_FIELD_NUMBER: builtins.int
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    fake_uid: builtins.int
    """"""
    is_refresh: builtins.bool
    """"""
    def __init__(
        self,
        *,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        local_time: builtins.int = ...,
        fake_uid: builtins.int = ...,
        is_refresh: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fake_uid", b"fake_uid", "is_refresh", b"is_refresh", "local_time", b"local_time", "player_args", b"player_args"]) -> None: ...

global___DynRcmdReq = DynRcmdReq

@typing_extensions.final
class DynRcmdUpExchangeReply(google.protobuf.message.Message):
    """关注推荐up主换一换-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNFOLLOW_FIELD_NUMBER: builtins.int
    @property
    def unfollow(self) -> global___Unfollow:
        """无关注推荐"""
    def __init__(
        self,
        *,
        unfollow: global___Unfollow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["unfollow", b"unfollow"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["unfollow", b"unfollow"]) -> None: ...

global___DynRcmdUpExchangeReply = DynRcmdUpExchangeReply

@typing_extensions.final
class DynRcmdUpExchangeReq(google.protobuf.message.Message):
    """关注推荐up主换一换-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    DISLIKETS_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """登录用户id"""
    dislikeTs: builtins.int
    """上一次不感兴趣的ts，单位：秒；该字段透传给搜索"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        dislikeTs: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislikeTs", b"dislikeTs", "from", b"from", "uid", b"uid"]) -> None: ...

global___DynRcmdUpExchangeReq = DynRcmdUpExchangeReq

@typing_extensions.final
class DynRegionRcmd(google.protobuf.message.Message):
    """推荐页返回参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    OPTS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynRegionRcmdItem]:
        """分区推荐项目列表"""
    @property
    def opts(self) -> global___RcmdOption:
        """分区聚类推荐选项"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___DynRegionRcmdItem] | None = ...,
        opts: global___RcmdOption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["opts", b"opts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "opts", b"opts"]) -> None: ...

global___DynRegionRcmd = DynRegionRcmd

@typing_extensions.final
class DynRegionRcmdItem(google.protobuf.message.Message):
    """分区推荐项目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    rid: builtins.int
    """分区id"""
    title: builtins.str
    """标题"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleRcmd]:
        """推荐模块"""
    def __init__(
        self,
        *,
        rid: builtins.int = ...,
        title: builtins.str = ...,
        items: collections.abc.Iterable[global___ModuleRcmd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "rid", b"rid", "title", b"title"]) -> None: ...

global___DynRegionRcmdItem = DynRegionRcmdItem

@typing_extensions.final
class DynScreenTab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_TAB_FIELD_NUMBER: builtins.int
    STRATEGY_SHOW_ON_ENTRANCE_FIELD_NUMBER: builtins.int
    STRATEGY_SHOW_ON_REFRESH_FIELD_NUMBER: builtins.int
    STRATEGY_SHOW_ON_PULL_UP_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    name: builtins.str
    """"""
    default_tab: builtins.bool
    """"""
    strategy_show_on_entrance: builtins.bool
    """"""
    strategy_show_on_refresh: builtins.bool
    """"""
    strategy_show_on_pull_up: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        name: builtins.str = ...,
        default_tab: builtins.bool = ...,
        strategy_show_on_entrance: builtins.bool = ...,
        strategy_show_on_refresh: builtins.bool = ...,
        strategy_show_on_pull_up: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_tab", b"default_tab", "name", b"name", "strategy_show_on_entrance", b"strategy_show_on_entrance", "strategy_show_on_pull_up", b"strategy_show_on_pull_up", "strategy_show_on_refresh", b"strategy_show_on_refresh", "title", b"title"]) -> None: ...

global___DynScreenTab = DynScreenTab

@typing_extensions.final
class DynSearchReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_INFO_FIELD_NUMBER: builtins.int
    SEARCH_TOPIC_FIELD_NUMBER: builtins.int
    SEARCH_INFO_FIELD_NUMBER: builtins.int
    @property
    def channel_info(self) -> global___SearchChannel:
        """"""
    @property
    def search_topic(self) -> global___SearchTopic:
        """"""
    @property
    def search_info(self) -> global___SearchInfo:
        """"""
    def __init__(
        self,
        *,
        channel_info: global___SearchChannel | None = ...,
        search_topic: global___SearchTopic | None = ...,
        search_info: global___SearchInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel_info", b"channel_info", "search_info", b"search_info", "search_topic", b"search_topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_info", b"channel_info", "search_info", b"search_info", "search_topic", b"search_topic"]) -> None: ...

global___DynSearchReply = DynSearchReply

@typing_extensions.final
class DynSearchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    page: builtins.int
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        page: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "local_time", b"local_time", "page", b"page", "player_args", b"player_args"]) -> None: ...

global___DynSearchReq = DynSearchReq

@typing_extensions.final
class DynServerDetailsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ItemsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___DynamicItem: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___DynamicItem | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___DynamicItem]:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Mapping[builtins.int, global___DynamicItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___DynServerDetailsReply = DynServerDetailsReply

@typing_extensions.final
class DynServerDetailsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    IS_MASTER_FIELD_NUMBER: builtins.int
    TOP_DYNAMIC_IDS_FIELD_NUMBER: builtins.int
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    mobi_app: builtins.str
    """"""
    device: builtins.str
    """"""
    buvid: builtins.str
    """"""
    build: builtins.int
    """"""
    mid: builtins.int
    """"""
    platform: builtins.str
    """"""
    is_master: builtins.bool
    """"""
    @property
    def top_dynamic_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    def __init__(
        self,
        *,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        mobi_app: builtins.str = ...,
        device: builtins.str = ...,
        buvid: builtins.str = ...,
        build: builtins.int = ...,
        mid: builtins.int = ...,
        platform: builtins.str = ...,
        is_master: builtins.bool = ...,
        top_dynamic_ids: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "buvid", b"buvid", "device", b"device", "is_master", b"is_master", "local_time", b"local_time", "mid", b"mid", "mobi_app", b"mobi_app", "platform", b"platform", "player_args", b"player_args", "top_dynamic_ids", b"top_dynamic_ids"]) -> None: ...

global___DynServerDetailsReq = DynServerDetailsReq

@typing_extensions.final
class DynSpaceReq(google.protobuf.message.Message):
    """空间页动态-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者，也就是空间主人的uid"""
    history_offset: builtins.str
    """动态偏移history_offset"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    page: builtins.int
    """向下翻页数，默认从1开始"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        history_offset: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        local_time: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "history_offset", b"history_offset", "host_uid", b"host_uid", "local_time", b"local_time", "page", b"page", "player_args", b"player_args"]) -> None: ...

global___DynSpaceReq = DynSpaceReq

@typing_extensions.final
class DynSpaceRsp(google.protobuf.message.Message):
    """空间页动态-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """卡片列表"""
    history_offset: builtins.str
    """历史偏移"""
    has_more: builtins.bool
    """是否还有更多数据"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        history_offset: builtins.str = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "history_offset", b"history_offset", "list", b"list"]) -> None: ...

global___DynSpaceRsp = DynSpaceRsp

@typing_extensions.final
class DynSpaceSearchDetailsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ItemsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___DynamicItem: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___DynamicItem | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___DynamicItem]:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Mapping[builtins.int, global___DynamicItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___DynSpaceSearchDetailsReply = DynSpaceSearchDetailsReply

@typing_extensions.final
class DynSpaceSearchDetailsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_WORDS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    NET_TYPE_FIELD_NUMBER: builtins.int
    TF_TYPE_FIELD_NUMBER: builtins.int
    @property
    def search_words(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    mobi_app: builtins.str
    """"""
    device: builtins.str
    """"""
    buvid: builtins.str
    """"""
    build: builtins.int
    """"""
    mid: builtins.int
    """"""
    platform: builtins.str
    """"""
    ip: builtins.str
    """"""
    net_type: builtins.int
    """"""
    tf_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        search_words: collections.abc.Iterable[builtins.str] | None = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        mobi_app: builtins.str = ...,
        device: builtins.str = ...,
        buvid: builtins.str = ...,
        build: builtins.int = ...,
        mid: builtins.int = ...,
        platform: builtins.str = ...,
        ip: builtins.str = ...,
        net_type: builtins.int = ...,
        tf_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "buvid", b"buvid", "device", b"device", "ip", b"ip", "local_time", b"local_time", "mid", b"mid", "mobi_app", b"mobi_app", "net_type", b"net_type", "platform", b"platform", "player_args", b"player_args", "search_words", b"search_words", "tf_type", b"tf_type"]) -> None: ...

global___DynSpaceSearchDetailsReq = DynSpaceSearchDetailsReq

@typing_extensions.final
class DynTab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    RED_POINT_FIELD_NUMBER: builtins.int
    CITY_ID_FIELD_NUMBER: builtins.int
    IS_POPUP_FIELD_NUMBER: builtins.int
    POPUP_FIELD_NUMBER: builtins.int
    DEFAULT_TAB_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    ANCHOR_FIELD_NUMBER: builtins.int
    INTERNAL_TEST_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BACK_UP_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    bubble: builtins.str
    """"""
    red_point: builtins.int
    """"""
    city_id: builtins.int
    """"""
    is_popup: builtins.int
    """"""
    @property
    def popup(self) -> global___Popup:
        """"""
    default_tab: builtins.bool
    """"""
    sub_title: builtins.str
    """"""
    anchor: builtins.str
    """"""
    internal_test: builtins.str
    """"""
    type: builtins.int
    """"""
    @property
    def back_up(self) -> global___DynTab:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        bubble: builtins.str = ...,
        red_point: builtins.int = ...,
        city_id: builtins.int = ...,
        is_popup: builtins.int = ...,
        popup: global___Popup | None = ...,
        default_tab: builtins.bool = ...,
        sub_title: builtins.str = ...,
        anchor: builtins.str = ...,
        internal_test: builtins.str = ...,
        type: builtins.int = ...,
        back_up: global___DynTab | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["back_up", b"back_up", "popup", b"popup"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor", b"anchor", "back_up", b"back_up", "bubble", b"bubble", "city_id", b"city_id", "default_tab", b"default_tab", "internal_test", b"internal_test", "is_popup", b"is_popup", "popup", b"popup", "red_point", b"red_point", "sub_title", b"sub_title", "title", b"title", "type", b"type", "uri", b"uri"]) -> None: ...

global___DynTab = DynTab

@typing_extensions.final
class DynTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_TAB_FIELD_NUMBER: builtins.int
    SCREEN_TAB_FIELD_NUMBER: builtins.int
    @property
    def dyn_tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynTab]:
        """"""
    @property
    def screen_tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynScreenTab]:
        """"""
    def __init__(
        self,
        *,
        dyn_tab: collections.abc.Iterable[global___DynTab] | None = ...,
        screen_tab: collections.abc.Iterable[global___DynScreenTab] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_tab", b"dyn_tab", "screen_tab", b"screen_tab"]) -> None: ...

global___DynTabReply = DynTabReply

@typing_extensions.final
class DynTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.int
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        teenagers_mode: builtins.int = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_type", b"from_type", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___DynTabReq = DynTabReq

@typing_extensions.final
class DynThumbReq(google.protobuf.message.Message):
    """动态点赞-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户uid"""
    dyn_id: builtins.str
    """动态id"""
    dyn_type: builtins.int
    """动态类型(透传extend中的dyn_type)"""
    rid: builtins.str
    """业务方资源id"""
    type: global___ThumbType.ValueType
    """点赞类型"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        dyn_id: builtins.str = ...,
        dyn_type: builtins.int = ...,
        rid: builtins.str = ...,
        type: global___ThumbType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_id", b"dyn_id", "dyn_type", b"dyn_type", "rid", b"rid", "type", b"type", "uid", b"uid"]) -> None: ...

global___DynThumbReq = DynThumbReq

@typing_extensions.final
class DynVideoPersonalReply(google.protobuf.message.Message):
    """最近访问-个人feed流列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    ADDITION_UP_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TITLE_SUB_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
    offset: builtins.str
    """偏移量"""
    has_more: builtins.bool
    """是否还有更多数据"""
    read_offset: builtins.str
    """已读进度"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    @property
    def addition_up(self) -> global___TopAdditionUP:
        """顶部预约卡"""
    title: builtins.str
    """"""
    title_sub: builtins.str
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        read_offset: builtins.str = ...,
        relation: global___Relation | None = ...,
        addition_up: global___TopAdditionUP | None = ...,
        title: builtins.str = ...,
        title_sub: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addition_up", b"addition_up", "relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_up", b"addition_up", "has_more", b"has_more", "list", b"list", "offset", b"offset", "read_offset", b"read_offset", "relation", b"relation", "title", b"title", "title_sub", b"title_sub"]) -> None: ...

global___DynVideoPersonalReply = DynVideoPersonalReply

@typing_extensions.final
class DynVideoPersonalReq(google.protobuf.message.Message):
    """最近访问-个人feed流列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    IS_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    PEGASUS_AVID_FIELD_NUMBER: builtins.int
    PERSONAL_EXTRA_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的 UID"""
    offset: builtins.str
    """偏移量 第一页可传空"""
    page: builtins.int
    """标明下拉几次"""
    is_preload: builtins.int
    """是否是预加载"""
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    pegasus_avid: builtins.int
    """"""
    personal_extra: builtins.str
    """"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        is_preload: builtins.int = ...,
        playurl_param: global___PlayurlParam | None = ...,
        local_time: builtins.int = ...,
        footprint: builtins.str = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        pegasus_avid: builtins.int = ...,
        personal_extra: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "from", b"from", "host_uid", b"host_uid", "is_preload", b"is_preload", "local_time", b"local_time", "offset", b"offset", "page", b"page", "pegasus_avid", b"pegasus_avid", "personal_extra", b"personal_extra", "player_args", b"player_args", "playurl_param", b"playurl_param"]) -> None: ...

global___DynVideoPersonalReq = DynVideoPersonalReq

@typing_extensions.final
class DynVideoReply(google.protobuf.message.Message):
    """动态视频页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_LIST_FIELD_NUMBER: builtins.int
    VIDEO_UP_LIST_FIELD_NUMBER: builtins.int
    VIDEO_FOLLOW_LIST_FIELD_NUMBER: builtins.int
    @property
    def dynamic_list(self) -> global___CardVideoDynList:
        """卡片列表"""
    @property
    def video_up_list(self) -> global___CardVideoUpList:
        """动态卡片"""
    @property
    def video_follow_list(self) -> global___CardVideoFollowList:
        """视频页-我的追番"""
    def __init__(
        self,
        *,
        dynamic_list: global___CardVideoDynList | None = ...,
        video_up_list: global___CardVideoUpList | None = ...,
        video_follow_list: global___CardVideoFollowList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "video_follow_list", b"video_follow_list", "video_up_list", b"video_up_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_list", b"dynamic_list", "video_follow_list", b"video_follow_list", "video_up_list", b"video_up_list"]) -> None: ...

global___DynVideoReply = DynVideoReply

@typing_extensions.final
class DynVideoReq(google.protobuf.message.Message):
    """动态视频页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    REFRESH_TYPE_FIELD_NUMBER: builtins.int
    PLAYURL_PARAM_FIELD_NUMBER: builtins.int
    ASSIST_BASELINE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    update_baseline: builtins.str
    """透传 update_baseline"""
    offset: builtins.str
    """透传 history_offset"""
    page: builtins.int
    """向下翻页数"""
    refresh_type: global___Refresh.ValueType
    """刷新方式
    1:向上刷新 2:向下翻页
    """
    @property
    def playurl_param(self) -> global___PlayurlParam:
        """秒开参数 新版本废弃，统一使用player_args"""
    assist_baseline: builtins.str
    """综合页当前更新的最大值"""
    local_time: builtins.int
    """客户端时区 兼容UTC-14和Etc/GMT+12,时区区间[-12,14] 东八区为8"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        update_baseline: builtins.str = ...,
        offset: builtins.str = ...,
        page: builtins.int = ...,
        refresh_type: global___Refresh.ValueType = ...,
        playurl_param: global___PlayurlParam | None = ...,
        assist_baseline: builtins.str = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args", "playurl_param", b"playurl_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assist_baseline", b"assist_baseline", "from", b"from", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "playurl_param", b"playurl_param", "refresh_type", b"refresh_type", "update_baseline", b"update_baseline"]) -> None: ...

global___DynVideoReq = DynVideoReq

@typing_extensions.final
class DynVideoUpdOffsetReq(google.protobuf.message.Message):
    """最近访问-标记已读-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_UID_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    FOOTPRINT_FIELD_NUMBER: builtins.int
    PERSONAL_EXTRA_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的UID"""
    read_offset: builtins.str
    """用户已读进度"""
    footprint: builtins.str
    """服务端生成的透传上报字段"""
    personal_extra: builtins.str
    """"""
    def __init__(
        self,
        *,
        host_uid: builtins.int = ...,
        read_offset: builtins.str = ...,
        footprint: builtins.str = ...,
        personal_extra: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["footprint", b"footprint", "host_uid", b"host_uid", "personal_extra", b"personal_extra", "read_offset", b"read_offset"]) -> None: ...

global___DynVideoUpdOffsetReq = DynVideoUpdOffsetReq

@typing_extensions.final
class DynVoteReply(google.protobuf.message.Message):
    """投票操作-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___AdditionVote2:
        """投票详情"""
    toast: builtins.str
    """投票操作返回状态"""
    def __init__(
        self,
        *,
        item: global___AdditionVote2 | None = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "toast", b"toast"]) -> None: ...

global___DynVoteReply = DynVoteReply

@typing_extensions.final
class DynVoteReq(google.protobuf.message.Message):
    """投票操作-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTE_ID_FIELD_NUMBER: builtins.int
    VOTES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    vote_id: builtins.int
    """投票ID"""
    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """选项索引数组"""
    status: global___VoteStatus.ValueType
    """状态"""
    dynamic_id: builtins.str
    """动态ID"""
    share: builtins.bool
    """是否分享"""
    def __init__(
        self,
        *,
        vote_id: builtins.int = ...,
        votes: collections.abc.Iterable[builtins.int] | None = ...,
        status: global___VoteStatus.ValueType = ...,
        dynamic_id: builtins.str = ...,
        share: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_id", b"dynamic_id", "share", b"share", "status", b"status", "vote_id", b"vote_id", "votes", b"votes"]) -> None: ...

global___DynVoteReq = DynVoteReq

@typing_extensions.final
class EmojiSizeSpec(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""
    def __init__(
        self,
        *,
        width: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["width", b"width"]) -> None: ...

global___EmojiSizeSpec = EmojiSizeSpec

@typing_extensions.final
class EmoteNode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMOTE_URL_FIELD_NUMBER: builtins.int
    EMOTE_WIDTH_FIELD_NUMBER: builtins.int
    INLINE_IMG_CFG_FIELD_NUMBER: builtins.int
    IS_INLINE_IMG_FIELD_NUMBER: builtins.int
    RAW_TEXT_FIELD_NUMBER: builtins.int
    emote_url: builtins.str
    """"""
    @property
    def emote_width(self) -> global___EmoteSize:
        """"""
    @property
    def inline_img_cfg(self) -> global___ImgInlineCfg:
        """"""
    is_inline_img: builtins.bool
    """"""
    @property
    def raw_text(self) -> global___WordNode:
        """"""
    def __init__(
        self,
        *,
        emote_url: builtins.str = ...,
        emote_width: global___EmoteSize | None = ...,
        inline_img_cfg: global___ImgInlineCfg | None = ...,
        is_inline_img: builtins.bool = ...,
        raw_text: global___WordNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["emote_width", b"emote_width", "inline_img_cfg", b"inline_img_cfg", "raw_text", b"raw_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emote_url", b"emote_url", "emote_width", b"emote_width", "inline_img_cfg", b"inline_img_cfg", "is_inline_img", b"is_inline_img", "raw_text", b"raw_text"]) -> None: ...

global___EmoteNode = EmoteNode

@typing_extensions.final
class EmoteSize(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    EMOJI_SIZE_FIELD_NUMBER: builtins.int
    width: builtins.float
    """"""
    emoji_size: builtins.int
    """"""
    def __init__(
        self,
        *,
        width: builtins.float = ...,
        emoji_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emoji_size", b"emoji_size", "width", b"width"]) -> None: ...

global___EmoteSize = EmoteSize

@typing_extensions.final
class Extend(google.protobuf.message.Message):
    """扩展字段，用于动态部分操作使用"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HistoryReportEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DYN_ID_STR_FIELD_NUMBER: builtins.int
    BUSINESS_ID_FIELD_NUMBER: builtins.int
    ORIG_DYN_ID_STR_FIELD_NUMBER: builtins.int
    ORIG_NAME_FIELD_NUMBER: builtins.int
    ORIG_IMG_URL_FIELD_NUMBER: builtins.int
    ORIG_DESC_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    ORIG_DYN_TYPE_FIELD_NUMBER: builtins.int
    SHARE_TYPE_FIELD_NUMBER: builtins.int
    SHARE_SCENE_FIELD_NUMBER: builtins.int
    IS_FAST_SHARE_FIELD_NUMBER: builtins.int
    R_TYPE_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    CARD_URL_FIELD_NUMBER: builtins.int
    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    ORIG_FACE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    OPUS_SUMMARY_FIELD_NUMBER: builtins.int
    ONLY_FANS_PROPERTY_FIELD_NUMBER: builtins.int
    FEATURE_GATE_FIELD_NUMBER: builtins.int
    IS_IN_AUDIT_FIELD_NUMBER: builtins.int
    HISTORY_REPORT_FIELD_NUMBER: builtins.int
    dyn_id_str: builtins.str
    """动态id"""
    business_id: builtins.str
    """业务方id"""
    orig_dyn_id_str: builtins.str
    """源动态id"""
    orig_name: builtins.str
    """转发卡：用户名"""
    orig_img_url: builtins.str
    """转发卡：图片url"""
    @property
    def orig_desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """转发卡：文字内容"""
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """填充文字内容"""
    orig_dyn_type: global___DynamicType.ValueType
    """被转发的源动态类型"""
    share_type: builtins.str
    """分享到站外展示类型"""
    share_scene: builtins.str
    """分享的场景"""
    is_fast_share: builtins.bool
    """是否快速转发"""
    r_type: builtins.int
    """r_type 分享和转发"""
    dyn_type: builtins.int
    """数据源的动态类型"""
    uid: builtins.int
    """用户id"""
    card_url: builtins.str
    """卡片跳转"""
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """透传字段"""
    orig_face: builtins.str
    """转发卡：用户头像"""
    @property
    def reply(self) -> global___ExtendReply:
        """评论跳转"""
    track_id: builtins.str
    """"""
    @property
    def opus_summary(self) -> global___ModuleOpusSummary:
        """"""
    @property
    def only_fans_property(self) -> global___OnlyFansProperty:
        """"""
    @property
    def feature_gate(self) -> global___DynFeatureGate:
        """"""
    is_in_audit: builtins.bool
    """"""
    @property
    def history_report(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        dyn_id_str: builtins.str = ...,
        business_id: builtins.str = ...,
        orig_dyn_id_str: builtins.str = ...,
        orig_name: builtins.str = ...,
        orig_img_url: builtins.str = ...,
        orig_desc: collections.abc.Iterable[global___Description] | None = ...,
        desc: collections.abc.Iterable[global___Description] | None = ...,
        orig_dyn_type: global___DynamicType.ValueType = ...,
        share_type: builtins.str = ...,
        share_scene: builtins.str = ...,
        is_fast_share: builtins.bool = ...,
        r_type: builtins.int = ...,
        dyn_type: builtins.int = ...,
        uid: builtins.int = ...,
        card_url: builtins.str = ...,
        source_content: google.protobuf.any_pb2.Any | None = ...,
        orig_face: builtins.str = ...,
        reply: global___ExtendReply | None = ...,
        track_id: builtins.str = ...,
        opus_summary: global___ModuleOpusSummary | None = ...,
        only_fans_property: global___OnlyFansProperty | None = ...,
        feature_gate: global___DynFeatureGate | None = ...,
        is_in_audit: builtins.bool = ...,
        history_report: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_gate", b"feature_gate", "only_fans_property", b"only_fans_property", "opus_summary", b"opus_summary", "reply", b"reply", "source_content", b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business_id", b"business_id", "card_url", b"card_url", "desc", b"desc", "dyn_id_str", b"dyn_id_str", "dyn_type", b"dyn_type", "feature_gate", b"feature_gate", "history_report", b"history_report", "is_fast_share", b"is_fast_share", "is_in_audit", b"is_in_audit", "only_fans_property", b"only_fans_property", "opus_summary", b"opus_summary", "orig_desc", b"orig_desc", "orig_dyn_id_str", b"orig_dyn_id_str", "orig_dyn_type", b"orig_dyn_type", "orig_face", b"orig_face", "orig_img_url", b"orig_img_url", "orig_name", b"orig_name", "r_type", b"r_type", "reply", b"reply", "share_scene", b"share_scene", "share_type", b"share_type", "source_content", b"source_content", "track_id", b"track_id", "uid", b"uid"]) -> None: ...

global___Extend = Extend

@typing_extensions.final
class ExtendReply(google.protobuf.message.Message):
    """评论扩展"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """基础跳转地址"""
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtendReplyParam]:
        """参数部分"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        params: collections.abc.Iterable[global___ExtendReplyParam] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params", "uri", b"uri"]) -> None: ...

global___ExtendReply = ExtendReply

@typing_extensions.final
class ExtendReplyParam(google.protobuf.message.Message):
    """评论扩展参数部分"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """参数名"""
    value: builtins.str
    """参数值"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___ExtendReplyParam = ExtendReplyParam

@typing_extensions.final
class ExtInfoCommon(google.protobuf.message.Message):
    """动态-拓展小卡模块-通用小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    POI_TYPE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SUB_MODULE_FIELD_NUMBER: builtins.int
    ACTION_TEXT_FIELD_NUMBER: builtins.int
    ACTION_URL_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    IS_SHOW_LIGHT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    poi_type: builtins.int
    """poiType"""
    type: global___DynExtendType.ValueType
    """类型"""
    sub_module: builtins.str
    """客户端埋点用"""
    action_text: builtins.str
    """行动点文案"""
    action_url: builtins.str
    """行动点链接"""
    rid: builtins.int
    """资源rid"""
    is_show_light: builtins.bool
    """轻浏览是否展示"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        poi_type: builtins.int = ...,
        type: global___DynExtendType.ValueType = ...,
        sub_module: builtins.str = ...,
        action_text: builtins.str = ...,
        action_url: builtins.str = ...,
        rid: builtins.int = ...,
        is_show_light: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_text", b"action_text", "action_url", b"action_url", "icon", b"icon", "is_show_light", b"is_show_light", "poi_type", b"poi_type", "rid", b"rid", "sub_module", b"sub_module", "title", b"title", "type", b"type", "uri", b"uri"]) -> None: ...

global___ExtInfoCommon = ExtInfoCommon

@typing_extensions.final
class ExtInfoGame(google.protobuf.message.Message):
    """动态-拓展小卡模块-游戏小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoGame = ExtInfoGame

@typing_extensions.final
class ExtInfoHot(google.protobuf.message.Message):
    """动态-拓展小卡模块-热门小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoHot = ExtInfoHot

@typing_extensions.final
class ExtInfoLBS(google.protobuf.message.Message):
    """动态-拓展小卡模块-lbs小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    POI_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    poi_type: builtins.int
    """poiType"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        poi_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "poi_type", b"poi_type", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoLBS = ExtInfoLBS

@typing_extensions.final
class ExtInfoOGV(google.protobuf.message.Message):
    """动态-拓展小卡模块-ogv小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_OGV_FIELD_NUMBER: builtins.int
    @property
    def info_ogv(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InfoOGV]:
        """ogv小卡"""
    def __init__(
        self,
        *,
        info_ogv: collections.abc.Iterable[global___InfoOGV] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["info_ogv", b"info_ogv"]) -> None: ...

global___ExtInfoOGV = ExtInfoOGV

@typing_extensions.final
class ExtInfoTopic(google.protobuf.message.Message):
    """动态-拓展小卡模块-话题小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题-话题名"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___ExtInfoTopic = ExtInfoTopic

@typing_extensions.final
class FeedFilterReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset"]) -> None: ...

global___FeedFilterReply = FeedFilterReply

@typing_extensions.final
class FeedFilterReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    AD_PARAM_FIELD_NUMBER: builtins.int
    COLD_START_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    offset: builtins.str
    """"""
    tab: builtins.str
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    @property
    def ad_param(self) -> global___AdParam:
        """"""
    cold_start: builtins.int
    """"""
    page: builtins.int
    """"""
    def __init__(
        self,
        *,
        offset: builtins.str = ...,
        tab: builtins.str = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        ad_param: global___AdParam | None = ...,
        cold_start: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_param", b"ad_param", "cold_start", b"cold_start", "local_time", b"local_time", "offset", b"offset", "page", b"page", "player_args", b"player_args", "tab", b"tab"]) -> None: ...

global___FeedFilterReq = FeedFilterReq

@typing_extensions.final
class FetchTabSettingReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    """"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___FetchTabSettingReply = FetchTabSettingReply

@typing_extensions.final
class FollowListItem(google.protobuf.message.Message):
    """视频页-我的追番-番剧信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NEW_EP_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """season_id"""
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    url: builtins.str
    """跳转链接"""
    @property
    def new_ep(self) -> global___NewEP:
        """new_ep"""
    sub_title: builtins.str
    """子标题"""
    pos: builtins.int
    """卡片位次"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        url: builtins.str = ...,
        new_ep: global___NewEP | None = ...,
        sub_title: builtins.str = ...,
        pos: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_ep", b"new_ep"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "new_ep", b"new_ep", "pos", b"pos", "season_id", b"season_id", "sub_title", b"sub_title", "title", b"title", "url", b"url"]) -> None: ...

global___FollowListItem = FollowListItem

@typing_extensions.final
class GoodsItem(google.protobuf.message.Message):
    """动态-附加卡-商品卡-商品"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    SCHEMA_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    JUMP_DESC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BRIEF_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    OPEN_WHITE_LIST_FIELD_NUMBER: builtins.int
    USER_WEB_V2_FIELD_NUMBER: builtins.int
    AD_MARK_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """图片"""
    schema_package_name: builtins.str
    """schemaPackageName(Android用)"""
    source_type: builtins.int
    """商品类型
    1:淘宝 2:会员购
    """
    jump_url: builtins.str
    """跳转链接"""
    jump_desc: builtins.str
    """跳转文案"""
    title: builtins.str
    """标题"""
    brief: builtins.str
    """摘要"""
    price: builtins.str
    """价格"""
    item_id: builtins.int
    """item_id"""
    schema_url: builtins.str
    """schema_url"""
    @property
    def open_white_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """open_white_list"""
    user_web_v2: builtins.bool
    """use_web_v2"""
    ad_mark: builtins.str
    """ad mark"""
    app_name: builtins.str
    """"""
    jump_type: global___GoodsJumpType.ValueType
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        schema_package_name: builtins.str = ...,
        source_type: builtins.int = ...,
        jump_url: builtins.str = ...,
        jump_desc: builtins.str = ...,
        title: builtins.str = ...,
        brief: builtins.str = ...,
        price: builtins.str = ...,
        item_id: builtins.int = ...,
        schema_url: builtins.str = ...,
        open_white_list: collections.abc.Iterable[builtins.str] | None = ...,
        user_web_v2: builtins.bool = ...,
        ad_mark: builtins.str = ...,
        app_name: builtins.str = ...,
        jump_type: global___GoodsJumpType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_mark", b"ad_mark", "app_name", b"app_name", "brief", b"brief", "cover", b"cover", "item_id", b"item_id", "jump_desc", b"jump_desc", "jump_type", b"jump_type", "jump_url", b"jump_url", "open_white_list", b"open_white_list", "price", b"price", "schema_package_name", b"schema_package_name", "schema_url", b"schema_url", "source_type", b"source_type", "title", b"title", "user_web_v2", b"user_web_v2"]) -> None: ...

global___GoodsItem = GoodsItem

@typing_extensions.final
class GuideBarInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    JUMP_PAGE_FIELD_NUMBER: builtins.int
    JUMP_POSITION_FIELD_NUMBER: builtins.int
    show: builtins.int
    """"""
    page: builtins.int
    """"""
    position: builtins.int
    """"""
    desc: builtins.str
    """"""
    jump_page: builtins.int
    """"""
    jump_position: builtins.int
    """"""
    def __init__(
        self,
        *,
        show: builtins.int = ...,
        page: builtins.int = ...,
        position: builtins.int = ...,
        desc: builtins.str = ...,
        jump_page: builtins.int = ...,
        jump_position: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "jump_page", b"jump_page", "jump_position", b"jump_position", "page", b"page", "position", b"position", "show", b"show"]) -> None: ...

global___GuideBarInfo = GuideBarInfo

@typing_extensions.final
class HighlightText(google.protobuf.message.Message):
    """高亮文本"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_STYLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    text: builtins.str
    """展示文本"""
    text_style: global___HighlightTextStyle.ValueType
    """高亮类型"""
    jump_url: builtins.str
    """"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_style: global___HighlightTextStyle.ValueType = ...,
        jump_url: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "jump_url", b"jump_url", "text", b"text", "text_style", b"text_style"]) -> None: ...

global___HighlightText = HighlightText

@typing_extensions.final
class HomeSubscribeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_FIELD_NUMBER: builtins.int
    online: builtins.int
    """"""
    def __init__(
        self,
        *,
        online: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["online", b"online"]) -> None: ...

global___HomeSubscribeReply = HomeSubscribeReply

@typing_extensions.final
class HomeSubscribeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name"]) -> None: ...

global___HomeSubscribeReq = HomeSubscribeReq

@typing_extensions.final
class IconBadge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_BG_URL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon_bg_url: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_bg_url: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_bg_url", b"icon_bg_url", "text", b"text"]) -> None: ...

global___IconBadge = IconBadge

@typing_extensions.final
class IconButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ICON_HEAD_FIELD_NUMBER: builtins.int
    ICON_TAIL_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    icon_head: builtins.str
    """"""
    icon_tail: builtins.str
    """"""
    jump_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        icon_head: builtins.str = ...,
        icon_tail: builtins.str = ...,
        jump_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_head", b"icon_head", "icon_tail", b"icon_tail", "jump_uri", b"jump_uri", "text", b"text"]) -> None: ...

global___IconButton = IconButton

@typing_extensions.final
class ImageSet(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMG_DAY_FIELD_NUMBER: builtins.int
    IMG_DARK_FIELD_NUMBER: builtins.int
    img_day: builtins.str
    """"""
    img_dark: builtins.str
    """"""
    def __init__(
        self,
        *,
        img_day: builtins.str = ...,
        img_dark: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["img_dark", b"img_dark", "img_day", b"img_day"]) -> None: ...

global___ImageSet = ImageSet

@typing_extensions.final
class ImgInlineCfg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    width: builtins.float
    """"""
    height: builtins.float
    """"""
    @property
    def color(self) -> global___Colors:
        """"""
    def __init__(
        self,
        *,
        width: builtins.float = ...,
        height: builtins.float = ...,
        color: global___Colors | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "height", b"height", "width", b"width"]) -> None: ...

global___ImgInlineCfg = ImgInlineCfg

@typing_extensions.final
class InfoOGV(google.protobuf.message.Message):
    """动态-拓展小卡模块-ogv小卡-(one of 片单、榜单、分区)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SUB_MODULE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    icon: builtins.str
    """小图标"""
    sub_module: builtins.str
    """客户端埋点用"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        sub_module: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "sub_module", b"sub_module", "title", b"title", "uri", b"uri"]) -> None: ...

global___InfoOGV = InfoOGV

@typing_extensions.final
class InteractionFace(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    face: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        face: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "mid", b"mid"]) -> None: ...

global___InteractionFace = InteractionFace

@typing_extensions.final
class InteractionItem(google.protobuf.message.Message):
    """外露交互模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    COMMENT_MID_FIELD_NUMBER: builtins.int
    FACES_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    icon_type: global___LocalIconType.ValueType
    """外露模块类型"""
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """外露模块文案"""
    uri: builtins.str
    """外露模块uri相关 根据type不同用法不同"""
    dynamic_id: builtins.str
    """动态id"""
    comment_mid: builtins.int
    """评论mid"""
    @property
    def faces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InteractionFace]:
        """"""
    @property
    def stat(self) -> global___InteractionStat:
        """"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_type: global___LocalIconType.ValueType = ...,
        desc: collections.abc.Iterable[global___Description] | None = ...,
        uri: builtins.str = ...,
        dynamic_id: builtins.str = ...,
        comment_mid: builtins.int = ...,
        faces: collections.abc.Iterable[global___InteractionFace] | None = ...,
        stat: global___InteractionStat | None = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment_mid", b"comment_mid", "desc", b"desc", "dynamic_id", b"dynamic_id", "faces", b"faces", "icon", b"icon", "icon_type", b"icon_type", "stat", b"stat", "uri", b"uri"]) -> None: ...

global___InteractionItem = InteractionItem

@typing_extensions.final
class InteractionStat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_FIELD_NUMBER: builtins.int
    like: builtins.int
    """"""
    def __init__(
        self,
        *,
        like: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["like", b"like"]) -> None: ...

global___InteractionStat = InteractionStat

@typing_extensions.final
class LbsPoiDetail(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BASE_PIC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    poi: builtins.str
    """"""
    type: builtins.int
    """"""
    @property
    def base_pic(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def cover(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    address: builtins.str
    """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        poi: builtins.str = ...,
        type: builtins.int = ...,
        base_pic: collections.abc.Iterable[builtins.str] | None = ...,
        cover: collections.abc.Iterable[builtins.str] | None = ...,
        address: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "base_pic", b"base_pic", "cover", b"cover", "poi", b"poi", "title", b"title", "type", b"type"]) -> None: ...

global___LbsPoiDetail = LbsPoiDetail

@typing_extensions.final
class LbsPoiReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    DETAIL_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    @property
    def detail(self) -> global___LbsPoiDetail:
        """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    def __init__(
        self,
        *,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
        detail: global___LbsPoiDetail | None = ...,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["detail", b"detail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail", b"detail", "has_more", b"has_more", "list", b"list", "offset", b"offset"]) -> None: ...

global___LbsPoiReply = LbsPoiReply

@typing_extensions.final
class LbsPoiReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    REFRESH_TYPE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    poi: builtins.str
    """"""
    type: builtins.int
    """"""
    offset: builtins.str
    """"""
    refresh_type: builtins.int
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        poi: builtins.str = ...,
        type: builtins.int = ...,
        offset: builtins.str = ...,
        refresh_type: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_time", b"local_time", "offset", b"offset", "player_args", b"player_args", "poi", b"poi", "refresh_type", b"refresh_type", "type", b"type"]) -> None: ...

global___LbsPoiReq = LbsPoiReq

@typing_extensions.final
class LegacyTopicFeedReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    SUPPORTED_SORT_TYPES_FIELD_NUMBER: builtins.int
    FEED_CARD_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    @property
    def supported_sort_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortType]:
        """"""
    @property
    def feed_card_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortType]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
        supported_sort_types: collections.abc.Iterable[global___SortType] | None = ...,
        feed_card_filters: collections.abc.Iterable[global___SortType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feed_card_filters", b"feed_card_filters", "has_more", b"has_more", "list", b"list", "offset", b"offset", "supported_sort_types", b"supported_sort_types"]) -> None: ...

global___LegacyTopicFeedReply = LegacyTopicFeedReply

@typing_extensions.final
class LegacyTopicFeedReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    SORT_TYPE_FIELD_NUMBER: builtins.int
    CARD_FILTER_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    topic_name: builtins.str
    """"""
    offset: builtins.str
    """"""
    @property
    def sort_type(self) -> global___SortType:
        """"""
    @property
    def card_filter(self) -> global___SortType:
        """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
        offset: builtins.str = ...,
        sort_type: global___SortType | None = ...,
        card_filter: global___SortType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_filter", b"card_filter", "sort_type", b"sort_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_filter", b"card_filter", "offset", b"offset", "sort_type", b"sort_type", "topic_id", b"topic_id", "topic_name", b"topic_name"]) -> None: ...

global___LegacyTopicFeedReq = LegacyTopicFeedReq

@typing_extensions.final
class LikeAnimation(google.protobuf.message.Message):
    """点赞动画"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_FIELD_NUMBER: builtins.int
    PROC_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    LIKE_ICON_ID_FIELD_NUMBER: builtins.int
    begin: builtins.str
    """开始动画"""
    proc: builtins.str
    """过程动画"""
    end: builtins.str
    """结束动画"""
    like_icon_id: builtins.int
    """id"""
    def __init__(
        self,
        *,
        begin: builtins.str = ...,
        proc: builtins.str = ...,
        end: builtins.str = ...,
        like_icon_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin", b"begin", "end", b"end", "like_icon_id", b"like_icon_id", "proc", b"proc"]) -> None: ...

global___LikeAnimation = LikeAnimation

@typing_extensions.final
class LikeInfo(google.protobuf.message.Message):
    """点赞拓展信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANIMATION_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    @property
    def animation(self) -> global___LikeAnimation:
        """点赞动画"""
    is_like: builtins.bool
    """是否点赞"""
    def __init__(
        self,
        *,
        animation: global___LikeAnimation | None = ...,
        is_like: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animation", b"animation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animation", b"animation", "is_like", b"is_like"]) -> None: ...

global___LikeInfo = LikeInfo

@typing_extensions.final
class LikeListReply(google.protobuf.message.Message):
    """点赞列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleAuthor]:
        """用户模块列表"""
    has_more: builtins.bool
    """是否还有更多数据"""
    total_count: builtins.int
    """点赞总数"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___ModuleAuthor] | None = ...,
        has_more: builtins.bool = ...,
        total_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "total_count", b"total_count"]) -> None: ...

global___LikeListReply = LikeListReply

@typing_extensions.final
class LikeListReq(google.protobuf.message.Message):
    """点赞列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    UID_OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    dynamic_id: builtins.str
    """动态ID"""
    dyn_type: builtins.int
    """动态类型"""
    rid: builtins.int
    """业务方资源id"""
    uid_offset: builtins.int
    """上一页最后一个uid"""
    page: builtins.int
    """下拉页数"""
    def __init__(
        self,
        *,
        dynamic_id: builtins.str = ...,
        dyn_type: builtins.int = ...,
        rid: builtins.int = ...,
        uid_offset: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_type", b"dyn_type", "dynamic_id", b"dynamic_id", "page", b"page", "rid", b"rid", "uid_offset", b"uid_offset"]) -> None: ...

global___LikeListReq = LikeListReq

@typing_extensions.final
class LikeUser(google.protobuf.message.Message):
    """点赞用户"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    UNAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    uname: builtins.str
    """用户昵称"""
    uri: builtins.str
    """点击跳转链接"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        uname: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uid", b"uid", "uname", b"uname", "uri", b"uri"]) -> None: ...

global___LikeUser = LikeUser

@typing_extensions.final
class LineParagraph(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIC_FIELD_NUMBER: builtins.int
    @property
    def pic(self) -> global___MdlDynDrawItem:
        """"""
    def __init__(
        self,
        *,
        pic: global___MdlDynDrawItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pic", b"pic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pic", b"pic"]) -> None: ...

global___LineParagraph = LineParagraph

@typing_extensions.final
class LinkNode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_TEXT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    ICON_SUFFIX_FIELD_NUMBER: builtins.int
    LINK_TYPE_FIELD_NUMBER: builtins.int
    LINK_TYPE_ENUM_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    GOODS_ITEM_FIELD_NUMBER: builtins.int
    NOTE_VIDEO_TS_FIELD_NUMBER: builtins.int
    show_text: builtins.str
    """"""
    link: builtins.str
    """"""
    icon: builtins.str
    """"""
    icon_suffix: builtins.str
    """"""
    link_type: builtins.str
    """"""
    link_type_enum: global___LinkNodeType.ValueType
    """"""
    biz_id: builtins.str
    """"""
    timestamp: builtins.int
    """"""
    @property
    def goods_item(self) -> global___GoodsItem:
        """"""
    @property
    def note_video_ts(self) -> global___NoteVideoTS:
        """"""
    def __init__(
        self,
        *,
        show_text: builtins.str = ...,
        link: builtins.str = ...,
        icon: builtins.str = ...,
        icon_suffix: builtins.str = ...,
        link_type: builtins.str = ...,
        link_type_enum: global___LinkNodeType.ValueType = ...,
        biz_id: builtins.str = ...,
        timestamp: builtins.int = ...,
        goods_item: global___GoodsItem | None = ...,
        note_video_ts: global___NoteVideoTS | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["goods_item", b"goods_item", "note_video_ts", b"note_video_ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "goods_item", b"goods_item", "icon", b"icon", "icon_suffix", b"icon_suffix", "link", b"link", "link_type", b"link_type", "link_type_enum", b"link_type_enum", "note_video_ts", b"note_video_ts", "show_text", b"show_text", "timestamp", b"timestamp"]) -> None: ...

global___LinkNode = LinkNode

@typing_extensions.final
class LiveInfo(google.protobuf.message.Message):
    """直播信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LIVING_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    is_living: builtins.int
    """是否在直播
    0:未直播 1:正在直播 (废弃)
    """
    uri: builtins.str
    """跳转链接"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    def __init__(
        self,
        *,
        is_living: builtins.int = ...,
        uri: builtins.str = ...,
        live_state: global___LiveState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_living", b"is_living", "live_state", b"live_state", "uri", b"uri"]) -> None: ...

global___LiveInfo = LiveInfo

@typing_extensions.final
class LivePendant(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    PENDANT_ID_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    icon: builtins.str
    """"""
    pendant_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        icon: builtins.str = ...,
        pendant_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "pendant_id", b"pendant_id", "text", b"text"]) -> None: ...

global___LivePendant = LivePendant

@typing_extensions.final
class MatchTeam(google.protobuf.message.Message):
    """动态-附加卡-电竞卡-战队"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    NIGHT_COLOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """战队ID"""
    name: builtins.str
    """战队名"""
    cover: builtins.str
    """战队图标"""
    color: builtins.str
    """日间色值"""
    night_color: builtins.str
    """夜间色值"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        cover: builtins.str = ...,
        color: builtins.str = ...,
        night_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "cover", b"cover", "id", b"id", "name", b"name", "night_color", b"night_color"]) -> None: ...

global___MatchTeam = MatchTeam

@typing_extensions.final
class MdlDynApplet(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-小程序/小游戏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """小程序id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """主标题"""
    sub_title: builtins.str
    """副标题"""
    cover: builtins.str
    """封面图"""
    icon: builtins.str
    """小程序icon"""
    label: builtins.str
    """小程序标题"""
    button_title: builtins.str
    """按钮文案"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
        cover: builtins.str = ...,
        icon: builtins.str = ...,
        label: builtins.str = ...,
        button_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_title", b"button_title", "cover", b"cover", "icon", b"icon", "id", b"id", "label", b"label", "sub_title", b"sub_title", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynApplet = MdlDynApplet

@typing_extensions.final
class MdlDynArchive(google.protobuf.message.Message):
    """动态-详情模块-稿件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    STYPE_FIELD_NUMBER: builtins.int
    ISPGC_FIELD_NUMBER: builtins.int
    INLINEURL_FIELD_NUMBER: builtins.int
    EPISODEID_FIELD_NUMBER: builtins.int
    SUBTYPE_FIELD_NUMBER: builtins.int
    PGCSEASONID_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    BADGE_CATEGORY_FIELD_NUMBER: builtins.int
    IS_FEATURE_FIELD_NUMBER: builtins.int
    RESERVE_TYPE_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    SHOW_PREMIERE_BADGE_FIELD_NUMBER: builtins.int
    PREMIERE_CARD_FIELD_NUMBER: builtins.int
    SHOW_PROGRESS_FIELD_NUMBER: builtins.int
    PART_DURATION_FIELD_NUMBER: builtins.int
    PART_PROGRESS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """秒开地址"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    cover_left_text_2: builtins.str
    """视频封面展示项 2"""
    cover_left_text_3: builtins.str
    """封面视频展示项 3"""
    avid: builtins.int
    """avid"""
    cid: builtins.int
    """cid"""
    media_type: global___MediaType.ValueType
    """视频源类型"""
    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标，多个角标之前有间距"""
    can_play: builtins.bool
    """是否能够自动播放"""
    stype: global___VideoType.ValueType
    """stype"""
    isPGC: builtins.bool
    """是否PGC"""
    inlineURL: builtins.str
    """inline播放地址"""
    EpisodeId: builtins.int
    """PGC的epid"""
    SubType: builtins.int
    """子类型"""
    PgcSeasonId: builtins.int
    """PGC的ssid"""
    play_icon: builtins.str
    """播放按钮"""
    duration: builtins.int
    """时长"""
    jump_url: builtins.str
    """跳转地址"""
    is_preview: builtins.bool
    """番剧是否为预览视频"""
    @property
    def badge_category(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """新角标，多个角标之前没有间距"""
    is_feature: builtins.bool
    """当前是否是pgc正片"""
    reserve_type: global___ReserveType.ValueType
    """是否是预约召回"""
    bvid: builtins.str
    """bvid"""
    view: builtins.int
    """播放数"""
    show_premiere_badge: builtins.bool
    """"""
    premiere_card: builtins.bool
    """"""
    show_progress: builtins.bool
    """"""
    part_duration: builtins.int
    """"""
    part_progress: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        media_type: global___MediaType.ValueType = ...,
        dimension: global___Dimension | None = ...,
        badge: collections.abc.Iterable[global___VideoBadge] | None = ...,
        can_play: builtins.bool = ...,
        stype: global___VideoType.ValueType = ...,
        isPGC: builtins.bool = ...,
        inlineURL: builtins.str = ...,
        EpisodeId: builtins.int = ...,
        SubType: builtins.int = ...,
        PgcSeasonId: builtins.int = ...,
        play_icon: builtins.str = ...,
        duration: builtins.int = ...,
        jump_url: builtins.str = ...,
        is_preview: builtins.bool = ...,
        badge_category: collections.abc.Iterable[global___VideoBadge] | None = ...,
        is_feature: builtins.bool = ...,
        reserve_type: global___ReserveType.ValueType = ...,
        bvid: builtins.str = ...,
        view: builtins.int = ...,
        show_premiere_badge: builtins.bool = ...,
        premiere_card: builtins.bool = ...,
        show_progress: builtins.bool = ...,
        part_duration: builtins.int = ...,
        part_progress: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["EpisodeId", b"EpisodeId", "PgcSeasonId", b"PgcSeasonId", "SubType", b"SubType", "avid", b"avid", "badge", b"badge", "badge_category", b"badge_category", "bvid", b"bvid", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "dimension", b"dimension", "duration", b"duration", "inlineURL", b"inlineURL", "isPGC", b"isPGC", "is_feature", b"is_feature", "is_preview", b"is_preview", "jump_url", b"jump_url", "media_type", b"media_type", "part_duration", b"part_duration", "part_progress", b"part_progress", "play_icon", b"play_icon", "premiere_card", b"premiere_card", "reserve_type", b"reserve_type", "show_premiere_badge", b"show_premiere_badge", "show_progress", b"show_progress", "stype", b"stype", "title", b"title", "uri", b"uri", "view", b"view"]) -> None: ...

global___MdlDynArchive = MdlDynArchive

@typing_extensions.final
class MdlDynArticle(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-专栏模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    TEMPLATEID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """专栏id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """标题"""
    desc: builtins.str
    """文案部分"""
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """配图"""
    label: builtins.str
    """阅读量标签"""
    templateID: builtins.int
    """模板类型"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        covers: collections.abc.Iterable[builtins.str] | None = ...,
        label: builtins.str = ...,
        templateID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["covers", b"covers", "desc", b"desc", "id", b"id", "label", b"label", "templateID", b"templateID", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynArticle = MdlDynArticle

@typing_extensions.final
class MdlDynCommon(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-通用"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BIZTYPE_FIELD_NUMBER: builtins.int
    SKETCHID_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """物料id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """标题"""
    desc: builtins.str
    """描述 漫画卡标题下第一行"""
    cover: builtins.str
    """封面"""
    label: builtins.str
    """标签1 漫画卡标题下第二行"""
    bizType: builtins.int
    """所属业务类型"""
    sketchID: builtins.int
    """镜像数据ID"""
    style: global___MdlDynCommonType.ValueType
    """卡片样式"""
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标"""
    @property
    def button(self) -> global___AdditionalButton:
        """"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        label: builtins.str = ...,
        bizType: builtins.int = ...,
        sketchID: builtins.int = ...,
        style: global___MdlDynCommonType.ValueType = ...,
        badge: collections.abc.Iterable[global___VideoBadge] | None = ...,
        button: global___AdditionalButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "bizType", b"bizType", "button", b"button", "cover", b"cover", "desc", b"desc", "label", b"label", "oid", b"oid", "sketchID", b"sketchID", "style", b"style", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCommon = MdlDynCommon

@typing_extensions.final
class MdlDynCourBatch(google.protobuf.message.Message):
    """动态-详情模块-付费课程批次"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    TEXT_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """跳转地址"""
    text_1: builtins.str
    """展示项 1(本集标题)"""
    text_2: builtins.str
    """展示项 2(更新了多少个视频)"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    play_icon: builtins.str
    """播放按钮"""
    can_play: builtins.bool
    """"""
    is_preview: builtins.bool
    """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_text_3: builtins.str
    """"""
    avid: builtins.int
    """"""
    cid: builtins.int
    """"""
    epid: builtins.int
    """"""
    duration: builtins.int
    """"""
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        text_1: builtins.str = ...,
        text_2: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        play_icon: builtins.str = ...,
        can_play: builtins.bool = ...,
        is_preview: builtins.bool = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        epid: builtins.int = ...,
        duration: builtins.int = ...,
        season_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid", b"avid", "badge", b"badge", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "duration", b"duration", "epid", b"epid", "is_preview", b"is_preview", "play_icon", b"play_icon", "season_id", b"season_id", "text_1", b"text_1", "text_2", b"text_2", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCourBatch = MdlDynCourBatch

@typing_extensions.final
class MdlDynCourSeason(google.protobuf.message.Message):
    """动态-详情模块-付费课程系列"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """跳转地址"""
    text_1: builtins.str
    """展示项 1(更新信息)"""
    desc: builtins.str
    """描述信息"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    play_icon: builtins.str
    """播放按钮"""
    can_play: builtins.bool
    """"""
    is_preview: builtins.bool
    """"""
    avid: builtins.int
    """"""
    cid: builtins.int
    """"""
    epid: builtins.int
    """"""
    duration: builtins.int
    """"""
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        text_1: builtins.str = ...,
        desc: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        play_icon: builtins.str = ...,
        can_play: builtins.bool = ...,
        is_preview: builtins.bool = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        epid: builtins.int = ...,
        duration: builtins.int = ...,
        season_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid", b"avid", "badge", b"badge", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "desc", b"desc", "duration", b"duration", "epid", b"epid", "is_preview", b"is_preview", "play_icon", b"play_icon", "season_id", b"season_id", "text_1", b"text_1", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCourSeason = MdlDynCourSeason

@typing_extensions.final
class MdlDynCourUp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    cover: builtins.str
    """"""
    uri: builtins.str
    """"""
    text_1: builtins.str
    """"""
    @property
    def badge(self) -> global___VideoBadge:
        """"""
    play_icon: builtins.str
    """"""
    can_play: builtins.bool
    """"""
    is_preview: builtins.bool
    """"""
    avid: builtins.int
    """"""
    cid: builtins.int
    """"""
    epid: builtins.int
    """"""
    duration: builtins.int
    """"""
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        text_1: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        play_icon: builtins.str = ...,
        can_play: builtins.bool = ...,
        is_preview: builtins.bool = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        epid: builtins.int = ...,
        duration: builtins.int = ...,
        season_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid", b"avid", "badge", b"badge", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "desc", b"desc", "duration", b"duration", "epid", b"epid", "is_preview", b"is_preview", "play_icon", b"play_icon", "season_id", b"season_id", "text_1", b"text_1", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynCourUp = MdlDynCourUp

@typing_extensions.final
class MdlDynDraw(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-图文模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IS_DRAW_FIRST_FIELD_NUMBER: builtins.int
    IS_BIG_COVER_FIELD_NUMBER: builtins.int
    IS_ARTICLE_COVER_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MdlDynDrawItem]:
        """图片"""
    uri: builtins.str
    """跳转地址"""
    id: builtins.int
    """图文ID"""
    is_draw_first: builtins.bool
    """"""
    is_big_cover: builtins.bool
    """"""
    is_article_cover: builtins.bool
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___MdlDynDrawItem] | None = ...,
        uri: builtins.str = ...,
        id: builtins.int = ...,
        is_draw_first: builtins.bool = ...,
        is_big_cover: builtins.bool = ...,
        is_article_cover: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "is_article_cover", b"is_article_cover", "is_big_cover", b"is_big_cover", "is_draw_first", b"is_draw_first", "items", b"items", "uri", b"uri"]) -> None: ...

global___MdlDynDraw = MdlDynDraw

@typing_extensions.final
class MdlDynDrawItem(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-图文"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SRC_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    src: builtins.str
    """图片链接"""
    width: builtins.int
    """图片宽度"""
    height: builtins.int
    """图片高度"""
    size: builtins.float
    """图片大小"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MdlDynDrawTag]:
        """图片标签"""
    def __init__(
        self,
        *,
        src: builtins.str = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        size: builtins.float = ...,
        tags: collections.abc.Iterable[global___MdlDynDrawTag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "size", b"size", "src", b"src", "tags", b"tags", "width", b"width"]) -> None: ...

global___MdlDynDrawItem = MdlDynDrawItem

@typing_extensions.final
class MdlDynDrawTag(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-图文-标签"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    type: global___MdlDynDrawTagType.ValueType
    """标签类型"""
    @property
    def item(self) -> global___MdlDynDrawTagItem:
        """标签详情"""
    def __init__(
        self,
        *,
        type: global___MdlDynDrawTagType.ValueType = ...,
        item: global___MdlDynDrawTagItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "type", b"type"]) -> None: ...

global___MdlDynDrawTag = MdlDynDrawTag

@typing_extensions.final
class MdlDynDrawTagItem(google.protobuf.message.Message):
    """动态列表部分-详情模块-图文-标签详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    POI_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """跳转链接"""
    text: builtins.str
    """标签内容"""
    x: builtins.int
    """坐标-x"""
    y: builtins.int
    """坐标-y"""
    orientation: builtins.int
    """方向"""
    source: builtins.int
    """来源
    0:未知 1:淘宝 2:自营
    """
    item_id: builtins.int
    """商品id"""
    mid: builtins.int
    """用户mid"""
    tid: builtins.int
    """话题id"""
    poi: builtins.str
    """lbs信息"""
    schema_url: builtins.str
    """商品标签链接"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        text: builtins.str = ...,
        x: builtins.int = ...,
        y: builtins.int = ...,
        orientation: builtins.int = ...,
        source: builtins.int = ...,
        item_id: builtins.int = ...,
        mid: builtins.int = ...,
        tid: builtins.int = ...,
        poi: builtins.str = ...,
        schema_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id", b"item_id", "mid", b"mid", "orientation", b"orientation", "poi", b"poi", "schema_url", b"schema_url", "source", b"source", "text", b"text", "tid", b"tid", "url", b"url", "x", b"x", "y", b"y"]) -> None: ...

global___MdlDynDrawTagItem = MdlDynDrawTagItem

@typing_extensions.final
class MdlDynForward(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-转发模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    RTYPE_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DynamicItem:
        """动态转发核心模块 套娃"""
    rtype: builtins.int
    """透传类型
    0:分享 1:转发
    """
    def __init__(
        self,
        *,
        item: global___DynamicItem | None = ...,
        rtype: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "rtype", b"rtype"]) -> None: ...

global___MdlDynForward = MdlDynForward

@typing_extensions.final
class MdlDynLive(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-直播"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_LABEL_FIELD_NUMBER: builtins.int
    COVER_LABEL2_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RESERVE_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """房间号"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """直播间标题"""
    cover: builtins.str
    """直播间封面"""
    cover_label: builtins.str
    """标题1 例: 陪伴学习"""
    cover_label2: builtins.str
    """标题2 例: 54.6万人气"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    @property
    def badge(self) -> global___VideoBadge:
        """直播角标"""
    reserve_type: global___ReserveType.ValueType
    """是否是预约召回"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_label: builtins.str = ...,
        cover_label2: builtins.str = ...,
        live_state: global___LiveState.ValueType = ...,
        badge: global___VideoBadge | None = ...,
        reserve_type: global___ReserveType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "cover_label", b"cover_label", "cover_label2", b"cover_label2", "id", b"id", "live_state", b"live_state", "reserve_type", b"reserve_type", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynLive = MdlDynLive

@typing_extensions.final
class MdlDynLiveRcmd(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-直播推荐"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    RESERVE_TYPE_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """直播数据"""
    reserve_type: global___ReserveType.ValueType
    """是否是预约召回"""
    @property
    def pendant(self) -> global___LivePendant:
        """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        reserve_type: global___ReserveType.ValueType = ...,
        pendant: global___LivePendant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pendant", b"pendant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "pendant", b"pendant", "reserve_type", b"reserve_type"]) -> None: ...

global___MdlDynLiveRcmd = MdlDynLiveRcmd

@typing_extensions.final
class MdlDynMedialist(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-播单"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_TYPE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """播单id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """主标题"""
    sub_title: builtins.str
    """副标题"""
    cover: builtins.str
    """封面图"""
    cover_type: builtins.int
    """封面类型"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_type: builtins.int = ...,
        badge: global___VideoBadge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "cover_type", b"cover_type", "id", b"id", "sub_title", b"sub_title", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynMedialist = MdlDynMedialist

@typing_extensions.final
class MdlDynMusic(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-音频模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LABEL1_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    id: builtins.int
    """音频id"""
    uri: builtins.str
    """跳转地址"""
    up_id: builtins.int
    """upId"""
    title: builtins.str
    """歌名"""
    cover: builtins.str
    """专辑封面"""
    label1: builtins.str
    """展示项1"""
    upper: builtins.str
    """upper"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uri: builtins.str = ...,
        up_id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        label1: builtins.str = ...,
        upper: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "id", b"id", "label1", b"label1", "title", b"title", "up_id", b"up_id", "upper", b"upper", "uri", b"uri"]) -> None: ...

global___MdlDynMusic = MdlDynMusic

@typing_extensions.final
class MdlDynPGC(google.protobuf.message.Message):
    """动态-详情模块-pgc"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    BADGE_CATEGORY_FIELD_NUMBER: builtins.int
    IS_FEATURE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """秒开地址"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    cover_left_text_2: builtins.str
    """视频封面展示项 2"""
    cover_left_text_3: builtins.str
    """封面视频展示项 3"""
    cid: builtins.int
    """cid"""
    season_id: builtins.int
    """season_id"""
    epid: builtins.int
    """epid"""
    aid: builtins.int
    """aid"""
    media_type: global___MediaType.ValueType
    """视频源类型"""
    sub_type: global___VideoSubType.ValueType
    """番剧类型"""
    is_preview: builtins.bool
    """番剧是否为预览视频"""
    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标，多个角标之前有间距"""
    can_play: builtins.bool
    """是否能够自动播放"""
    @property
    def season(self) -> global___PGCSeason:
        """season"""
    play_icon: builtins.str
    """播放按钮"""
    duration: builtins.int
    """时长"""
    jump_url: builtins.str
    """跳转地址"""
    @property
    def badge_category(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """新角标，多个角标之前没有间距"""
    is_feature: builtins.bool
    """当前是否是pgc正片"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        cid: builtins.int = ...,
        season_id: builtins.int = ...,
        epid: builtins.int = ...,
        aid: builtins.int = ...,
        media_type: global___MediaType.ValueType = ...,
        sub_type: global___VideoSubType.ValueType = ...,
        is_preview: builtins.bool = ...,
        dimension: global___Dimension | None = ...,
        badge: collections.abc.Iterable[global___VideoBadge] | None = ...,
        can_play: builtins.bool = ...,
        season: global___PGCSeason | None = ...,
        play_icon: builtins.str = ...,
        duration: builtins.int = ...,
        jump_url: builtins.str = ...,
        badge_category: collections.abc.Iterable[global___VideoBadge] | None = ...,
        is_feature: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension", "season", b"season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "badge", b"badge", "badge_category", b"badge_category", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "dimension", b"dimension", "duration", b"duration", "epid", b"epid", "is_feature", b"is_feature", "is_preview", b"is_preview", "jump_url", b"jump_url", "media_type", b"media_type", "play_icon", b"play_icon", "season", b"season", "season_id", b"season_id", "sub_type", b"sub_type", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynPGC = MdlDynPGC

@typing_extensions.final
class MdlDynSubscription(google.protobuf.message.Message):
    """动态列表渲染部分-详情模块-订阅卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AD_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AD_TITLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    TIPS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """卡片物料id"""
    ad_id: builtins.int
    """广告创意id"""
    uri: builtins.str
    """跳转地址"""
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    ad_title: builtins.str
    """广告标题"""
    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
    tips: builtins.str
    """小提示"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        ad_id: builtins.int = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        ad_title: builtins.str = ...,
        badge: global___VideoBadge | None = ...,
        tips: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_id", b"ad_id", "ad_title", b"ad_title", "badge", b"badge", "cover", b"cover", "id", b"id", "tips", b"tips", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynSubscription = MdlDynSubscription

@typing_extensions.final
class MdlDynSubscriptionNew(google.protobuf.message.Message):
    """动态新附加卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_FIELD_NUMBER: builtins.int
    DYN_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    DYN_LIVE_RCMD_FIELD_NUMBER: builtins.int
    style: global___MdlDynSubscriptionNewStyle.ValueType
    """样式类型"""
    @property
    def dyn_subscription(self) -> global___MdlDynSubscription:
        """"""
    @property
    def dyn_live_rcmd(self) -> global___MdlDynLiveRcmd:
        """直播推荐"""
    def __init__(
        self,
        *,
        style: global___MdlDynSubscriptionNewStyle.ValueType = ...,
        dyn_subscription: global___MdlDynSubscription | None = ...,
        dyn_live_rcmd: global___MdlDynLiveRcmd | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dyn_live_rcmd", b"dyn_live_rcmd", "dyn_subscription", b"dyn_subscription", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_live_rcmd", b"dyn_live_rcmd", "dyn_subscription", b"dyn_subscription", "item", b"item", "style", b"style"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["dyn_subscription", "dyn_live_rcmd"] | None: ...

global___MdlDynSubscriptionNew = MdlDynSubscriptionNew

@typing_extensions.final
class MdlDynTopicSet(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPICS_FIELD_NUMBER: builtins.int
    MORE_BTN_FIELD_NUMBER: builtins.int
    TOPIC_SET_ID_FIELD_NUMBER: builtins.int
    PUSH_ID_FIELD_NUMBER: builtins.int
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicItem]:
        """"""
    @property
    def more_btn(self) -> global___IconButton:
        """"""
    topic_set_id: builtins.int
    """"""
    push_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        topics: collections.abc.Iterable[global___TopicItem] | None = ...,
        more_btn: global___IconButton | None = ...,
        topic_set_id: builtins.int = ...,
        push_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["more_btn", b"more_btn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["more_btn", b"more_btn", "push_id", b"push_id", "topic_set_id", b"topic_set_id", "topics", b"topics"]) -> None: ...

global___MdlDynTopicSet = MdlDynTopicSet

@typing_extensions.final
class MdlDynUGCSeason(google.protobuf.message.Message):
    """动态列表渲染部分-UGC合集"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INLINEURL_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    PLAY_ICON_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    uri: builtins.str
    """秒开地址"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    cover_left_text_2: builtins.str
    """视频封面展示项 2"""
    cover_left_text_3: builtins.str
    """封面视频展示项 3"""
    id: builtins.int
    """卡片物料id"""
    inlineURL: builtins.str
    """inline播放地址"""
    can_play: builtins.bool
    """是否能够自动播放"""
    play_icon: builtins.str
    """播放按钮"""
    avid: builtins.int
    """avid"""
    cid: builtins.int
    """cid"""
    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
    duration: builtins.int
    """时长"""
    jump_url: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        id: builtins.int = ...,
        inlineURL: builtins.str = ...,
        can_play: builtins.bool = ...,
        play_icon: builtins.str = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        dimension: global___Dimension | None = ...,
        duration: builtins.int = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid", b"avid", "can_play", b"can_play", "cid", b"cid", "cover", b"cover", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "dimension", b"dimension", "duration", b"duration", "id", b"id", "inlineURL", b"inlineURL", "jump_url", b"jump_url", "play_icon", b"play_icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___MdlDynUGCSeason = MdlDynUGCSeason

@typing_extensions.final
class MixUpListItem(google.protobuf.message.Message):
    """查看更多-列表单条数据"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    SPECIAL_ATTENTION_FIELD_NUMBER: builtins.int
    REDDOT_STATE_FIELD_NUMBER: builtins.int
    LIVE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    PERMIRE_STATE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    special_attention: builtins.int
    """特别关注
    0:否 1:是
    """
    reddot_state: builtins.int
    """小红点状态
    0:没有 1:有
    """
    @property
    def live_info(self) -> global___MixUpListLiveItem:
        """直播信息"""
    name: builtins.str
    """昵称"""
    face: builtins.str
    """头像"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    permire_state: builtins.int
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        special_attention: builtins.int = ...,
        reddot_state: builtins.int = ...,
        live_info: global___MixUpListLiveItem | None = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        relation: global___Relation | None = ...,
        permire_state: builtins.int = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live_info", b"live_info", "official", b"official", "relation", b"relation", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "live_info", b"live_info", "name", b"name", "official", b"official", "permire_state", b"permire_state", "reddot_state", b"reddot_state", "relation", b"relation", "special_attention", b"special_attention", "uid", b"uid", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___MixUpListItem = MixUpListItem

@typing_extensions.final
class MixUpListLiveItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """直播状态
    0:未直播 1:直播中
    """
    room_id: builtins.int
    """房间号"""
    uri: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        status: builtins.bool = ...,
        room_id: builtins.int = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id", b"room_id", "status", b"status", "uri", b"uri"]) -> None: ...

global___MixUpListLiveItem = MixUpListLiveItem

@typing_extensions.final
class Module(google.protobuf.message.Message):
    """动态模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    MODULE_DISPUTE_FIELD_NUMBER: builtins.int
    MODULE_DESC_FIELD_NUMBER: builtins.int
    MODULE_DYNAMIC_FIELD_NUMBER: builtins.int
    MODULE_LIKEUSER_FIELD_NUMBER: builtins.int
    MODULE_EXTEND_FIELD_NUMBER: builtins.int
    MODULE_ADDITIONAL_FIELD_NUMBER: builtins.int
    MODULE_STAT_FIELD_NUMBER: builtins.int
    MODULE_FOLD_FIELD_NUMBER: builtins.int
    MODULE_COMMENT_FIELD_NUMBER: builtins.int
    MODULE_INTERACTION_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FORWARD_FIELD_NUMBER: builtins.int
    MODULE_AD_FIELD_NUMBER: builtins.int
    MODULE_BANNER_FIELD_NUMBER: builtins.int
    MODULE_ITEM_NULL_FIELD_NUMBER: builtins.int
    MODULE_SHARE_INFO_FIELD_NUMBER: builtins.int
    MODULE_RECOMMEND_FIELD_NUMBER: builtins.int
    MODULE_TOP_FIELD_NUMBER: builtins.int
    MODULE_BUTTOM_FIELD_NUMBER: builtins.int
    MODULE_STAT_FORWARD_FIELD_NUMBER: builtins.int
    MODULE_STORY_FIELD_NUMBER: builtins.int
    MODULE_TOPIC_FIELD_NUMBER: builtins.int
    MODULE_TOPIC_DETAILS_EXT_FIELD_NUMBER: builtins.int
    MODULE_TOP_TAG_FIELD_NUMBER: builtins.int
    MODULE_TOPIC_BRIEF_FIELD_NUMBER: builtins.int
    MODULE_TITLE_FIELD_NUMBER: builtins.int
    MODULE_BUTTON_FIELD_NUMBER: builtins.int
    MODULE_NOTICE_FIELD_NUMBER: builtins.int
    MODULE_OPUS_SUMMARY_FIELD_NUMBER: builtins.int
    MODULE_COPYRIGHT_FIELD_NUMBER: builtins.int
    MODULE_PARAGRAPH_FIELD_NUMBER: builtins.int
    MODULE_BLOCKED_FIELD_NUMBER: builtins.int
    MODULE_TEXT_NOTICE_FIELD_NUMBER: builtins.int
    MODULE_OPUS_COLLECTION_FIELD_NUMBER: builtins.int
    module_type: global___DynModuleType.ValueType
    """类型"""
    @property
    def module_author(self) -> global___ModuleAuthor:
        """用户模块 1"""
    @property
    def module_dispute(self) -> global___ModuleDispute:
        """争议黄条模块 2"""
    @property
    def module_desc(self) -> global___ModuleDesc:
        """动态正文模块 3"""
    @property
    def module_dynamic(self) -> global___ModuleDynamic:
        """动态卡模块 4"""
    @property
    def module_likeUser(self) -> global___ModuleLikeUser:
        """点赞外露(废弃)"""
    @property
    def module_extend(self) -> global___ModuleExtend:
        """小卡模块 6"""
    @property
    def module_additional(self) -> global___ModuleAdditional:
        """大卡模块 5"""
    @property
    def module_stat(self) -> global___ModuleStat:
        """计数模块 8"""
    @property
    def module_fold(self) -> global___ModuleFold:
        """折叠模块 9"""
    @property
    def module_comment(self) -> global___ModuleComment:
        """评论外露(废弃)"""
    @property
    def module_interaction(self) -> global___ModuleInteraction:
        """外露交互模块(点赞、评论) 7"""
    @property
    def module_author_forward(self) -> global___ModuleAuthorForward:
        """转发卡-原卡用户模块"""
    @property
    def module_ad(self) -> global___ModuleAd:
        """广告卡"""
    @property
    def module_banner(self) -> global___ModuleBanner:
        """通栏"""
    @property
    def module_item_null(self) -> global___ModuleItemNull:
        """获取物料失败"""
    @property
    def module_share_info(self) -> global___ModuleShareInfo:
        """分享组件"""
    @property
    def module_recommend(self) -> global___ModuleRecommend:
        """相关推荐模块"""
    @property
    def module_top(self) -> global___ModuleTop:
        """顶部模块"""
    @property
    def module_buttom(self) -> global___ModuleButtom:
        """底部模块"""
    @property
    def module_stat_forward(self) -> global___ModuleStat:
        """转发卡计数模块"""
    @property
    def module_story(self) -> global___ModuleStory:
        """"""
    @property
    def module_topic(self) -> global___ModuleTopic:
        """"""
    @property
    def module_topic_details_ext(self) -> global___ModuleTopicDetailsExt:
        """"""
    @property
    def module_top_tag(self) -> global___ModuleTopTag:
        """"""
    @property
    def module_topic_brief(self) -> global___ModuleTopicBrief:
        """"""
    @property
    def module_title(self) -> global___ModuleTitle:
        """"""
    @property
    def module_button(self) -> global___ModuleButton:
        """"""
    @property
    def module_notice(self) -> global___ModuleNotice:
        """"""
    @property
    def module_opus_summary(self) -> global___ModuleOpusSummary:
        """"""
    @property
    def module_copyright(self) -> global___ModuleCopyright:
        """"""
    @property
    def module_paragraph(self) -> global___ModuleParagraph:
        """"""
    @property
    def module_blocked(self) -> global___ModuleBlocked:
        """"""
    @property
    def module_text_notice(self) -> global___ModuleTextNotice:
        """"""
    @property
    def module_opus_collection(self) -> global___ModuleOpusCollection:
        """"""
    def __init__(
        self,
        *,
        module_type: global___DynModuleType.ValueType = ...,
        module_author: global___ModuleAuthor | None = ...,
        module_dispute: global___ModuleDispute | None = ...,
        module_desc: global___ModuleDesc | None = ...,
        module_dynamic: global___ModuleDynamic | None = ...,
        module_likeUser: global___ModuleLikeUser | None = ...,
        module_extend: global___ModuleExtend | None = ...,
        module_additional: global___ModuleAdditional | None = ...,
        module_stat: global___ModuleStat | None = ...,
        module_fold: global___ModuleFold | None = ...,
        module_comment: global___ModuleComment | None = ...,
        module_interaction: global___ModuleInteraction | None = ...,
        module_author_forward: global___ModuleAuthorForward | None = ...,
        module_ad: global___ModuleAd | None = ...,
        module_banner: global___ModuleBanner | None = ...,
        module_item_null: global___ModuleItemNull | None = ...,
        module_share_info: global___ModuleShareInfo | None = ...,
        module_recommend: global___ModuleRecommend | None = ...,
        module_top: global___ModuleTop | None = ...,
        module_buttom: global___ModuleButtom | None = ...,
        module_stat_forward: global___ModuleStat | None = ...,
        module_story: global___ModuleStory | None = ...,
        module_topic: global___ModuleTopic | None = ...,
        module_topic_details_ext: global___ModuleTopicDetailsExt | None = ...,
        module_top_tag: global___ModuleTopTag | None = ...,
        module_topic_brief: global___ModuleTopicBrief | None = ...,
        module_title: global___ModuleTitle | None = ...,
        module_button: global___ModuleButton | None = ...,
        module_notice: global___ModuleNotice | None = ...,
        module_opus_summary: global___ModuleOpusSummary | None = ...,
        module_copyright: global___ModuleCopyright | None = ...,
        module_paragraph: global___ModuleParagraph | None = ...,
        module_blocked: global___ModuleBlocked | None = ...,
        module_text_notice: global___ModuleTextNotice | None = ...,
        module_opus_collection: global___ModuleOpusCollection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_ad", b"module_ad", "module_additional", b"module_additional", "module_author", b"module_author", "module_author_forward", b"module_author_forward", "module_banner", b"module_banner", "module_blocked", b"module_blocked", "module_buttom", b"module_buttom", "module_button", b"module_button", "module_comment", b"module_comment", "module_copyright", b"module_copyright", "module_desc", b"module_desc", "module_dispute", b"module_dispute", "module_dynamic", b"module_dynamic", "module_extend", b"module_extend", "module_fold", b"module_fold", "module_interaction", b"module_interaction", "module_item", b"module_item", "module_item_null", b"module_item_null", "module_likeUser", b"module_likeUser", "module_notice", b"module_notice", "module_opus_collection", b"module_opus_collection", "module_opus_summary", b"module_opus_summary", "module_paragraph", b"module_paragraph", "module_recommend", b"module_recommend", "module_share_info", b"module_share_info", "module_stat", b"module_stat", "module_stat_forward", b"module_stat_forward", "module_story", b"module_story", "module_text_notice", b"module_text_notice", "module_title", b"module_title", "module_top", b"module_top", "module_top_tag", b"module_top_tag", "module_topic", b"module_topic", "module_topic_brief", b"module_topic_brief", "module_topic_details_ext", b"module_topic_details_ext"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_ad", b"module_ad", "module_additional", b"module_additional", "module_author", b"module_author", "module_author_forward", b"module_author_forward", "module_banner", b"module_banner", "module_blocked", b"module_blocked", "module_buttom", b"module_buttom", "module_button", b"module_button", "module_comment", b"module_comment", "module_copyright", b"module_copyright", "module_desc", b"module_desc", "module_dispute", b"module_dispute", "module_dynamic", b"module_dynamic", "module_extend", b"module_extend", "module_fold", b"module_fold", "module_interaction", b"module_interaction", "module_item", b"module_item", "module_item_null", b"module_item_null", "module_likeUser", b"module_likeUser", "module_notice", b"module_notice", "module_opus_collection", b"module_opus_collection", "module_opus_summary", b"module_opus_summary", "module_paragraph", b"module_paragraph", "module_recommend", b"module_recommend", "module_share_info", b"module_share_info", "module_stat", b"module_stat", "module_stat_forward", b"module_stat_forward", "module_story", b"module_story", "module_text_notice", b"module_text_notice", "module_title", b"module_title", "module_top", b"module_top", "module_top_tag", b"module_top_tag", "module_topic", b"module_topic", "module_topic_brief", b"module_topic_brief", "module_topic_details_ext", b"module_topic_details_ext", "module_type", b"module_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item", b"module_item"]) -> typing_extensions.Literal["module_author", "module_dispute", "module_desc", "module_dynamic", "module_likeUser", "module_extend", "module_additional", "module_stat", "module_fold", "module_comment", "module_interaction", "module_author_forward", "module_ad", "module_banner", "module_item_null", "module_share_info", "module_recommend", "module_top", "module_buttom", "module_stat_forward", "module_story", "module_topic", "module_topic_details_ext", "module_top_tag", "module_topic_brief", "module_title", "module_button", "module_notice", "module_opus_summary", "module_copyright", "module_paragraph", "module_blocked", "module_text_notice", "module_opus_collection"] | None: ...

global___Module = Module

@typing_extensions.final
class ModuleAd(google.protobuf.message.Message):
    """动态列表-用户模块-广告卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    AD_CONTENT_TYPE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT3_FIELD_NUMBER: builtins.int
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """广告透传信息"""
    @property
    def module_author(self) -> global___ModuleAuthor:
        """用户模块"""
    ad_content_type: builtins.int
    """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_text3: builtins.str
    """"""
    def __init__(
        self,
        *,
        source_content: google.protobuf.any_pb2.Any | None = ...,
        module_author: global___ModuleAuthor | None = ...,
        ad_content_type: builtins.int = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_text3: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_author", b"module_author", "source_content", b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_content_type", b"ad_content_type", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "cover_left_text3", b"cover_left_text3", "module_author", b"module_author", "source_content", b"source_content"]) -> None: ...

global___ModuleAd = ModuleAd

@typing_extensions.final
class ModuleAdditional(google.protobuf.message.Message):
    """动态-附加卡模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    PGC_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    COMMON_FIELD_NUMBER: builtins.int
    ESPORT_FIELD_NUMBER: builtins.int
    VOTE2_FIELD_NUMBER: builtins.int
    UGC_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    ARTICLE_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    NEED_WRITE_CALENDER_FIELD_NUMBER: builtins.int
    type: global___AdditionalType.ValueType
    """类型"""
    @property
    def pgc(self) -> global___AdditionalPGC:
        """废弃"""
    @property
    def goods(self) -> global___AdditionGoods:
        """"""
    @property
    def vote(self) -> global___AdditionVote:
        """废弃"""
    @property
    def common(self) -> global___AdditionCommon:
        """"""
    @property
    def esport(self) -> global___AdditionEsport:
        """"""
    @property
    def vote2(self) -> global___AdditionVote2:
        """投票"""
    @property
    def ugc(self) -> global___AdditionUgc:
        """"""
    @property
    def up(self) -> global___AdditionUP:
        """up主预约发布卡"""
    @property
    def article(self) -> global___AdditionArticle:
        """"""
    @property
    def live(self) -> global___AdditionLiveRoom:
        """"""
    rid: builtins.int
    """附加卡物料ID"""
    need_write_calender: builtins.bool
    """"""
    def __init__(
        self,
        *,
        type: global___AdditionalType.ValueType = ...,
        pgc: global___AdditionalPGC | None = ...,
        goods: global___AdditionGoods | None = ...,
        vote: global___AdditionVote | None = ...,
        common: global___AdditionCommon | None = ...,
        esport: global___AdditionEsport | None = ...,
        vote2: global___AdditionVote2 | None = ...,
        ugc: global___AdditionUgc | None = ...,
        up: global___AdditionUP | None = ...,
        article: global___AdditionArticle | None = ...,
        live: global___AdditionLiveRoom | None = ...,
        rid: builtins.int = ...,
        need_write_calender: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["article", b"article", "common", b"common", "esport", b"esport", "goods", b"goods", "item", b"item", "live", b"live", "pgc", b"pgc", "ugc", b"ugc", "up", b"up", "vote", b"vote", "vote2", b"vote2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["article", b"article", "common", b"common", "esport", b"esport", "goods", b"goods", "item", b"item", "live", b"live", "need_write_calender", b"need_write_calender", "pgc", b"pgc", "rid", b"rid", "type", b"type", "ugc", b"ugc", "up", b"up", "vote", b"vote", "vote2", b"vote2"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["pgc", "goods", "vote", "common", "esport", "vote2", "ugc", "up", "article", "live"] | None: ...

global___ModuleAdditional = ModuleAdditional

@typing_extensions.final
class ModuleAuthor(google.protobuf.message.Message):
    """动态-发布人模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    PTIME_LABEL_TEXT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    DECORATE_CARD_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TP_LIST_FIELD_NUMBER: builtins.int
    BADGE_TYPE_FIELD_NUMBER: builtins.int
    BADGE_BUTTON_FIELD_NUMBER: builtins.int
    ATTEND_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_FIELD_NUMBER: builtins.int
    IS_TOP_FIELD_NUMBER: builtins.int
    PTIME_LOCATION_TEXT_FIELD_NUMBER: builtins.int
    SHOW_LEVEL_FIELD_NUMBER: builtins.int
    ONLY_FANS_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    ptime_label_text: builtins.str
    """时间标签"""
    @property
    def author(self) -> global___UserInfo:
        """用户详情"""
    @property
    def decorate_card(self) -> global___DecorateCard:
        """装扮卡片"""
    uri: builtins.str
    """点击跳转链接"""
    @property
    def tp_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """右侧操作区域 - 三点样式"""
    badge_type: global___ModuleAuthorBadgeType.ValueType
    """右侧操作区域样式枚举"""
    @property
    def badge_button(self) -> global___ModuleAuthorBadgeButton:
        """右侧操作区域 - 按钮样式"""
    attend: builtins.int
    """是否关注
    1:关注 0:不关注 默认0，注：点赞列表使用，其他场景不使用该字段
    """
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    @property
    def weight(self) -> global___Weight:
        """右侧操作区域 - 提权样式"""
    show_follow: builtins.bool
    """是否展示关注"""
    is_top: builtins.bool
    """是否置顶"""
    ptime_location_text: builtins.str
    """ip属地"""
    show_level: builtins.bool
    """"""
    @property
    def only_fans(self) -> global___OnlyFans:
        """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        ptime_label_text: builtins.str = ...,
        author: global___UserInfo | None = ...,
        decorate_card: global___DecorateCard | None = ...,
        uri: builtins.str = ...,
        tp_list: collections.abc.Iterable[global___ThreePointItem] | None = ...,
        badge_type: global___ModuleAuthorBadgeType.ValueType = ...,
        badge_button: global___ModuleAuthorBadgeButton | None = ...,
        attend: builtins.int = ...,
        relation: global___Relation | None = ...,
        weight: global___Weight | None = ...,
        show_follow: builtins.bool = ...,
        is_top: builtins.bool = ...,
        ptime_location_text: builtins.str = ...,
        show_level: builtins.bool = ...,
        only_fans: global___OnlyFans | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "badge_button", b"badge_button", "decorate_card", b"decorate_card", "only_fans", b"only_fans", "relation", b"relation", "weight", b"weight"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attend", b"attend", "author", b"author", "badge_button", b"badge_button", "badge_type", b"badge_type", "decorate_card", b"decorate_card", "is_top", b"is_top", "mid", b"mid", "only_fans", b"only_fans", "ptime_label_text", b"ptime_label_text", "ptime_location_text", b"ptime_location_text", "relation", b"relation", "show_follow", b"show_follow", "show_level", b"show_level", "tp_list", b"tp_list", "uri", b"uri", "weight", b"weight"]) -> None: ...

global___ModuleAuthor = ModuleAuthor

@typing_extensions.final
class ModuleAuthorBadgeButton(google.protobuf.message.Message):
    """动态列表渲染部分-用户模块-按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """图标"""
    title: builtins.str
    """文案"""
    state: builtins.int
    """状态"""
    id: builtins.int
    """物料ID"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        state: builtins.int = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "id", b"id", "state", b"state", "title", b"title"]) -> None: ...

global___ModuleAuthorBadgeButton = ModuleAuthorBadgeButton

@typing_extensions.final
class ModuleAuthorForward(google.protobuf.message.Message):
    """动态列表-用户模块-转发模板"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    PTIME_LABEL_TEXT_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_FIELD_NUMBER: builtins.int
    FACE_URL_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    TP_LIST_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleAuthorForwardTitle]:
        """展示标题"""
    url: builtins.str
    """源卡片跳转链接"""
    uid: builtins.int
    """用户uid"""
    ptime_label_text: builtins.str
    """时间标签"""
    show_follow: builtins.bool
    """是否展示关注"""
    face_url: builtins.str
    """源up主头像"""
    @property
    def relation(self) -> global___Relation:
        """双向关系"""
    @property
    def tp_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """右侧操作区域 - 三点样式"""
    def __init__(
        self,
        *,
        title: collections.abc.Iterable[global___ModuleAuthorForwardTitle] | None = ...,
        url: builtins.str = ...,
        uid: builtins.int = ...,
        ptime_label_text: builtins.str = ...,
        show_follow: builtins.bool = ...,
        face_url: builtins.str = ...,
        relation: global___Relation | None = ...,
        tp_list: collections.abc.Iterable[global___ThreePointItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face_url", b"face_url", "ptime_label_text", b"ptime_label_text", "relation", b"relation", "show_follow", b"show_follow", "title", b"title", "tp_list", b"tp_list", "uid", b"uid", "url", b"url"]) -> None: ...

global___ModuleAuthorForward = ModuleAuthorForward

@typing_extensions.final
class ModuleAuthorForwardTitle(google.protobuf.message.Message):
    """动态列表-用户模块-转发模板-title部分"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    url: builtins.str
    """跳转链接"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "url", b"url"]) -> None: ...

global___ModuleAuthorForwardTitle = ModuleAuthorForwardTitle

@typing_extensions.final
class ModuleBanner(google.protobuf.message.Message):
    """动态列表-通栏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DISLIKE_TEXT_FIELD_NUMBER: builtins.int
    DISLIKE_ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """模块标题"""
    type: global___ModuleBannerType.ValueType
    """卡片类型"""
    @property
    def user(self) -> global___ModuleBannerUser: ...
    dislike_text: builtins.str
    """不感兴趣文案"""
    dislike_icon: builtins.str
    """不感兴趣图标"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        type: global___ModuleBannerType.ValueType = ...,
        user: global___ModuleBannerUser | None = ...,
        dislike_text: builtins.str = ...,
        dislike_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_icon", b"dislike_icon", "dislike_text", b"dislike_text", "item", b"item", "title", b"title", "type", b"type", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["user"] | None: ...

global___ModuleBanner = ModuleBanner

@typing_extensions.final
class ModuleBannerUser(google.protobuf.message.Message):
    """动态通栏-用户"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleBannerUserItem]:
        """卡片列表"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___ModuleBannerUserItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___ModuleBannerUser = ModuleBannerUser

@typing_extensions.final
class ModuleBannerUserItem(google.protobuf.message.Message):
    """动态通栏-推荐用户卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    face: builtins.str
    """up主头像"""
    name: builtins.str
    """up主昵称"""
    uid: builtins.int
    """up主uid"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    label: builtins.str
    """标签信息"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    uri: builtins.str
    """跳转地址"""
    @property
    def relation(self) -> global___Relation:
        """"""
    def __init__(
        self,
        *,
        face: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        live_state: global___LiveState.ValueType = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        label: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        uri: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "official", b"official", "relation", b"relation", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "face", b"face", "label", b"label", "live_state", b"live_state", "name", b"name", "official", b"official", "relation", b"relation", "uid", b"uid", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___ModuleBannerUserItem = ModuleBannerUserItem

@typing_extensions.final
class ModuleBlocked(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    BG_IMG_FIELD_NUMBER: builtins.int
    HINT_MESSAGE_FIELD_NUMBER: builtins.int
    ACT_BTN_FIELD_NUMBER: builtins.int
    BLOCK_STYLE_FIELD_NUMBER: builtins.int
    SUB_HINT_MESSAGE_FIELD_NUMBER: builtins.int
    VIDEO_BOTTOM_TEXT_UPPER_FIELD_NUMBER: builtins.int
    VIDEO_BOTTOM_TEXT_LOWER_FIELD_NUMBER: builtins.int
    ARCHIVE_TITLE_FIELD_NUMBER: builtins.int
    HINT_MESSAGE_ONE_LINE_FIELD_NUMBER: builtins.int
    @property
    def icon(self) -> global___ImageSet:
        """"""
    @property
    def bg_img(self) -> global___ImageSet:
        """"""
    hint_message: builtins.str
    """"""
    @property
    def act_btn(self) -> global___IconButton:
        """"""
    block_style: global___MdlBlockedStyle.ValueType
    """"""
    sub_hint_message: builtins.str
    """"""
    @property
    def video_bottom_text_upper(self) -> global___OneLineText:
        """"""
    @property
    def video_bottom_text_lower(self) -> global___OneLineText:
        """"""
    archive_title: builtins.str
    """"""
    @property
    def hint_message_one_line(self) -> global___OneLineText:
        """"""
    def __init__(
        self,
        *,
        icon: global___ImageSet | None = ...,
        bg_img: global___ImageSet | None = ...,
        hint_message: builtins.str = ...,
        act_btn: global___IconButton | None = ...,
        block_style: global___MdlBlockedStyle.ValueType = ...,
        sub_hint_message: builtins.str = ...,
        video_bottom_text_upper: global___OneLineText | None = ...,
        video_bottom_text_lower: global___OneLineText | None = ...,
        archive_title: builtins.str = ...,
        hint_message_one_line: global___OneLineText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["act_btn", b"act_btn", "bg_img", b"bg_img", "hint_message_one_line", b"hint_message_one_line", "icon", b"icon", "video_bottom_text_lower", b"video_bottom_text_lower", "video_bottom_text_upper", b"video_bottom_text_upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_btn", b"act_btn", "archive_title", b"archive_title", "bg_img", b"bg_img", "block_style", b"block_style", "hint_message", b"hint_message", "hint_message_one_line", b"hint_message_one_line", "icon", b"icon", "sub_hint_message", b"sub_hint_message", "video_bottom_text_lower", b"video_bottom_text_lower", "video_bottom_text_upper", b"video_bottom_text_upper"]) -> None: ...

global___ModuleBlocked = ModuleBlocked

@typing_extensions.final
class ModuleButtom(google.protobuf.message.Message):
    """底部模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _InteractionIcon:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _InteractionIconEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ModuleButtom._InteractionIcon.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ICON_INVALID: ModuleButtom._InteractionIcon.ValueType  # 0
        ICON_FORWARD: ModuleButtom._InteractionIcon.ValueType  # 1
        ICON_COMMENT: ModuleButtom._InteractionIcon.ValueType  # 2
        ICON_FAVORITE: ModuleButtom._InteractionIcon.ValueType  # 3
        ICON_LIKE: ModuleButtom._InteractionIcon.ValueType  # 4

    class InteractionIcon(_InteractionIcon, metaclass=_InteractionIconEnumTypeWrapper): ...
    ICON_INVALID: ModuleButtom.InteractionIcon.ValueType  # 0
    ICON_FORWARD: ModuleButtom.InteractionIcon.ValueType  # 1
    ICON_COMMENT: ModuleButtom.InteractionIcon.ValueType  # 2
    ICON_FAVORITE: ModuleButtom.InteractionIcon.ValueType  # 3
    ICON_LIKE: ModuleButtom.InteractionIcon.ValueType  # 4

    MODULE_STAT_FIELD_NUMBER: builtins.int
    COMMENT_BOX_FIELD_NUMBER: builtins.int
    COMMENT_BOX_MSG_FIELD_NUMBER: builtins.int
    INTERACTION_ICONS_FIELD_NUMBER: builtins.int
    FACES_FIELD_NUMBER: builtins.int
    @property
    def module_stat(self) -> global___ModuleStat:
        """计数模块"""
    comment_box: builtins.bool
    """"""
    comment_box_msg: builtins.str
    """"""
    @property
    def interaction_icons(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ModuleButtom.InteractionIcon.ValueType]:
        """"""
    @property
    def faces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InteractionFace]:
        """"""
    def __init__(
        self,
        *,
        module_stat: global___ModuleStat | None = ...,
        comment_box: builtins.bool = ...,
        comment_box_msg: builtins.str = ...,
        interaction_icons: collections.abc.Iterable[global___ModuleButtom.InteractionIcon.ValueType] | None = ...,
        faces: collections.abc.Iterable[global___InteractionFace] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_stat", b"module_stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment_box", b"comment_box", "comment_box_msg", b"comment_box_msg", "faces", b"faces", "interaction_icons", b"interaction_icons", "module_stat", b"module_stat"]) -> None: ...

global___ModuleButtom = ModuleButtom

@typing_extensions.final
class ModuleButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BTN_FIELD_NUMBER: builtins.int
    @property
    def btn(self) -> global___IconButton:
        """"""
    def __init__(
        self,
        *,
        btn: global___IconButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["btn", b"btn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["btn", b"btn"]) -> None: ...

global___ModuleButton = ModuleButton

@typing_extensions.final
class ModuleComment(google.protobuf.message.Message):
    """评论外露模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMTSHOWITEM_FIELD_NUMBER: builtins.int
    @property
    def cmtShowItem(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CmtShowItem]:
        """评论外露展示项"""
    def __init__(
        self,
        *,
        cmtShowItem: collections.abc.Iterable[global___CmtShowItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmtShowItem", b"cmtShowItem"]) -> None: ...

global___ModuleComment = ModuleComment

@typing_extensions.final
class ModuleCopyright(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEFT_TEXT_FIELD_NUMBER: builtins.int
    RIGHT_TEXT_FIELD_NUMBER: builtins.int
    left_text: builtins.str
    """"""
    right_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        left_text: builtins.str = ...,
        right_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["left_text", b"left_text", "right_text", b"right_text"]) -> None: ...

global___ModuleCopyright = ModuleCopyright

@typing_extensions.final
class ModuleDesc(google.protobuf.message.Message):
    """动态-描述文字模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """描述信息(已按高亮拆分)"""
    jump_uri: builtins.str
    """点击跳转链接"""
    text: builtins.str
    """文本原本"""
    def __init__(
        self,
        *,
        desc: collections.abc.Iterable[global___Description] | None = ...,
        jump_uri: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "jump_uri", b"jump_uri", "text", b"text"]) -> None: ...

global___ModuleDesc = ModuleDesc

@typing_extensions.final
class ModuleDescGoods(google.protobuf.message.Message):
    """正文商品卡参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    OPEN_WHITE_LIST_FIELD_NUMBER: builtins.int
    USER_WEB_V2_FIELD_NUMBER: builtins.int
    AD_MARK_FIELD_NUMBER: builtins.int
    SCHEMA_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    source_type: builtins.int
    """商品类型
    1:淘宝 2:会员购
    """
    jump_url: builtins.str
    """跳转链接"""
    schema_url: builtins.str
    """schema_url"""
    item_id: builtins.int
    """item_id"""
    @property
    def open_white_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """open_white_list"""
    user_web_v2: builtins.bool
    """use_web_v2"""
    ad_mark: builtins.str
    """ad mark"""
    schema_package_name: builtins.str
    """schemaPackageName(Android用)"""
    jump_type: builtins.int
    """"""
    app_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        source_type: builtins.int = ...,
        jump_url: builtins.str = ...,
        schema_url: builtins.str = ...,
        item_id: builtins.int = ...,
        open_white_list: collections.abc.Iterable[builtins.str] | None = ...,
        user_web_v2: builtins.bool = ...,
        ad_mark: builtins.str = ...,
        schema_package_name: builtins.str = ...,
        jump_type: builtins.int = ...,
        app_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_mark", b"ad_mark", "app_name", b"app_name", "item_id", b"item_id", "jump_type", b"jump_type", "jump_url", b"jump_url", "open_white_list", b"open_white_list", "schema_package_name", b"schema_package_name", "schema_url", b"schema_url", "source_type", b"source_type", "user_web_v2", b"user_web_v2"]) -> None: ...

global___ModuleDescGoods = ModuleDescGoods

@typing_extensions.final
class ModuleDispute(google.protobuf.message.Message):
    """动态-争议小黄条模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    desc: builtins.str
    """描述内容"""
    uri: builtins.str
    """跳转链接"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "title", b"title", "uri", b"uri"]) -> None: ...

global___ModuleDispute = ModuleDispute

@typing_extensions.final
class ModuleDynamic(google.protobuf.message.Message):
    """动态-详情模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DYN_ARCHIVE_FIELD_NUMBER: builtins.int
    DYN_PGC_FIELD_NUMBER: builtins.int
    DYN_COUR_SEASON_FIELD_NUMBER: builtins.int
    DYN_COUR_BATCH_FIELD_NUMBER: builtins.int
    DYN_FORWARD_FIELD_NUMBER: builtins.int
    DYN_DRAW_FIELD_NUMBER: builtins.int
    DYN_ARTICLE_FIELD_NUMBER: builtins.int
    DYN_MUSIC_FIELD_NUMBER: builtins.int
    DYN_COMMON_FIELD_NUMBER: builtins.int
    DYN_COMMON_LIVE_FIELD_NUMBER: builtins.int
    DYN_MEDIALIST_FIELD_NUMBER: builtins.int
    DYN_APPLET_FIELD_NUMBER: builtins.int
    DYN_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    DYN_LIVE_RCMD_FIELD_NUMBER: builtins.int
    DYN_UGC_SEASON_FIELD_NUMBER: builtins.int
    DYN_SUBSCRIPTION_NEW_FIELD_NUMBER: builtins.int
    DYN_COUR_BATCH_UP_FIELD_NUMBER: builtins.int
    DYN_TOPIC_SET_FIELD_NUMBER: builtins.int
    type: global___ModuleDynamicType.ValueType
    """类型"""
    @property
    def dyn_archive(self) -> global___MdlDynArchive:
        """稿件"""
    @property
    def dyn_pgc(self) -> global___MdlDynPGC:
        """pgc"""
    @property
    def dyn_cour_season(self) -> global___MdlDynCourSeason:
        """付费课程-系列"""
    @property
    def dyn_cour_batch(self) -> global___MdlDynCourBatch:
        """付费课程-批次"""
    @property
    def dyn_forward(self) -> global___MdlDynForward:
        """转发卡"""
    @property
    def dyn_draw(self) -> global___MdlDynDraw:
        """图文"""
    @property
    def dyn_article(self) -> global___MdlDynArticle:
        """专栏"""
    @property
    def dyn_music(self) -> global___MdlDynMusic:
        """音频"""
    @property
    def dyn_common(self) -> global___MdlDynCommon:
        """通用卡方"""
    @property
    def dyn_common_live(self) -> global___MdlDynLive:
        """直播卡"""
    @property
    def dyn_medialist(self) -> global___MdlDynMedialist:
        """播单"""
    @property
    def dyn_applet(self) -> global___MdlDynApplet:
        """小程序卡"""
    @property
    def dyn_subscription(self) -> global___MdlDynSubscription:
        """订阅卡"""
    @property
    def dyn_live_rcmd(self) -> global___MdlDynLiveRcmd:
        """直播推荐卡"""
    @property
    def dyn_ugc_season(self) -> global___MdlDynUGCSeason:
        """UGC合集"""
    @property
    def dyn_subscription_new(self) -> global___MdlDynSubscriptionNew:
        """订阅卡"""
    @property
    def dyn_cour_batch_up(self) -> global___MdlDynCourUp:
        """课程"""
    @property
    def dyn_topic_set(self) -> global___MdlDynTopicSet:
        """话题集合"""
    def __init__(
        self,
        *,
        type: global___ModuleDynamicType.ValueType = ...,
        dyn_archive: global___MdlDynArchive | None = ...,
        dyn_pgc: global___MdlDynPGC | None = ...,
        dyn_cour_season: global___MdlDynCourSeason | None = ...,
        dyn_cour_batch: global___MdlDynCourBatch | None = ...,
        dyn_forward: global___MdlDynForward | None = ...,
        dyn_draw: global___MdlDynDraw | None = ...,
        dyn_article: global___MdlDynArticle | None = ...,
        dyn_music: global___MdlDynMusic | None = ...,
        dyn_common: global___MdlDynCommon | None = ...,
        dyn_common_live: global___MdlDynLive | None = ...,
        dyn_medialist: global___MdlDynMedialist | None = ...,
        dyn_applet: global___MdlDynApplet | None = ...,
        dyn_subscription: global___MdlDynSubscription | None = ...,
        dyn_live_rcmd: global___MdlDynLiveRcmd | None = ...,
        dyn_ugc_season: global___MdlDynUGCSeason | None = ...,
        dyn_subscription_new: global___MdlDynSubscriptionNew | None = ...,
        dyn_cour_batch_up: global___MdlDynCourUp | None = ...,
        dyn_topic_set: global___MdlDynTopicSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dyn_applet", b"dyn_applet", "dyn_archive", b"dyn_archive", "dyn_article", b"dyn_article", "dyn_common", b"dyn_common", "dyn_common_live", b"dyn_common_live", "dyn_cour_batch", b"dyn_cour_batch", "dyn_cour_batch_up", b"dyn_cour_batch_up", "dyn_cour_season", b"dyn_cour_season", "dyn_draw", b"dyn_draw", "dyn_forward", b"dyn_forward", "dyn_live_rcmd", b"dyn_live_rcmd", "dyn_medialist", b"dyn_medialist", "dyn_music", b"dyn_music", "dyn_pgc", b"dyn_pgc", "dyn_subscription", b"dyn_subscription", "dyn_subscription_new", b"dyn_subscription_new", "dyn_topic_set", b"dyn_topic_set", "dyn_ugc_season", b"dyn_ugc_season", "module_item", b"module_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_applet", b"dyn_applet", "dyn_archive", b"dyn_archive", "dyn_article", b"dyn_article", "dyn_common", b"dyn_common", "dyn_common_live", b"dyn_common_live", "dyn_cour_batch", b"dyn_cour_batch", "dyn_cour_batch_up", b"dyn_cour_batch_up", "dyn_cour_season", b"dyn_cour_season", "dyn_draw", b"dyn_draw", "dyn_forward", b"dyn_forward", "dyn_live_rcmd", b"dyn_live_rcmd", "dyn_medialist", b"dyn_medialist", "dyn_music", b"dyn_music", "dyn_pgc", b"dyn_pgc", "dyn_subscription", b"dyn_subscription", "dyn_subscription_new", b"dyn_subscription_new", "dyn_topic_set", b"dyn_topic_set", "dyn_ugc_season", b"dyn_ugc_season", "module_item", b"module_item", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item", b"module_item"]) -> typing_extensions.Literal["dyn_archive", "dyn_pgc", "dyn_cour_season", "dyn_cour_batch", "dyn_forward", "dyn_draw", "dyn_article", "dyn_music", "dyn_common", "dyn_common_live", "dyn_medialist", "dyn_applet", "dyn_subscription", "dyn_live_rcmd", "dyn_ugc_season", "dyn_subscription_new", "dyn_cour_batch_up", "dyn_topic_set"] | None: ...

global___ModuleDynamic = ModuleDynamic

@typing_extensions.final
class ModuleExtend(google.protobuf.message.Message):
    """动态-小卡模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTEND_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    @property
    def extend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleExtendItem]:
        """详情"""
    uri: builtins.str
    """模块整体跳转uri
    废弃
    """
    def __init__(
        self,
        *,
        extend: collections.abc.Iterable[global___ModuleExtendItem] | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extend", b"extend", "uri", b"uri"]) -> None: ...

global___ModuleExtend = ModuleExtend

@typing_extensions.final
class ModuleExtendItem(google.protobuf.message.Message):
    """动态-拓展小卡模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    EXT_INFO_TOPIC_FIELD_NUMBER: builtins.int
    EXT_INFO_LBS_FIELD_NUMBER: builtins.int
    EXT_INFO_HOT_FIELD_NUMBER: builtins.int
    EXT_INFO_GAME_FIELD_NUMBER: builtins.int
    EXT_INFO_COMMON_FIELD_NUMBER: builtins.int
    EXT_INFO_OGV_FIELD_NUMBER: builtins.int
    type: global___DynExtendType.ValueType
    """类型"""
    @property
    def ext_info_topic(self) -> global___ExtInfoTopic:
        """废弃"""
    @property
    def ext_info_lbs(self) -> global___ExtInfoLBS:
        """废弃"""
    @property
    def ext_info_hot(self) -> global___ExtInfoHot:
        """废弃"""
    @property
    def ext_info_game(self) -> global___ExtInfoGame:
        """废弃"""
    @property
    def ext_info_common(self) -> global___ExtInfoCommon:
        """"""
    @property
    def ext_info_ogv(self) -> global___ExtInfoOGV:
        """"""
    def __init__(
        self,
        *,
        type: global___DynExtendType.ValueType = ...,
        ext_info_topic: global___ExtInfoTopic | None = ...,
        ext_info_lbs: global___ExtInfoLBS | None = ...,
        ext_info_hot: global___ExtInfoHot | None = ...,
        ext_info_game: global___ExtInfoGame | None = ...,
        ext_info_common: global___ExtInfoCommon | None = ...,
        ext_info_ogv: global___ExtInfoOGV | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ext_info_common", b"ext_info_common", "ext_info_game", b"ext_info_game", "ext_info_hot", b"ext_info_hot", "ext_info_lbs", b"ext_info_lbs", "ext_info_ogv", b"ext_info_ogv", "ext_info_topic", b"ext_info_topic", "extend", b"extend"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ext_info_common", b"ext_info_common", "ext_info_game", b"ext_info_game", "ext_info_hot", b"ext_info_hot", "ext_info_lbs", b"ext_info_lbs", "ext_info_ogv", b"ext_info_ogv", "ext_info_topic", b"ext_info_topic", "extend", b"extend", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["extend", b"extend"]) -> typing_extensions.Literal["ext_info_topic", "ext_info_lbs", "ext_info_hot", "ext_info_game", "ext_info_common", "ext_info_ogv"] | None: ...

global___ModuleExtendItem = ModuleExtendItem

@typing_extensions.final
class ModuleFold(google.protobuf.message.Message):
    """动态-折叠模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLD_TYPE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLD_IDS_FIELD_NUMBER: builtins.int
    FOLD_USERS_FIELD_NUMBER: builtins.int
    TOPIC_MERGED_RESOURCE_FIELD_NUMBER: builtins.int
    fold_type: global___FoldType.ValueType
    """折叠分类"""
    text: builtins.str
    """折叠文案"""
    fold_ids: builtins.str
    """被折叠的动态"""
    @property
    def fold_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInfo]:
        """被折叠的用户信息"""
    @property
    def topic_merged_resource(self) -> global___TopicMergedResource:
        """"""
    def __init__(
        self,
        *,
        fold_type: global___FoldType.ValueType = ...,
        text: builtins.str = ...,
        fold_ids: builtins.str = ...,
        fold_users: collections.abc.Iterable[global___UserInfo] | None = ...,
        topic_merged_resource: global___TopicMergedResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_merged_resource", b"topic_merged_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold_ids", b"fold_ids", "fold_type", b"fold_type", "fold_users", b"fold_users", "text", b"text", "topic_merged_resource", b"topic_merged_resource"]) -> None: ...

global___ModuleFold = ModuleFold

@typing_extensions.final
class ModuleInteraction(google.protobuf.message.Message):
    """外露交互模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERACTION_ITEM_FIELD_NUMBER: builtins.int
    @property
    def interaction_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InteractionItem]:
        """外露交互模块"""
    def __init__(
        self,
        *,
        interaction_item: collections.abc.Iterable[global___InteractionItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interaction_item", b"interaction_item"]) -> None: ...

global___ModuleInteraction = ModuleInteraction

@typing_extensions.final
class ModuleItemNull(google.protobuf.message.Message):
    """获取物料失败模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """图标"""
    text: builtins.str
    """文案"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text"]) -> None: ...

global___ModuleItemNull = ModuleItemNull

@typing_extensions.final
class ModuleLikeUser(google.protobuf.message.Message):
    """动态-点赞用户模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_USERS_FIELD_NUMBER: builtins.int
    DISPLAY_TEXT_FIELD_NUMBER: builtins.int
    @property
    def like_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LikeUser]:
        """点赞用户"""
    display_text: builtins.str
    """文案"""
    def __init__(
        self,
        *,
        like_users: collections.abc.Iterable[global___LikeUser] | None = ...,
        display_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_text", b"display_text", "like_users", b"like_users"]) -> None: ...

global___ModuleLikeUser = ModuleLikeUser

@typing_extensions.final
class ModuleNotice(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NOTICE_TYPE_FIELD_NUMBER: builtins.int
    identity: builtins.str
    """"""
    icon: builtins.str
    """"""
    title: builtins.str
    """"""
    url: builtins.str
    """"""
    notice_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        identity: builtins.str = ...,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        url: builtins.str = ...,
        notice_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "identity", b"identity", "notice_type", b"notice_type", "title", b"title", "url", b"url"]) -> None: ...

global___ModuleNotice = ModuleNotice

@typing_extensions.final
class ModuleOpusCollection(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_INFO_FIELD_NUMBER: builtins.int
    TITLE_UPPER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TITLE_PREFIX_ICON_FIELD_NUMBER: builtins.int
    TOTAL_TEXT_FIELD_NUMBER: builtins.int
    @property
    def collection_info(self) -> global___OpusCollection:
        """"""
    title_upper: builtins.str
    """"""
    title: builtins.str
    """"""
    title_prefix_icon: builtins.str
    """"""
    total_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        collection_info: global___OpusCollection | None = ...,
        title_upper: builtins.str = ...,
        title: builtins.str = ...,
        title_prefix_icon: builtins.str = ...,
        total_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collection_info", b"collection_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_info", b"collection_info", "title", b"title", "title_prefix_icon", b"title_prefix_icon", "title_upper", b"title_upper", "total_text", b"total_text"]) -> None: ...

global___ModuleOpusCollection = ModuleOpusCollection

@typing_extensions.final
class ModuleOpusSummary(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    SUMMARY_JUMP_BTN_TEXT_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> global___Paragraph:
        """"""
    @property
    def summary(self) -> global___Paragraph:
        """"""
    summary_jump_btn_text: builtins.str
    """"""
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MdlDynDrawItem]:
        """"""
    def __init__(
        self,
        *,
        title: global___Paragraph | None = ...,
        summary: global___Paragraph | None = ...,
        summary_jump_btn_text: builtins.str = ...,
        covers: collections.abc.Iterable[global___MdlDynDrawItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summary", b"summary", "title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["covers", b"covers", "summary", b"summary", "summary_jump_btn_text", b"summary_jump_btn_text", "title", b"title"]) -> None: ...

global___ModuleOpusSummary = ModuleOpusSummary

@typing_extensions.final
class ModuleParagraph(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAGRAPH_FIELD_NUMBER: builtins.int
    IS_ARTICLE_TITLE_FIELD_NUMBER: builtins.int
    PARA_SPACING_FIELD_NUMBER: builtins.int
    @property
    def paragraph(self) -> global___Paragraph:
        """"""
    is_article_title: builtins.bool
    """"""
    @property
    def para_spacing(self) -> global___ParaSpacing:
        """"""
    def __init__(
        self,
        *,
        paragraph: global___Paragraph | None = ...,
        is_article_title: builtins.bool = ...,
        para_spacing: global___ParaSpacing | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["para_spacing", b"para_spacing", "paragraph", b"paragraph"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_article_title", b"is_article_title", "para_spacing", b"para_spacing", "paragraph", b"paragraph"]) -> None: ...

global___ModuleParagraph = ModuleParagraph

@typing_extensions.final
class ModuleRcmd(google.protobuf.message.Message):
    """推荐模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    SERVER_INFO_FIELD_NUMBER: builtins.int
    @property
    def author(self) -> global___RcmdAuthor:
        """用户头像"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RcmdItem]:
        """推荐卡片列表"""
    server_info: builtins.str
    """透传到客户端的埋点字段"""
    def __init__(
        self,
        *,
        author: global___RcmdAuthor | None = ...,
        items: collections.abc.Iterable[global___RcmdItem] | None = ...,
        server_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "items", b"items", "server_info", b"server_info"]) -> None: ...

global___ModuleRcmd = ModuleRcmd

@typing_extensions.final
class ModuleRecommend(google.protobuf.message.Message):
    """相关推荐模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_TITLE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    AD_FIELD_NUMBER: builtins.int
    module_title: builtins.str
    """模块标题"""
    image: builtins.str
    """图片"""
    tag: builtins.str
    """标签"""
    title: builtins.str
    """标题"""
    jump_url: builtins.str
    """跳转链接"""
    @property
    def ad(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """序列化的广告信息"""
    def __init__(
        self,
        *,
        module_title: builtins.str = ...,
        image: builtins.str = ...,
        tag: builtins.str = ...,
        title: builtins.str = ...,
        jump_url: builtins.str = ...,
        ad: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad", b"ad", "image", b"image", "jump_url", b"jump_url", "module_title", b"module_title", "tag", b"tag", "title", b"title"]) -> None: ...

global___ModuleRecommend = ModuleRecommend

@typing_extensions.final
class ModuleShareInfo(google.protobuf.message.Message):
    """分享模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SHARE_CHANNELS_FIELD_NUMBER: builtins.int
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """展示标题"""
    @property
    def share_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareChannel]:
        """分享组件列表"""
    share_origin: builtins.str
    """share_origin"""
    oid: builtins.str
    """业务id"""
    sid: builtins.str
    """sid"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        share_channels: collections.abc.Iterable[global___ShareChannel] | None = ...,
        share_origin: builtins.str = ...,
        oid: builtins.str = ...,
        sid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "share_channels", b"share_channels", "share_origin", b"share_origin", "sid", b"sid", "title", b"title"]) -> None: ...

global___ModuleShareInfo = ModuleShareInfo

@typing_extensions.final
class ModuleStat(google.protobuf.message.Message):
    """动态-计数模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOST_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    LIKE_INFO_FIELD_NUMBER: builtins.int
    NO_COMMENT_FIELD_NUMBER: builtins.int
    NO_FORWARD_FIELD_NUMBER: builtins.int
    REPLY_URL_FIELD_NUMBER: builtins.int
    NO_COMMENT_TEXT_FIELD_NUMBER: builtins.int
    NO_FORWARD_TEXT_FIELD_NUMBER: builtins.int
    repost: builtins.int
    """转发数"""
    like: builtins.int
    """点赞数"""
    reply: builtins.int
    """评论数"""
    @property
    def like_info(self) -> global___LikeInfo:
        """点赞拓展信息"""
    no_comment: builtins.bool
    """禁评"""
    no_forward: builtins.bool
    """禁转"""
    reply_url: builtins.str
    """点击评论跳转链接"""
    no_comment_text: builtins.str
    """禁评文案"""
    no_forward_text: builtins.str
    """禁转文案"""
    def __init__(
        self,
        *,
        repost: builtins.int = ...,
        like: builtins.int = ...,
        reply: builtins.int = ...,
        like_info: global___LikeInfo | None = ...,
        no_comment: builtins.bool = ...,
        no_forward: builtins.bool = ...,
        reply_url: builtins.str = ...,
        no_comment_text: builtins.str = ...,
        no_forward_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["like_info", b"like_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["like", b"like", "like_info", b"like_info", "no_comment", b"no_comment", "no_comment_text", b"no_comment_text", "no_forward", b"no_forward", "no_forward_text", b"no_forward_text", "reply", b"reply", "reply_url", b"reply_url", "repost", b"repost"]) -> None: ...

global___ModuleStat = ModuleStat

@typing_extensions.final
class ModuleStory(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    SHOW_PUBLISH_ENTRANCE_FIELD_NUMBER: builtins.int
    FOLD_STATE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PUBLISH_TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StoryItem]:
        """"""
    show_publish_entrance: builtins.bool
    """"""
    fold_state: builtins.int
    """"""
    uri: builtins.str
    """"""
    cover: builtins.str
    """"""
    publish_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        items: collections.abc.Iterable[global___StoryItem] | None = ...,
        show_publish_entrance: builtins.bool = ...,
        fold_state: builtins.int = ...,
        uri: builtins.str = ...,
        cover: builtins.str = ...,
        publish_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "fold_state", b"fold_state", "items", b"items", "publish_text", b"publish_text", "show_publish_entrance", b"show_publish_entrance", "title", b"title", "uri", b"uri"]) -> None: ...

global___ModuleStory = ModuleStory

@typing_extensions.final
class ModuleTextNotice(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTICE_FIELD_NUMBER: builtins.int
    @property
    def notice(self) -> global___OneLineText:
        """"""
    def __init__(
        self,
        *,
        notice: global___OneLineText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notice", b"notice"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notice", b"notice"]) -> None: ...

global___ModuleTextNotice = ModuleTextNotice

@typing_extensions.final
class ModuleTitle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    RIGHT_BTN_FIELD_NUMBER: builtins.int
    TITLE_STYLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def right_btn(self) -> global___IconButton:
        """"""
    title_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        right_btn: global___IconButton | None = ...,
        title_style: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["right_btn", b"right_btn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["right_btn", b"right_btn", "title", b"title", "title_style", b"title_style"]) -> None: ...

global___ModuleTitle = ModuleTitle

@typing_extensions.final
class ModuleTop(google.protobuf.message.Message):
    """顶部模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TP_LIST_FIELD_NUMBER: builtins.int
    ARCHIVE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    HIDDEN_NAV_BAR_FIELD_NUMBER: builtins.int
    @property
    def tp_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """三点模块"""
    @property
    def archive(self) -> global___MdlDynArchive:
        """"""
    @property
    def author(self) -> global___ModuleAuthor:
        """"""
    hidden_nav_bar: builtins.bool
    """"""
    def __init__(
        self,
        *,
        tp_list: collections.abc.Iterable[global___ThreePointItem] | None = ...,
        archive: global___MdlDynArchive | None = ...,
        author: global___ModuleAuthor | None = ...,
        hidden_nav_bar: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["archive", b"archive", "author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive", b"archive", "author", b"author", "hidden_nav_bar", b"hidden_nav_bar", "tp_list", b"tp_list"]) -> None: ...

global___ModuleTop = ModuleTop

@typing_extensions.final
class ModuleTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "url", b"url"]) -> None: ...

global___ModuleTopic = ModuleTopic

@typing_extensions.final
class ModuleTopicBrief(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    @property
    def topic(self) -> global___TopicItem:
        """"""
    def __init__(
        self,
        *,
        topic: global___TopicItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> None: ...

global___ModuleTopicBrief = ModuleTopicBrief

@typing_extensions.final
class ModuleTopicDetailsExt(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMENT_GUIDE_FIELD_NUMBER: builtins.int
    comment_guide: builtins.str
    """"""
    def __init__(
        self,
        *,
        comment_guide: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment_guide", b"comment_guide"]) -> None: ...

global___ModuleTopicDetailsExt = ModuleTopicDetailsExt

@typing_extensions.final
class ModuleTopTag(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_NAME_FIELD_NUMBER: builtins.int
    tag_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        tag_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag_name", b"tag_name"]) -> None: ...

global___ModuleTopTag = ModuleTopTag

@typing_extensions.final
class Nameplate(google.protobuf.message.Message):
    """认证名牌"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_SMALL_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    nid: builtins.int
    """nid"""
    name: builtins.str
    """名称"""
    image: builtins.str
    """图片地址"""
    image_small: builtins.str
    """小图地址"""
    level: builtins.str
    """等级"""
    condition: builtins.str
    """获取条件"""
    def __init__(
        self,
        *,
        nid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        image_small: builtins.str = ...,
        level: builtins.str = ...,
        condition: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "image", b"image", "image_small", b"image_small", "level", b"level", "name", b"name", "nid", b"nid"]) -> None: ...

global___Nameplate = Nameplate

@typing_extensions.final
class NewEP(google.protobuf.message.Message):
    """最新ep"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INDEX_SHOW_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    id: builtins.int
    """最新话epid"""
    index_show: builtins.str
    """更新至XX话"""
    cover: builtins.str
    """更新剧集的封面"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        index_show: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "id", b"id", "index_show", b"index_show"]) -> None: ...

global___NewEP = NewEP

@typing_extensions.final
class NFTInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_TYPE_FIELD_NUMBER: builtins.int
    REGION_ICON_FIELD_NUMBER: builtins.int
    REGION_SHOW_STATUS_FIELD_NUMBER: builtins.int
    region_type: global___NFTRegionType.ValueType
    """"""
    region_icon: builtins.str
    """"""
    region_show_status: global___NFTShowStatus.ValueType
    """"""
    def __init__(
        self,
        *,
        region_type: global___NFTRegionType.ValueType = ...,
        region_icon: builtins.str = ...,
        region_show_status: global___NFTShowStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["region_icon", b"region_icon", "region_show_status", b"region_show_status", "region_type", b"region_type"]) -> None: ...

global___NFTInfo = NFTInfo

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """空响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class NoReq(google.protobuf.message.Message):
    """空请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReq = NoReq

@typing_extensions.final
class NoteVideoTS(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    OID_TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    CID_COUNT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""
    oid_type: builtins.int
    """"""
    status: builtins.int
    """"""
    index: builtins.int
    """"""
    seconds: builtins.int
    """"""
    cid_count: builtins.int
    """"""
    key: builtins.str
    """"""
    epid: builtins.int
    """"""
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        oid_type: builtins.int = ...,
        status: builtins.int = ...,
        index: builtins.int = ...,
        seconds: builtins.int = ...,
        cid_count: builtins.int = ...,
        key: builtins.str = ...,
        epid: builtins.int = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "cid_count", b"cid_count", "desc", b"desc", "epid", b"epid", "index", b"index", "key", b"key", "oid_type", b"oid_type", "seconds", b"seconds", "status", b"status", "title", b"title"]) -> None: ...

global___NoteVideoTS = NoteVideoTS

@typing_extensions.final
class OfficialAccountInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    DESC_TEXT1_FIELD_NUMBER: builtins.int
    DESC_TEXT2_FIELD_NUMBER: builtins.int
    @property
    def author(self) -> global___UserInfo:
        """"""
    mid: builtins.int
    """"""
    uri: builtins.str
    """"""
    @property
    def relation(self) -> global___Relation:
        """"""
    desc_text1: builtins.str
    """"""
    desc_text2: builtins.str
    """"""
    def __init__(
        self,
        *,
        author: global___UserInfo | None = ...,
        mid: builtins.int = ...,
        uri: builtins.str = ...,
        relation: global___Relation | None = ...,
        desc_text1: builtins.str = ...,
        desc_text2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "desc_text1", b"desc_text1", "desc_text2", b"desc_text2", "mid", b"mid", "relation", b"relation", "uri", b"uri"]) -> None: ...

global___OfficialAccountInfo = OfficialAccountInfo

@typing_extensions.final
class OfficialAccountsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OfficialAccountInfo]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.int
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___OfficialAccountInfo] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "items", b"items", "offset", b"offset"]) -> None: ...

global___OfficialAccountsReply = OfficialAccountsReply

@typing_extensions.final
class OfficialAccountsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    offset: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "offset", b"offset"]) -> None: ...

global___OfficialAccountsReq = OfficialAccountsReq

@typing_extensions.final
class OfficialDynamicsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OfficialItem]:
        """"""
    offset: builtins.int
    """"""
    has_more: builtins.bool
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___OfficialItem] | None = ...,
        offset: builtins.int = ...,
        has_more: builtins.bool = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "items", b"items", "offset", b"offset", "player_args", b"player_args"]) -> None: ...

global___OfficialDynamicsReply = OfficialDynamicsReply

@typing_extensions.final
class OfficialDynamicsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    offset: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "offset", b"offset"]) -> None: ...

global___OfficialDynamicsReq = OfficialDynamicsReq

@typing_extensions.final
class OfficialItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    RCMD_ARCHIVE_FIELD_NUMBER: builtins.int
    RCMD_DYNAMIC_FIELD_NUMBER: builtins.int
    type: builtins.int
    @property
    def rcmd_archive(self) -> global___OfficialRcmdArchive: ...
    @property
    def rcmd_dynamic(self) -> global___OfficialRcmdDynamic: ...
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        rcmd_archive: global___OfficialRcmdArchive | None = ...,
        rcmd_dynamic: global___OfficialRcmdDynamic | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rcmd_archive", b"rcmd_archive", "rcmd_dynamic", b"rcmd_dynamic", "rcmd_item", b"rcmd_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["rcmd_archive", b"rcmd_archive", "rcmd_dynamic", b"rcmd_dynamic", "rcmd_item", b"rcmd_item", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["rcmd_item", b"rcmd_item"]) -> typing_extensions.Literal["rcmd_archive", "rcmd_dynamic"] | None: ...

global___OfficialItem = OfficialItem

@typing_extensions.final
class OfficialRcmdArchive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    DESC_ICON1_FIELD_NUMBER: builtins.int
    DESC_TEXT1_FIELD_NUMBER: builtins.int
    DESC_ICON2_FIELD_NUMBER: builtins.int
    DESC_TEXT2_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    SHOW_THREE_POINT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    cover_right_text: builtins.str
    """"""
    desc_icon1: builtins.int
    """"""
    desc_text1: builtins.str
    """"""
    desc_icon2: builtins.int
    """"""
    desc_text2: builtins.str
    """"""
    reason: builtins.str
    """"""
    show_three_point: builtins.bool
    """"""
    uri: builtins.str
    """"""
    aid: builtins.int
    """"""
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    dynamic_id: builtins.int
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_right_text: builtins.str = ...,
        desc_icon1: builtins.int = ...,
        desc_text1: builtins.str = ...,
        desc_icon2: builtins.int = ...,
        desc_text2: builtins.str = ...,
        reason: builtins.str = ...,
        show_three_point: builtins.bool = ...,
        uri: builtins.str = ...,
        aid: builtins.int = ...,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        dynamic_id: builtins.int = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "cover", b"cover", "cover_right_text", b"cover_right_text", "desc_icon1", b"desc_icon1", "desc_icon2", b"desc_icon2", "desc_text1", b"desc_text1", "desc_text2", b"desc_text2", "dynamic_id", b"dynamic_id", "mid", b"mid", "name", b"name", "reason", b"reason", "show_three_point", b"show_three_point", "title", b"title", "uri", b"uri"]) -> None: ...

global___OfficialRcmdArchive = OfficialRcmdArchive

@typing_extensions.final
class OfficialRcmdDynamic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TOP_TEXT_FIELD_NUMBER: builtins.int
    DESC_ICON1_FIELD_NUMBER: builtins.int
    DESC_TEXT1_FIELD_NUMBER: builtins.int
    DESC_ICON2_FIELD_NUMBER: builtins.int
    DESC_TEXT2_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    cover_right_top_text: builtins.str
    """"""
    desc_icon1: builtins.int
    """"""
    desc_text1: builtins.str
    """"""
    desc_icon2: builtins.int
    """"""
    desc_text2: builtins.str
    """"""
    reason: builtins.str
    """"""
    uri: builtins.str
    """"""
    dynamic_id: builtins.int
    """"""
    mid: builtins.int
    """"""
    user_name: builtins.str
    """"""
    rid: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_right_top_text: builtins.str = ...,
        desc_icon1: builtins.int = ...,
        desc_text1: builtins.str = ...,
        desc_icon2: builtins.int = ...,
        desc_text2: builtins.str = ...,
        reason: builtins.str = ...,
        uri: builtins.str = ...,
        dynamic_id: builtins.int = ...,
        mid: builtins.int = ...,
        user_name: builtins.str = ...,
        rid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "cover_right_top_text", b"cover_right_top_text", "desc_icon1", b"desc_icon1", "desc_icon2", b"desc_icon2", "desc_text1", b"desc_text1", "desc_text2", b"desc_text2", "dynamic_id", b"dynamic_id", "mid", b"mid", "reason", b"reason", "rid", b"rid", "title", b"title", "uri", b"uri", "user_name", b"user_name"]) -> None: ...

global___OfficialRcmdDynamic = OfficialRcmdDynamic

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    type: builtins.int
    """127:未认证 0:个人 1:机构"""
    desc: builtins.str
    """认证描述"""
    is_atten: builtins.int
    """是否关注"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
        is_atten: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "is_atten", b"is_atten", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class OneLineText(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXTS_FIELD_NUMBER: builtins.int
    @property
    def texts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextWithPriority]:
        """"""
    def __init__(
        self,
        *,
        texts: collections.abc.Iterable[global___TextWithPriority] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["texts", b"texts"]) -> None: ...

global___OneLineText = OneLineText

@typing_extensions.final
class OnlyFans(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_ONLY_FANS_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    is_only_fans: builtins.bool
    """"""
    @property
    def badge(self) -> global___IconBadge:
        """"""
    def __init__(
        self,
        *,
        is_only_fans: builtins.bool = ...,
        badge: global___IconBadge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "is_only_fans", b"is_only_fans"]) -> None: ...

global___OnlyFans = OnlyFans

@typing_extensions.final
class OnlyFansProperty(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_PRIVILEGE_FIELD_NUMBER: builtins.int
    IS_ONLY_FANS_FIELD_NUMBER: builtins.int
    has_privilege: builtins.bool
    """"""
    is_only_fans: builtins.bool
    """"""
    def __init__(
        self,
        *,
        has_privilege: builtins.bool = ...,
        is_only_fans: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_privilege", b"has_privilege", "is_only_fans", b"is_only_fans"]) -> None: ...

global___OnlyFansProperty = OnlyFansProperty

@typing_extensions.final
class OpusCollection(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DETAIL_URI_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    ALL_ITEMS_FIELD_NUMBER: builtins.int
    collection_id: builtins.int
    """"""
    @property
    def title(self) -> global___OneLineText:
        """"""
    detail_uri: builtins.str
    """"""
    intro: builtins.str
    """"""
    @property
    def all_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OpusCollectionItem]:
        """"""
    def __init__(
        self,
        *,
        collection_id: builtins.int = ...,
        title: global___OneLineText | None = ...,
        detail_uri: builtins.str = ...,
        intro: builtins.str = ...,
        all_items: collections.abc.Iterable[global___OpusCollectionItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_items", b"all_items", "collection_id", b"collection_id", "detail_uri", b"detail_uri", "intro", b"intro", "title", b"title"]) -> None: ...

global___OpusCollection = OpusCollection

@typing_extensions.final
class OpusCollectionItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPUS_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    PUB_TIME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    IS_SELECTED_HIGHLIGHT_FIELD_NUMBER: builtins.int
    opus_id: builtins.int
    """"""
    title: builtins.str
    """"""
    pub_time: builtins.str
    """"""
    uri: builtins.str
    """"""
    is_selected_highlight: builtins.bool
    """"""
    def __init__(
        self,
        *,
        opus_id: builtins.int = ...,
        title: builtins.str = ...,
        pub_time: builtins.str = ...,
        uri: builtins.str = ...,
        is_selected_highlight: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_selected_highlight", b"is_selected_highlight", "opus_id", b"opus_id", "pub_time", b"pub_time", "title", b"title", "uri", b"uri"]) -> None: ...

global___OpusCollectionItem = OpusCollectionItem

@typing_extensions.final
class Paragraph(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ParagraphAlign:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ParagraphAlignEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Paragraph._ParagraphAlign.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LEFT: Paragraph._ParagraphAlign.ValueType  # 0
        MIDDLE: Paragraph._ParagraphAlign.ValueType  # 1
        RIGHT: Paragraph._ParagraphAlign.ValueType  # 2

    class ParagraphAlign(_ParagraphAlign, metaclass=_ParagraphAlignEnumTypeWrapper): ...
    LEFT: Paragraph.ParagraphAlign.ValueType  # 0
    MIDDLE: Paragraph.ParagraphAlign.ValueType  # 1
    RIGHT: Paragraph.ParagraphAlign.ValueType  # 2

    class _ParagraphType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ParagraphTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Paragraph._ParagraphType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: Paragraph._ParagraphType.ValueType  # 0
        TEXT: Paragraph._ParagraphType.ValueType  # 1
        PICTURES: Paragraph._ParagraphType.ValueType  # 2
        LINE: Paragraph._ParagraphType.ValueType  # 3
        REFERENCE: Paragraph._ParagraphType.ValueType  # 4
        SORTED_LIST: Paragraph._ParagraphType.ValueType  # 5
        UNSORTED_LIST: Paragraph._ParagraphType.ValueType  # 6
        LINK_CARD: Paragraph._ParagraphType.ValueType  # 7

    class ParagraphType(_ParagraphType, metaclass=_ParagraphTypeEnumTypeWrapper):
        """"""

    INVALID: Paragraph.ParagraphType.ValueType  # 0
    TEXT: Paragraph.ParagraphType.ValueType  # 1
    PICTURES: Paragraph.ParagraphType.ValueType  # 2
    LINE: Paragraph.ParagraphType.ValueType  # 3
    REFERENCE: Paragraph.ParagraphType.ValueType  # 4
    SORTED_LIST: Paragraph.ParagraphType.ValueType  # 5
    UNSORTED_LIST: Paragraph.ParagraphType.ValueType  # 6
    LINK_CARD: Paragraph.ParagraphType.ValueType  # 7

    @typing_extensions.final
    class ListFormat(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LEVEL_FIELD_NUMBER: builtins.int
        ORDER_FIELD_NUMBER: builtins.int
        THEME_FIELD_NUMBER: builtins.int
        level: builtins.int
        """"""
        order: builtins.int
        """"""
        theme: builtins.str
        """"""
        def __init__(
            self,
            *,
            level: builtins.int = ...,
            order: builtins.int = ...,
            theme: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["level", b"level", "order", b"order", "theme", b"theme"]) -> None: ...

    @typing_extensions.final
    class ParagraphFormat(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ALIGN_FIELD_NUMBER: builtins.int
        LIST_FORMAT_FIELD_NUMBER: builtins.int
        align: global___Paragraph.ParagraphAlign.ValueType
        """"""
        @property
        def list_format(self) -> global___Paragraph.ListFormat:
            """"""
        def __init__(
            self,
            *,
            align: global___Paragraph.ParagraphAlign.ValueType = ...,
            list_format: global___Paragraph.ListFormat | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["list_format", b"list_format"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["align", b"align", "list_format", b"list_format"]) -> None: ...

    PARA_TYPE_FIELD_NUMBER: builtins.int
    PARA_FORMAT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    LINK_CARD_FIELD_NUMBER: builtins.int
    para_type: global___Paragraph.ParagraphType.ValueType
    """"""
    @property
    def para_format(self) -> global___Paragraph.ParagraphFormat:
        """"""
    @property
    def text(self) -> global___TextParagraph: ...
    @property
    def pic(self) -> global___PicParagraph: ...
    @property
    def line(self) -> global___LineParagraph: ...
    @property
    def link_card(self) -> global___CardParagraph: ...
    def __init__(
        self,
        *,
        para_type: global___Paragraph.ParagraphType.ValueType = ...,
        para_format: global___Paragraph.ParagraphFormat | None = ...,
        text: global___TextParagraph | None = ...,
        pic: global___PicParagraph | None = ...,
        line: global___LineParagraph | None = ...,
        link_card: global___CardParagraph | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "line", b"line", "link_card", b"link_card", "para_format", b"para_format", "pic", b"pic", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "line", b"line", "link_card", b"link_card", "para_format", b"para_format", "para_type", b"para_type", "pic", b"pic", "text", b"text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["text", "pic", "line", "link_card"] | None: ...

global___Paragraph = Paragraph

@typing_extensions.final
class ParaSpacing(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPACING_BEFORE_PARA_FIELD_NUMBER: builtins.int
    SPACING_AFTER_PARA_FIELD_NUMBER: builtins.int
    LINE_SPACING_FIELD_NUMBER: builtins.int
    spacing_before_para: builtins.float
    """"""
    spacing_after_para: builtins.float
    """"""
    line_spacing: builtins.float
    """"""
    def __init__(
        self,
        *,
        spacing_before_para: builtins.float = ...,
        spacing_after_para: builtins.float = ...,
        line_spacing: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["line_spacing", b"line_spacing", "spacing_after_para", b"spacing_after_para", "spacing_before_para", b"spacing_before_para"]) -> None: ...

global___ParaSpacing = ParaSpacing

@typing_extensions.final
class PGCSeason(google.protobuf.message.Message):
    """PGC单季信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FINISH_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    is_finish: builtins.int
    """是否完结"""
    title: builtins.str
    """标题"""
    type: builtins.int
    """类型"""
    def __init__(
        self,
        *,
        is_finish: builtins.int = ...,
        title: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_finish", b"is_finish", "title", b"title", "type", b"type"]) -> None: ...

global___PGCSeason = PGCSeason

@typing_extensions.final
class PicParagraph(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PicParagraphStyle:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PicParagraphStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PicParagraph._PicParagraphStyle.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: PicParagraph._PicParagraphStyle.ValueType  # 0
        NINE_CELL: PicParagraph._PicParagraphStyle.ValueType  # 1
        BIG_SCROLL: PicParagraph._PicParagraphStyle.ValueType  # 2

    class PicParagraphStyle(_PicParagraphStyle, metaclass=_PicParagraphStyleEnumTypeWrapper):
        """"""

    INVALID: PicParagraph.PicParagraphStyle.ValueType  # 0
    NINE_CELL: PicParagraph.PicParagraphStyle.ValueType  # 1
    BIG_SCROLL: PicParagraph.PicParagraphStyle.ValueType  # 2

    PICS_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    @property
    def pics(self) -> global___MdlDynDraw:
        """"""
    style: global___PicParagraph.PicParagraphStyle.ValueType
    """"""
    def __init__(
        self,
        *,
        pics: global___MdlDynDraw | None = ...,
        style: global___PicParagraph.PicParagraphStyle.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pics", b"pics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pics", b"pics", "style", b"style"]) -> None: ...

global___PicParagraph = PicParagraph

@typing_extensions.final
class PlayurlParam(google.protobuf.message.Message):
    """秒开通用参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """流版本"""
    fnval: builtins.int
    """流类型"""
    force_host: builtins.int
    """是否强制使用域名"""
    fourk: builtins.int
    """是否4k"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "qn", b"qn"]) -> None: ...

global___PlayurlParam = PlayurlParam

@typing_extensions.final
class Popup(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "title", b"title", "uri", b"uri"]) -> None: ...

global___Popup = Popup

@typing_extensions.final
class RcmdArchive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    IS_PGC_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON3_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT3_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面图"""
    cover_left_icon_1: global___CoverIcon.ValueType
    """视频封面展示项 1"""
    cover_left_text_1: builtins.str
    """视频封面展示项 1"""
    uri: builtins.str
    """秒开地址"""
    is_pgc: builtins.bool
    """是否PGC"""
    aid: builtins.int
    """aid"""
    @property
    def badge(self) -> global___IconBadge:
        """"""
    cover_left_icon2: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon3: builtins.int
    """"""
    cover_left_text3: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_left_icon_1: global___CoverIcon.ValueType = ...,
        cover_left_text_1: builtins.str = ...,
        uri: builtins.str = ...,
        is_pgc: builtins.bool = ...,
        aid: builtins.int = ...,
        badge: global___IconBadge | None = ...,
        cover_left_icon2: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon3: builtins.int = ...,
        cover_left_text3: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "badge", b"badge", "cover", b"cover", "cover_left_icon2", b"cover_left_icon2", "cover_left_icon3", b"cover_left_icon3", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_text2", b"cover_left_text2", "cover_left_text3", b"cover_left_text3", "cover_left_text_1", b"cover_left_text_1", "is_pgc", b"is_pgc", "title", b"title", "uri", b"uri"]) -> None: ...

global___RcmdArchive = RcmdArchive

@typing_extensions.final
class RcmdAuthor(google.protobuf.message.Message):
    """推荐UP主用户模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    @property
    def author(self) -> global___UserInfo:
        """用户详情"""
    desc: builtins.str
    """描述：粉丝数、推荐理由"""
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
    def __init__(
        self,
        *,
        author: global___UserInfo | None = ...,
        desc: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "desc", b"desc", "relation", b"relation"]) -> None: ...

global___RcmdAuthor = RcmdAuthor

@typing_extensions.final
class RcmdCampusBrief(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    CAMPUS_BADGE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    campus_badge: builtins.str
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        campus_badge: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_badge", b"campus_badge", "campus_id", b"campus_id", "campus_name", b"campus_name", "url", b"url"]) -> None: ...

global___RcmdCampusBrief = RcmdCampusBrief

@typing_extensions.final
class RcmdItem(google.protobuf.message.Message):
    """推荐卡片列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    RCMD_ARCHIVE_FIELD_NUMBER: builtins.int
    type: global___RcmdType.ValueType
    """卡片类型"""
    @property
    def rcmd_archive(self) -> global___RcmdArchive:
        """"""
    def __init__(
        self,
        *,
        type: global___RcmdType.ValueType = ...,
        rcmd_archive: global___RcmdArchive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rcmd_archive", b"rcmd_archive", "rcmd_item", b"rcmd_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["rcmd_archive", b"rcmd_archive", "rcmd_item", b"rcmd_item", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["rcmd_item", b"rcmd_item"]) -> typing_extensions.Literal["rcmd_archive"] | None: ...

global___RcmdItem = RcmdItem

@typing_extensions.final
class RcmdOption(google.protobuf.message.Message):
    """分区聚类推荐选项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_TITLE_FIELD_NUMBER: builtins.int
    show_title: builtins.bool
    """视频是否展示标题"""
    def __init__(
        self,
        *,
        show_title: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_title", b"show_title"]) -> None: ...

global___RcmdOption = RcmdOption

@typing_extensions.final
class RcmdReason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    campus_name: builtins.str
    """"""
    style: global___RcmdReasonStyle.ValueType
    """"""
    rcmd_reason: builtins.str
    """"""
    up_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_name: builtins.str = ...,
        style: global___RcmdReasonStyle.ValueType = ...,
        rcmd_reason: builtins.str = ...,
        up_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_name", b"campus_name", "rcmd_reason", b"rcmd_reason", "style", b"style", "up_name", b"up_name"]) -> None: ...

global___RcmdReason = RcmdReason

@typing_extensions.final
class RcmdTopButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "url", b"url"]) -> None: ...

global___RcmdTopButton = RcmdTopButton

@typing_extensions.final
class RcmdUPsParam(google.protobuf.message.Message):
    """推荐up主入参"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISLIKE_TS_FIELD_NUMBER: builtins.int
    dislike_ts: builtins.int
    def __init__(
        self,
        *,
        dislike_ts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_ts", b"dislike_ts"]) -> None: ...

global___RcmdUPsParam = RcmdUPsParam

@typing_extensions.final
class ReactionListItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    ACT_TEXT_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserInfo:
        """用户信息"""
    @property
    def relation(self) -> global___Relation:
        """关注关系"""
    act_text: builtins.str
    """显示文字"""
    rcmd_reason: builtins.str
    """"""
    def __init__(
        self,
        *,
        user: global___UserInfo | None = ...,
        relation: global___Relation | None = ...,
        act_text: builtins.str = ...,
        rcmd_reason: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_text", b"act_text", "rcmd_reason", b"rcmd_reason", "relation", b"relation", "user", b"user"]) -> None: ...

global___ReactionListItem = ReactionListItem

@typing_extensions.final
class ReactionListReply(google.protobuf.message.Message):
    """新版动态转发点赞列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReactionListItem]:
        """列表"""
    offset: builtins.str
    """偏移"""
    has_more: builtins.bool
    """是否还有更多"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___ReactionListItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset", "title", b"title"]) -> None: ...

global___ReactionListReply = ReactionListReply

@typing_extensions.final
class ReactionListReq(google.protobuf.message.Message):
    """新版动态转发点赞列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    dynamic_id: builtins.int
    """动态ID"""
    dyn_type: builtins.int
    """动态类型"""
    rid: builtins.int
    """业务方资源id"""
    offset: builtins.str
    """偏移,使用上一页回包中的offset字段；第一页不传。"""
    def __init__(
        self,
        *,
        dynamic_id: builtins.int = ...,
        dyn_type: builtins.int = ...,
        rid: builtins.int = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_type", b"dyn_type", "dynamic_id", b"dynamic_id", "offset", b"offset", "rid", b"rid"]) -> None: ...

global___ReactionListReq = ReactionListReq

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """关注关系"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    status: global___RelationStatus.ValueType
    """关注状态"""
    is_follow: builtins.int
    """关注"""
    is_followed: builtins.int
    """被关注"""
    title: builtins.str
    """文案"""
    def __init__(
        self,
        *,
        status: global___RelationStatus.ValueType = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "is_followed", b"is_followed", "status", b"status", "title", b"title"]) -> None: ...

global___Relation = Relation

@typing_extensions.final
class RepostListReq(google.protobuf.message.Message):
    """转发列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    REPOST_TYPE_FIELD_NUMBER: builtins.int
    dynamic_id: builtins.str
    """动态ID"""
    dyn_type: builtins.int
    """动态类型"""
    rid: builtins.int
    """业务方资源id"""
    offset: builtins.str
    """偏移,使用上一页回包中的offset字段；第一页不传。"""
    repost_type: global___RepostType.ValueType
    """评论类型"""
    def __init__(
        self,
        *,
        dynamic_id: builtins.str = ...,
        dyn_type: builtins.int = ...,
        rid: builtins.int = ...,
        offset: builtins.str = ...,
        repost_type: global___RepostType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_type", b"dyn_type", "dynamic_id", b"dynamic_id", "from", b"from", "offset", b"offset", "repost_type", b"repost_type", "rid", b"rid"]) -> None: ...

global___RepostListReq = RepostListReq

@typing_extensions.final
class RepostListRsp(google.protobuf.message.Message):
    """转发列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    REPOST_TYPE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """列表"""
    offset: builtins.str
    """偏移"""
    has_more: builtins.bool
    """是否还有更多"""
    total_count: builtins.int
    """转发总数"""
    repost_type: global___RepostType.ValueType
    """评论类型"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        total_count: builtins.int = ...,
        repost_type: global___RepostType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "offset", b"offset", "repost_type", b"repost_type", "total_count", b"total_count"]) -> None: ...

global___RepostListRsp = RepostListRsp

@typing_extensions.final
class SchoolRecommendReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusInfo]:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CampusInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___SchoolRecommendReply = SchoolRecommendReply

@typing_extensions.final
class SchoolRecommendReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    lat: builtins.float
    """"""
    lng: builtins.float
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_type", b"from_type", "lat", b"lat", "lng", b"lng"]) -> None: ...

global___SchoolRecommendReq = SchoolRecommendReq

@typing_extensions.final
class SchoolSearchReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CampusInfo]:
        """"""
    @property
    def toast(self) -> global___SearchToast:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CampusInfo] | None = ...,
        toast: global___SearchToast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["toast", b"toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "toast", b"toast"]) -> None: ...

global___SchoolSearchReply = SchoolSearchReply

@typing_extensions.final
class SchoolSearchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_type", b"from_type", "keyword", b"keyword"]) -> None: ...

global___SchoolSearchReq = SchoolSearchReq

@typing_extensions.final
class SearchChannel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    MORE_BUTTON_FIELD_NUMBER: builtins.int
    CHANNELS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def more_button(self) -> global___SearchTopicButton:
        """"""
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChannelInfo]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        more_button: global___SearchTopicButton | None = ...,
        channels: collections.abc.Iterable[global___ChannelInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["more_button", b"more_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels", b"channels", "more_button", b"more_button", "title", b"title"]) -> None: ...

global___SearchChannel = SearchChannel

@typing_extensions.final
class SearchInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """"""
    track_id: builtins.str
    """"""
    total: builtins.int
    """"""
    has_more: builtins.bool
    """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___DynamicItem] | None = ...,
        track_id: builtins.str = ...,
        total: builtins.int = ...,
        has_more: builtins.bool = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "list", b"list", "title", b"title", "total", b"total", "track_id", b"track_id", "version", b"version"]) -> None: ...

global___SearchInfo = SearchInfo

@typing_extensions.final
class SearchToast(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_TEXT1_FIELD_NUMBER: builtins.int
    DESC_TEXT2_FIELD_NUMBER: builtins.int
    desc_text1: builtins.str
    """"""
    desc_text2: builtins.str
    """"""
    def __init__(
        self,
        *,
        desc_text1: builtins.str = ...,
        desc_text2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc_text1", b"desc_text1", "desc_text2", b"desc_text2"]) -> None: ...

global___SearchToast = SearchToast

@typing_extensions.final
class SearchTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    MORE_BUTTON_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def more_button(self) -> global___SearchTopicButton:
        """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchTopicItem]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        more_button: global___SearchTopicButton | None = ...,
        items: collections.abc.Iterable[global___SearchTopicItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["more_button", b"more_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "more_button", b"more_button", "title", b"title"]) -> None: ...

global___SearchTopic = SearchTopic

@typing_extensions.final
class SearchTopicButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    jump_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        jump_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_uri", b"jump_uri", "title", b"title"]) -> None: ...

global___SearchTopicButton = SearchTopicButton

@typing_extensions.final
class SearchTopicItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    IS_ACTIVITY_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    topic_name: builtins.str
    """"""
    desc: builtins.str
    """"""
    url: builtins.str
    """"""
    is_activity: builtins.bool
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
        desc: builtins.str = ...,
        url: builtins.str = ...,
        is_activity: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "is_activity", b"is_activity", "topic_id", b"topic_id", "topic_name", b"topic_name", "url", b"url"]) -> None: ...

global___SearchTopicItem = SearchTopicItem

@typing_extensions.final
class SetDecisionReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    result: builtins.int
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        result: builtins.int = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_type", b"from_type", "result", b"result"]) -> None: ...

global___SetDecisionReq = SetDecisionReq

@typing_extensions.final
class SetRecentCampusReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "from_type", b"from_type"]) -> None: ...

global___SetRecentCampusReq = SetRecentCampusReq

@typing_extensions.final
class ShareChannel(google.protobuf.message.Message):
    """分享渠道组件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """分享名称"""
    image: builtins.str
    """分享按钮图片"""
    channel: builtins.str
    """分享渠道"""
    @property
    def reserve(self) -> global___ShareReserve:
        """预约卡分享图信息，仅分享有预约信息的动态时存在"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        image: builtins.str = ...,
        channel: builtins.str = ...,
        reserve: global___ShareReserve | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel", "image", b"image", "name", b"name", "reserve", b"reserve"]) -> None: ...

global___ShareChannel = ShareChannel

@typing_extensions.final
class ShareReserve(google.protobuf.message.Message):
    """预约卡分享图信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    QR_CODE_ICON_FIELD_NUMBER: builtins.int
    QR_CODE_TEXT_FIELD_NUMBER: builtins.int
    QR_CODE_URL_FIELD_NUMBER: builtins.int
    USER_INFO_FIELD_NUMBER: builtins.int
    title: builtins.str
    """展示标题"""
    desc: builtins.str
    """描述(时间+类型)"""
    qr_code_icon: builtins.str
    """二维码附带icon"""
    qr_code_text: builtins.str
    """二维码附带文本"""
    qr_code_url: builtins.str
    """二维码url"""
    @property
    def user_info(self) -> global___AdditionUserInfo:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        qr_code_icon: builtins.str = ...,
        qr_code_text: builtins.str = ...,
        qr_code_url: builtins.str = ...,
        user_info: global___AdditionUserInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_info", b"user_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "qr_code_icon", b"qr_code_icon", "qr_code_text", b"qr_code_text", "qr_code_url", b"qr_code_url", "title", b"title", "user_info", b"user_info"]) -> None: ...

global___ShareReserve = ShareReserve

@typing_extensions.final
class SortType(google.protobuf.message.Message):
    """排序类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_TYPE_FIELD_NUMBER: builtins.int
    SORT_TYPE_NAME_FIELD_NUMBER: builtins.int
    sort_type: builtins.int
    """排序策略
    1:推荐排序 2:最常访问 3:最近关注
    """
    sort_type_name: builtins.str
    """排序策略名称"""
    def __init__(
        self,
        *,
        sort_type: builtins.int = ...,
        sort_type_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_type", b"sort_type", "sort_type_name", b"sort_type_name"]) -> None: ...

global___SortType = SortType

@typing_extensions.final
class StoryArchive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    aid: builtins.int
    """"""
    uri: builtins.str
    """"""
    @property
    def dimension(self) -> global___Dimension:
        """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        aid: builtins.int = ...,
        uri: builtins.str = ...,
        dimension: global___Dimension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cover", b"cover", "dimension", b"dimension", "uri", b"uri"]) -> None: ...

global___StoryArchive = StoryArchive

@typing_extensions.final
class StoryItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STORY_ARCHIVE_FIELD_NUMBER: builtins.int
    @property
    def author(self) -> global___UserInfo:
        """"""
    desc: builtins.str
    """"""
    status: builtins.int
    """"""
    type: builtins.int
    """"""
    @property
    def story_archive(self) -> global___StoryArchive:
        """"""
    def __init__(
        self,
        *,
        author: global___UserInfo | None = ...,
        desc: builtins.str = ...,
        status: builtins.int = ...,
        type: builtins.int = ...,
        story_archive: global___StoryArchive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "rcmd_item", b"rcmd_item", "story_archive", b"story_archive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "desc", b"desc", "rcmd_item", b"rcmd_item", "status", b"status", "story_archive", b"story_archive", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["rcmd_item", b"rcmd_item"]) -> typing_extensions.Literal["story_archive"] | None: ...

global___StoryItem = StoryItem

@typing_extensions.final
class SubscribeCampusReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    CAMPUS_NAME_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    campus_name: builtins.str
    """"""
    from_type: global___CampusReqFromType.ValueType
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        campus_name: builtins.str = ...,
        from_type: global___CampusReqFromType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "campus_name", b"campus_name", "from_type", b"from_type"]) -> None: ...

global___SubscribeCampusReq = SubscribeCampusReq

@typing_extensions.final
class TextNode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TextNodeType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TextNodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TextNode._TextNodeType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: TextNode._TextNodeType.ValueType  # 0
        WORDS: TextNode._TextNodeType.ValueType  # 1
        EMOTE: TextNode._TextNodeType.ValueType  # 2
        AT: TextNode._TextNodeType.ValueType  # 3
        BIZ_LINK: TextNode._TextNodeType.ValueType  # 4

    class TextNodeType(_TextNodeType, metaclass=_TextNodeTypeEnumTypeWrapper): ...
    INVALID: TextNode.TextNodeType.ValueType  # 0
    WORDS: TextNode.TextNodeType.ValueType  # 1
    EMOTE: TextNode.TextNodeType.ValueType  # 2
    AT: TextNode.TextNodeType.ValueType  # 3
    BIZ_LINK: TextNode.TextNodeType.ValueType  # 4

    NODE_TYPE_FIELD_NUMBER: builtins.int
    RAW_TEXT_FIELD_NUMBER: builtins.int
    WORD_FIELD_NUMBER: builtins.int
    EMOTE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    node_type: global___TextNode.TextNodeType.ValueType
    """"""
    raw_text: builtins.str
    @property
    def word(self) -> global___WordNode: ...
    @property
    def emote(self) -> global___EmoteNode: ...
    @property
    def link(self) -> global___LinkNode: ...
    def __init__(
        self,
        *,
        node_type: global___TextNode.TextNodeType.ValueType = ...,
        raw_text: builtins.str = ...,
        word: global___WordNode | None = ...,
        emote: global___EmoteNode | None = ...,
        link: global___LinkNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["emote", b"emote", "link", b"link", "text", b"text", "word", b"word"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emote", b"emote", "link", b"link", "node_type", b"node_type", "raw_text", b"raw_text", "text", b"text", "word", b"word"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["text", b"text"]) -> typing_extensions.Literal["word", "emote", "link"] | None: ...

global___TextNode = TextNode

@typing_extensions.final
class TextParagraph(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODES_FIELD_NUMBER: builtins.int
    @property
    def nodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextNode]:
        """"""
    def __init__(
        self,
        *,
        nodes: collections.abc.Iterable[global___TextNode] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nodes", b"nodes"]) -> None: ...

global___TextParagraph = TextParagraph

@typing_extensions.final
class TextWithPriority(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    priority: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["priority", b"priority", "text", b"text"]) -> None: ...

global___TextWithPriority = TextWithPriority

@typing_extensions.final
class ThreePointAttention(google.protobuf.message.Message):
    """三点-关注"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTENTION_ICON_FIELD_NUMBER: builtins.int
    ATTENTION_TEXT_FIELD_NUMBER: builtins.int
    NOT_ATTENTION_ICON_FIELD_NUMBER: builtins.int
    NOT_ATTENTION_TEXT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    attention_icon: builtins.str
    """attention icon"""
    attention_text: builtins.str
    """关注时显示的文案"""
    not_attention_icon: builtins.str
    """not attention icon"""
    not_attention_text: builtins.str
    """未关注时显示的文案"""
    status: global___ThreePointAttentionStatus.ValueType
    """当前关注状态"""
    def __init__(
        self,
        *,
        attention_icon: builtins.str = ...,
        attention_text: builtins.str = ...,
        not_attention_icon: builtins.str = ...,
        not_attention_text: builtins.str = ...,
        status: global___ThreePointAttentionStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention_icon", b"attention_icon", "attention_text", b"attention_text", "not_attention_icon", b"not_attention_icon", "not_attention_text", b"not_attention_text", "status", b"status"]) -> None: ...

global___ThreePointAttention = ThreePointAttention

@typing_extensions.final
class ThreePointAutoPlay(google.protobuf.message.Message):
    """三点-自动播放 旧版不维护"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_ICON_FIELD_NUMBER: builtins.int
    OPEN_TEXT_FIELD_NUMBER: builtins.int
    CLOSE_ICON_FIELD_NUMBER: builtins.int
    CLOSE_TEXT_FIELD_NUMBER: builtins.int
    OPEN_TEXT_V2_FIELD_NUMBER: builtins.int
    CLOSE_TEXT_V2_FIELD_NUMBER: builtins.int
    ONLY_ICON_FIELD_NUMBER: builtins.int
    ONLY_TEXT_FIELD_NUMBER: builtins.int
    OPEN_ICON_V2_FIELD_NUMBER: builtins.int
    CLOSE_ICON_V2_FIELD_NUMBER: builtins.int
    open_icon: builtins.str
    """open icon"""
    open_text: builtins.str
    """开启时显示文案"""
    close_icon: builtins.str
    """close icon"""
    close_text: builtins.str
    """关闭时显示文案"""
    open_text_v2: builtins.str
    """开启时显示文案v2"""
    close_text_v2: builtins.str
    """关闭时显示文案v2"""
    only_icon: builtins.str
    """仅wifi/免流 icon"""
    only_text: builtins.str
    """仅wifi/免流 文案"""
    open_icon_v2: builtins.str
    """open icon v2"""
    close_icon_v2: builtins.str
    """close icon v2"""
    def __init__(
        self,
        *,
        open_icon: builtins.str = ...,
        open_text: builtins.str = ...,
        close_icon: builtins.str = ...,
        close_text: builtins.str = ...,
        open_text_v2: builtins.str = ...,
        close_text_v2: builtins.str = ...,
        only_icon: builtins.str = ...,
        only_text: builtins.str = ...,
        open_icon_v2: builtins.str = ...,
        close_icon_v2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["close_icon", b"close_icon", "close_icon_v2", b"close_icon_v2", "close_text", b"close_text", "close_text_v2", b"close_text_v2", "only_icon", b"only_icon", "only_text", b"only_text", "open_icon", b"open_icon", "open_icon_v2", b"open_icon_v2", "open_text", b"open_text", "open_text_v2", b"open_text_v2"]) -> None: ...

global___ThreePointAutoPlay = ThreePointAutoPlay

@typing_extensions.final
class ThreePointComment(google.protobuf.message.Message):
    """三点-评论"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_SELECTION_FIELD_NUMBER: builtins.int
    UP_CLOSE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def up_selection(self) -> global___CommentDetail:
        """精选评论区功能"""
    @property
    def up_close(self) -> global___CommentDetail:
        """up关闭评论区功能"""
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    def __init__(
        self,
        *,
        up_selection: global___CommentDetail | None = ...,
        up_close: global___CommentDetail | None = ...,
        icon: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["up_close", b"up_close", "up_selection", b"up_selection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "up_close", b"up_close", "up_selection", b"up_selection"]) -> None: ...

global___ThreePointComment = ThreePointComment

@typing_extensions.final
class ThreePointDefault(google.protobuf.message.Message):
    """三点-默认结构(使用此背景、举报、删除)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转链接"""
    id: builtins.str
    """id"""
    @property
    def toast(self) -> global___ThreePointDefaultToast:
        """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        id: builtins.str = ...,
        toast: global___ThreePointDefaultToast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["toast", b"toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "id", b"id", "title", b"title", "toast", b"toast", "uri", b"uri"]) -> None: ...

global___ThreePointDefault = ThreePointDefault

@typing_extensions.final
class ThreePointDefaultToast(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "title", b"title"]) -> None: ...

global___ThreePointDefaultToast = ThreePointDefaultToast

@typing_extensions.final
class ThreePointDislike(google.protobuf.message.Message):
    """三点-不感兴趣"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title"]) -> None: ...

global___ThreePointDislike = ThreePointDislike

@typing_extensions.final
class ThreePointFavorite(google.protobuf.message.Message):
    """三点-收藏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IS_FAVOURITE_FIELD_NUMBER: builtins.int
    CANCEL_ICON_FIELD_NUMBER: builtins.int
    CANCEL_TITLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    id: builtins.int
    """物料ID"""
    is_favourite: builtins.bool
    """是否订阅"""
    cancel_icon: builtins.str
    """取消收藏图标"""
    cancel_title: builtins.str
    """取消收藏文案"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        id: builtins.int = ...,
        is_favourite: builtins.bool = ...,
        cancel_icon: builtins.str = ...,
        cancel_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cancel_icon", b"cancel_icon", "cancel_title", b"cancel_title", "icon", b"icon", "id", b"id", "is_favourite", b"is_favourite", "title", b"title"]) -> None: ...

global___ThreePointFavorite = ThreePointFavorite

@typing_extensions.final
class ThreePointHide(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    INTERACTIVE_FIELD_NUMBER: builtins.int
    BLOOK_FID_FIELD_NUMBER: builtins.int
    BLOOK_TYPE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    title: builtins.str
    """"""
    @property
    def interactive(self) -> global___ThreePointHideInteractive:
        """"""
    blook_fid: builtins.int
    """"""
    blook_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        interactive: global___ThreePointHideInteractive | None = ...,
        blook_fid: builtins.int = ...,
        blook_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interactive", b"interactive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blook_fid", b"blook_fid", "blook_type", b"blook_type", "icon", b"icon", "interactive", b"interactive", "title", b"title"]) -> None: ...

global___ThreePointHide = ThreePointHide

@typing_extensions.final
class ThreePointHideInteractive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONFIRM_FIELD_NUMBER: builtins.int
    CANCEL_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    confirm: builtins.str
    """"""
    cancel: builtins.str
    """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        confirm: builtins.str = ...,
        cancel: builtins.str = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cancel", b"cancel", "confirm", b"confirm", "title", b"title", "toast", b"toast"]) -> None: ...

global___ThreePointHideInteractive = ThreePointHideInteractive

@typing_extensions.final
class ThreePointItem(google.protobuf.message.Message):
    """三点Item"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    AUTO_PLAYER_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    WAIT_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    TOP_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    HIDE_FIELD_NUMBER: builtins.int
    TOPIC_IRRELEVANT_FIELD_NUMBER: builtins.int
    type: global___ThreePointType.ValueType
    """类型"""
    @property
    def default(self) -> global___ThreePointDefault:
        """默认结构"""
    @property
    def auto_player(self) -> global___ThreePointAutoPlay:
        """自动播放"""
    @property
    def share(self) -> global___ThreePointShare:
        """分享"""
    @property
    def attention(self) -> global___ThreePointAttention:
        """关注"""
    @property
    def wait(self) -> global___ThreePointWait:
        """稍后在看"""
    @property
    def dislike(self) -> global___ThreePointDislike:
        """不感兴趣"""
    @property
    def favorite(self) -> global___ThreePointFavorite:
        """收藏"""
    @property
    def top(self) -> global___ThreePointTop:
        """置顶"""
    @property
    def comment(self) -> global___ThreePointComment:
        """评论"""
    @property
    def hide(self) -> global___ThreePointHide:
        """"""
    @property
    def topic_irrelevant(self) -> global___ThreePointTopicIrrelevant:
        """"""
    def __init__(
        self,
        *,
        type: global___ThreePointType.ValueType = ...,
        default: global___ThreePointDefault | None = ...,
        auto_player: global___ThreePointAutoPlay | None = ...,
        share: global___ThreePointShare | None = ...,
        attention: global___ThreePointAttention | None = ...,
        wait: global___ThreePointWait | None = ...,
        dislike: global___ThreePointDislike | None = ...,
        favorite: global___ThreePointFavorite | None = ...,
        top: global___ThreePointTop | None = ...,
        comment: global___ThreePointComment | None = ...,
        hide: global___ThreePointHide | None = ...,
        topic_irrelevant: global___ThreePointTopicIrrelevant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attention", b"attention", "auto_player", b"auto_player", "comment", b"comment", "default", b"default", "dislike", b"dislike", "favorite", b"favorite", "hide", b"hide", "item", b"item", "share", b"share", "top", b"top", "topic_irrelevant", b"topic_irrelevant", "wait", b"wait"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "auto_player", b"auto_player", "comment", b"comment", "default", b"default", "dislike", b"dislike", "favorite", b"favorite", "hide", b"hide", "item", b"item", "share", b"share", "top", b"top", "topic_irrelevant", b"topic_irrelevant", "type", b"type", "wait", b"wait"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["default", "auto_player", "share", "attention", "wait", "dislike", "favorite", "top", "comment", "hide", "topic_irrelevant"] | None: ...

global___ThreePointItem = ThreePointItem

@typing_extensions.final
class ThreePointShare(google.protobuf.message.Message):
    """三点-分享"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    @property
    def channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointShareChannel]:
        """分享渠道"""
    channel_name: builtins.str
    """分享渠道名"""
    @property
    def reserve(self) -> global___ShareReserve:
        """预约卡分享图信息，仅分享有预约信息的动态时存在"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        channel: collections.abc.Iterable[global___ThreePointShareChannel] | None = ...,
        channel_name: builtins.str = ...,
        reserve: global___ShareReserve | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel", "channel_name", b"channel_name", "icon", b"icon", "reserve", b"reserve", "title", b"title"]) -> None: ...

global___ThreePointShare = ThreePointShare

@typing_extensions.final
class ThreePointShareChannel(google.protobuf.message.Message):
    """三点-分享渠道"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """名称"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title"]) -> None: ...

global___ThreePointShareChannel = ThreePointShareChannel

@typing_extensions.final
class ThreePointTop(google.protobuf.message.Message):
    """三点-置顶"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon"""
    title: builtins.str
    """标题"""
    type: global___TopType.ValueType
    """状态"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        type: global___TopType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "type", b"type"]) -> None: ...

global___ThreePointTop = ThreePointTop

@typing_extensions.final
class ThreePointTopicIrrelevant(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    TOPIC_ID_FIELD_NUMBER: builtins.int
    RES_ID_FIELD_NUMBER: builtins.int
    RES_TYPE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    title: builtins.str
    """"""
    toast: builtins.str
    """"""
    topic_id: builtins.int
    """"""
    res_id: builtins.int
    """"""
    res_type: builtins.int
    """"""
    reason: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        toast: builtins.str = ...,
        topic_id: builtins.int = ...,
        res_id: builtins.int = ...,
        res_type: builtins.int = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "reason", b"reason", "res_id", b"res_id", "res_type", b"res_type", "title", b"title", "toast", b"toast", "topic_id", b"topic_id"]) -> None: ...

global___ThreePointTopicIrrelevant = ThreePointTopicIrrelevant

@typing_extensions.final
class ThreePointWait(google.protobuf.message.Message):
    """三点-稍后在看"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITION_ICON_FIELD_NUMBER: builtins.int
    ADDITION_TEXT_FIELD_NUMBER: builtins.int
    NO_ADDITION_ICON_FIELD_NUMBER: builtins.int
    NO_ADDITION_TEXT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    addition_icon: builtins.str
    """addition icon"""
    addition_text: builtins.str
    """已添加时的文案"""
    no_addition_icon: builtins.str
    """no addition icon"""
    no_addition_text: builtins.str
    """未添加时的文案"""
    id: builtins.int
    """avid"""
    def __init__(
        self,
        *,
        addition_icon: builtins.str = ...,
        addition_text: builtins.str = ...,
        no_addition_icon: builtins.str = ...,
        no_addition_text: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addition_icon", b"addition_icon", "addition_text", b"addition_text", "id", b"id", "no_addition_icon", b"no_addition_icon", "no_addition_text", b"no_addition_text"]) -> None: ...

global___ThreePointWait = ThreePointWait

@typing_extensions.final
class TopAdditionUP(google.protobuf.message.Message):
    """顶部预约卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_FIELD_NUMBER: builtins.int
    HAS_FOLD_FIELD_NUMBER: builtins.int
    @property
    def up(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionUP]:
        """预约卡"""
    has_fold: builtins.int
    """折叠数量，大于多少个进行折叠"""
    def __init__(
        self,
        *,
        up: collections.abc.Iterable[global___AdditionUP] | None = ...,
        has_fold: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_fold", b"has_fold", "up", b"up"]) -> None: ...

global___TopAdditionUP = TopAdditionUP

@typing_extensions.final
class TopicButton(google.protobuf.message.Message):
    """话题广场操作按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    RED_DOT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """按钮图标"""
    title: builtins.str
    """按钮文案"""
    jump_uri: builtins.str
    """跳转"""
    red_dot: builtins.bool
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        jump_uri: builtins.str = ...,
        red_dot: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "jump_uri", b"jump_uri", "red_dot", b"red_dot", "title", b"title"]) -> None: ...

global___TopicButton = TopicButton

@typing_extensions.final
class TopicItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    RCMD_DESC_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    topic_name: builtins.str
    """"""
    url: builtins.str
    """"""
    desc: builtins.str
    """"""
    desc2: builtins.str
    """"""
    rcmd_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
        url: builtins.str = ...,
        desc: builtins.str = ...,
        desc2: builtins.str = ...,
        rcmd_desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "desc2", b"desc2", "rcmd_desc", b"rcmd_desc", "topic_id", b"topic_id", "topic_name", b"topic_name", "url", b"url"]) -> None: ...

global___TopicItem = TopicItem

@typing_extensions.final
class TopicList(google.protobuf.message.Message):
    """综合页-话题广场"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TOPIC_LIST_ITEM_FIELD_NUMBER: builtins.int
    ACT_BUTTON_FIELD_NUMBER: builtins.int
    MORE_BUTTON_FIELD_NUMBER: builtins.int
    SERVER_INFO_FIELD_NUMBER: builtins.int
    title: builtins.str
    """模块标题"""
    @property
    def topic_list_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicListItem]:
        """话题列表"""
    @property
    def act_button(self) -> global___TopicButton:
        """发起活动"""
    @property
    def more_button(self) -> global___TopicButton:
        """查看更多"""
    server_info: builtins.str
    """透传服务端上报"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        topic_list_item: collections.abc.Iterable[global___TopicListItem] | None = ...,
        act_button: global___TopicButton | None = ...,
        more_button: global___TopicButton | None = ...,
        server_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["act_button", b"act_button", "more_button", b"more_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_button", b"act_button", "more_button", b"more_button", "server_info", b"server_info", "title", b"title", "topic_list_item", b"topic_list_item"]) -> None: ...

global___TopicList = TopicList

@typing_extensions.final
class TopicListItem(google.protobuf.message.Message):
    """综合页-话题广场-话题"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    ICON_TITLE_FIELD_NUMBER: builtins.int
    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    SERVER_INFO_FIELD_NUMBER: builtins.int
    HEAD_ICON_URL_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    TAIL_ICON_URL_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """前置图标"""
    icon_title: builtins.str
    """前置图标文案"""
    topic_id: builtins.int
    """话题id"""
    topic_name: builtins.str
    """话题名"""
    url: builtins.str
    """跳转链接"""
    pos: builtins.int
    """卡片位次"""
    server_info: builtins.str
    """透传服务端上报"""
    head_icon_url: builtins.str
    """"""
    up_mid: builtins.int
    """"""
    tail_icon_url: builtins.str
    """"""
    extension: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        icon_title: builtins.str = ...,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
        url: builtins.str = ...,
        pos: builtins.int = ...,
        server_info: builtins.str = ...,
        head_icon_url: builtins.str = ...,
        up_mid: builtins.int = ...,
        tail_icon_url: builtins.str = ...,
        extension: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extension", b"extension", "head_icon_url", b"head_icon_url", "icon", b"icon", "icon_title", b"icon_title", "pos", b"pos", "server_info", b"server_info", "tail_icon_url", b"tail_icon_url", "topic_id", b"topic_id", "topic_name", b"topic_name", "up_mid", b"up_mid", "url", b"url"]) -> None: ...

global___TopicListItem = TopicListItem

@typing_extensions.final
class TopicListReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicItem]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___TopicItem] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "items", b"items", "offset", b"offset"]) -> None: ...

global___TopicListReply = TopicListReply

@typing_extensions.final
class TopicListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id", "offset", b"offset"]) -> None: ...

global___TopicListReq = TopicListReq

@typing_extensions.final
class TopicMergedResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MERGE_TYPE_FIELD_NUMBER: builtins.int
    MERGED_RES_CNT_FIELD_NUMBER: builtins.int
    merge_type: builtins.int
    """"""
    merged_res_cnt: builtins.int
    """"""
    def __init__(
        self,
        *,
        merge_type: builtins.int = ...,
        merged_res_cnt: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["merge_type", b"merge_type", "merged_res_cnt", b"merged_res_cnt"]) -> None: ...

global___TopicMergedResource = TopicMergedResource

@typing_extensions.final
class TopicRcmdCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    DESC1_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    UPDATE_DESC_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    topic_name: builtins.str
    """"""
    url: builtins.str
    """"""
    @property
    def button(self) -> global___CampusLabel:
        """"""
    desc1: builtins.str
    """"""
    desc2: builtins.str
    """"""
    update_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
        url: builtins.str = ...,
        button: global___CampusLabel | None = ...,
        desc1: builtins.str = ...,
        desc2: builtins.str = ...,
        update_desc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "desc1", b"desc1", "desc2", b"desc2", "topic_id", b"topic_id", "topic_name", b"topic_name", "update_desc", b"update_desc", "url", b"url"]) -> None: ...

global___TopicRcmdCard = TopicRcmdCard

@typing_extensions.final
class TopicSquareInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    RCMD_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def button(self) -> global___CampusLabel:
        """"""
    @property
    def rcmd(self) -> global___TopicRcmdCard:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        button: global___CampusLabel | None = ...,
        rcmd: global___TopicRcmdCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "rcmd", b"rcmd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "rcmd", b"rcmd", "title", b"title"]) -> None: ...

global___TopicSquareInfo = TopicSquareInfo

@typing_extensions.final
class TopicSquareReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___TopicSquareInfo:
        """"""
    def __init__(
        self,
        *,
        info: global___TopicSquareInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info", b"info"]) -> None: ...

global___TopicSquareReply = TopicSquareReply

@typing_extensions.final
class TopicSquareReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAMPUS_ID_FIELD_NUMBER: builtins.int
    campus_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        campus_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["campus_id", b"campus_id"]) -> None: ...

global___TopicSquareReq = TopicSquareReq

@typing_extensions.final
class Unfollow(google.protobuf.message.Message):
    """综合页-无关注列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题展示文案"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UnfollowUserItem]:
        """无关注列表"""
    TrackId: builtins.str
    """trackID"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        list: collections.abc.Iterable[global___UnfollowUserItem] | None = ...,
        TrackId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["TrackId", b"TrackId", "list", b"list", "title", b"title"]) -> None: ...

global___Unfollow = Unfollow

@typing_extensions.final
class UnfollowMatchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid"]) -> None: ...

global___UnfollowMatchReq = UnfollowMatchReq

@typing_extensions.final
class UnfollowUserItem(google.protobuf.message.Message):
    """综合页-无关注列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_UPDATE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    has_update: builtins.bool
    """是否有更新"""
    face: builtins.str
    """up主头像"""
    name: builtins.str
    """up主昵称"""
    uid: builtins.int
    """up主uid"""
    pos: builtins.int
    """排序字段 从1开始"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    sign: builtins.str
    """up介绍"""
    label: builtins.str
    """标签信息"""
    @property
    def button(self) -> global___AdditionalButton:
        """按钮"""
    uri: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        has_update: builtins.bool = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        pos: builtins.int = ...,
        live_state: global___LiveState.ValueType = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        sign: builtins.str = ...,
        label: builtins.str = ...,
        button: global___AdditionalButton | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "official", b"official", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "face", b"face", "has_update", b"has_update", "label", b"label", "live_state", b"live_state", "name", b"name", "official", b"official", "pos", b"pos", "sign", b"sign", "uid", b"uid", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___UnfollowUserItem = UnfollowUserItem

@typing_extensions.final
class UpdateTabSettingReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: global___HomePageTabSttingStatus.ValueType
    """"""
    def __init__(
        self,
        *,
        status: global___HomePageTabSttingStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___UpdateTabSettingReq = UpdateTabSettingReq

@typing_extensions.final
class UpListItem(google.protobuf.message.Message):
    """动态顶部up列表-up主信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_UPDATE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    USER_ITEM_TYPE_FIELD_NUMBER: builtins.int
    DISPLAY_STYLE_DAY_FIELD_NUMBER: builtins.int
    DISPLAY_STYLE_NIGHT_FIELD_NUMBER: builtins.int
    STYLE_ID_FIELD_NUMBER: builtins.int
    LIVE_STATE_FIELD_NUMBER: builtins.int
    SEPARATOR_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    IS_RECALL_FIELD_NUMBER: builtins.int
    UPDATE_ICON_FIELD_NUMBER: builtins.int
    LIVE_RCMD_REASON_FIELD_NUMBER: builtins.int
    LIVE_COVER_FIELD_NUMBER: builtins.int
    PERSONAL_EXTRA_FIELD_NUMBER: builtins.int
    has_update: builtins.bool
    """是否有更新"""
    face: builtins.str
    """up主头像"""
    name: builtins.str
    """up主昵称"""
    uid: builtins.int
    """up主uid"""
    pos: builtins.int
    """排序字段 从1开始"""
    user_item_type: global___UserItemType.ValueType
    """用户类型"""
    @property
    def display_style_day(self) -> global___UserItemStyle:
        """直播头像样式-日"""
    @property
    def display_style_night(self) -> global___UserItemStyle:
        """直播头像样式-夜"""
    style_id: builtins.int
    """直播埋点"""
    live_state: global___LiveState.ValueType
    """直播状态"""
    separator: builtins.bool
    """分割线"""
    uri: builtins.str
    """跳转"""
    is_recall: builtins.bool
    """UP主预约上报使用"""
    @property
    def update_icon(self) -> global___IconBadge:
        """"""
    live_rcmd_reason: builtins.str
    """"""
    live_cover: builtins.str
    """"""
    personal_extra: builtins.str
    """"""
    def __init__(
        self,
        *,
        has_update: builtins.bool = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        pos: builtins.int = ...,
        user_item_type: global___UserItemType.ValueType = ...,
        display_style_day: global___UserItemStyle | None = ...,
        display_style_night: global___UserItemStyle | None = ...,
        style_id: builtins.int = ...,
        live_state: global___LiveState.ValueType = ...,
        separator: builtins.bool = ...,
        uri: builtins.str = ...,
        is_recall: builtins.bool = ...,
        update_icon: global___IconBadge | None = ...,
        live_rcmd_reason: builtins.str = ...,
        live_cover: builtins.str = ...,
        personal_extra: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display_style_day", b"display_style_day", "display_style_night", b"display_style_night", "update_icon", b"update_icon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_style_day", b"display_style_day", "display_style_night", b"display_style_night", "face", b"face", "has_update", b"has_update", "is_recall", b"is_recall", "live_cover", b"live_cover", "live_rcmd_reason", b"live_rcmd_reason", "live_state", b"live_state", "name", b"name", "personal_extra", b"personal_extra", "pos", b"pos", "separator", b"separator", "style_id", b"style_id", "uid", b"uid", "update_icon", b"update_icon", "uri", b"uri", "user_item_type", b"user_item_type"]) -> None: ...

global___UpListItem = UpListItem

@typing_extensions.final
class UpListMoreLabel(google.protobuf.message.Message):
    """最常访问-查看更多"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """文案"""
    uri: builtins.str
    """跳转地址"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "uri", b"uri"]) -> None: ...

global___UpListMoreLabel = UpListMoreLabel

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    """用户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    FACE_NFT_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    NFT_INFO_FIELD_NUMBER: builtins.int
    IS_SENIOR_MEMBER_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    name: builtins.str
    """用户昵称"""
    face: builtins.str
    """用户头像"""
    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
    @property
    def live(self) -> global___LiveInfo:
        """直播信息"""
    uri: builtins.str
    """空间页跳转链接"""
    @property
    def pendant(self) -> global___UserPendant:
        """挂件信息"""
    @property
    def nameplate(self) -> global___Nameplate:
        """认证名牌"""
    level: builtins.int
    """用户等级"""
    sign: builtins.str
    """用户简介"""
    face_nft: builtins.int
    """"""
    face_nft_new: builtins.int
    """"""
    @property
    def nft_info(self) -> global___NFTInfo:
        """"""
    is_senior_member: builtins.int
    """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.avatar_pb2.AvatarItem:
        """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        official: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        live: global___LiveInfo | None = ...,
        uri: builtins.str = ...,
        pendant: global___UserPendant | None = ...,
        nameplate: global___Nameplate | None = ...,
        level: builtins.int = ...,
        sign: builtins.str = ...,
        face_nft: builtins.int = ...,
        face_nft_new: builtins.int = ...,
        nft_info: global___NFTInfo | None = ...,
        is_senior_member: builtins.int = ...,
        avatar: bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.avatar_pb2.AvatarItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "live", b"live", "nameplate", b"nameplate", "nft_info", b"nft_info", "official", b"official", "pendant", b"pendant", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "face", b"face", "face_nft", b"face_nft", "face_nft_new", b"face_nft_new", "is_senior_member", b"is_senior_member", "level", b"level", "live", b"live", "mid", b"mid", "name", b"name", "nameplate", b"nameplate", "nft_info", b"nft_info", "official", b"official", "pendant", b"pendant", "sign", b"sign", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___UserInfo = UserInfo

@typing_extensions.final
class UserItemStyle(google.protobuf.message.Message):
    """直播头像样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECT_TEXT_FIELD_NUMBER: builtins.int
    RECT_TEXT_COLOR_FIELD_NUMBER: builtins.int
    RECT_ICON_FIELD_NUMBER: builtins.int
    RECT_BG_COLOR_FIELD_NUMBER: builtins.int
    OUTER_ANIMATION_FIELD_NUMBER: builtins.int
    rect_text: builtins.str
    """"""
    rect_text_color: builtins.str
    """"""
    rect_icon: builtins.str
    """"""
    rect_bg_color: builtins.str
    """"""
    outer_animation: builtins.str
    """"""
    def __init__(
        self,
        *,
        rect_text: builtins.str = ...,
        rect_text_color: builtins.str = ...,
        rect_icon: builtins.str = ...,
        rect_bg_color: builtins.str = ...,
        outer_animation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outer_animation", b"outer_animation", "rect_bg_color", b"rect_bg_color", "rect_icon", b"rect_icon", "rect_text", b"rect_text", "rect_text_color", b"rect_text_color"]) -> None: ...

global___UserItemStyle = UserItemStyle

@typing_extensions.final
class UserPendant(google.protobuf.message.Message):
    """头像挂件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """pid"""
    name: builtins.str
    """名称"""
    image: builtins.str
    """图片链接"""
    expire: builtins.int
    """有效期"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        name: builtins.str = ...,
        image: builtins.str = ...,
        expire: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire", b"expire", "image", b"image", "name", b"name", "pid", b"pid"]) -> None: ...

global___UserPendant = UserPendant

@typing_extensions.final
class VideoBadge(google.protobuf.message.Message):
    """角标信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    BG_ALPHA_FIELD_NUMBER: builtins.int
    BG_ALPHA_NIGHT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    text_color: builtins.str
    """文案颜色-日间"""
    text_color_night: builtins.str
    """文案颜色-夜间"""
    bg_color: builtins.str
    """背景颜色-日间"""
    bg_color_night: builtins.str
    """背景颜色-夜间"""
    border_color: builtins.str
    """边框颜色-日间"""
    border_color_night: builtins.str
    """边框颜色-夜间"""
    bg_style: builtins.int
    """样式"""
    bg_alpha: builtins.int
    """背景透明度-日间"""
    bg_alpha_night: builtins.int
    """背景透明度-夜间"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
        bg_alpha: builtins.int = ...,
        bg_alpha_night: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_alpha", b"bg_alpha", "bg_alpha_night", b"bg_alpha_night", "bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___VideoBadge = VideoBadge

@typing_extensions.final
class VipInfo(google.protobuf.message.Message):
    """大会员信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    Type: builtins.int
    """大会员类型"""
    status: builtins.int
    """大会员状态"""
    due_date: builtins.int
    """到期时间"""
    @property
    def label(self) -> global___VipLabel:
        """标签"""
    theme_type: builtins.int
    """主题"""
    avatar_subscript: builtins.int
    """大会员角标
    0:无角标 1:粉色大会员角标 2:绿色小会员角标
    """
    nickname_color: builtins.str
    """昵称色值，可能为空，色值示例：#FFFB9E60"""
    def __init__(
        self,
        *,
        Type: builtins.int = ...,
        status: builtins.int = ...,
        due_date: builtins.int = ...,
        label: global___VipLabel | None = ...,
        theme_type: builtins.int = ...,
        avatar_subscript: builtins.int = ...,
        nickname_color: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Type", b"Type", "avatar_subscript", b"avatar_subscript", "due_date", b"due_date", "label", b"label", "nickname_color", b"nickname_color", "status", b"status", "theme_type", b"theme_type"]) -> None: ...

global___VipInfo = VipInfo

@typing_extensions.final
class VipLabel(google.protobuf.message.Message):
    """大会员标签"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LABEL_THEME_FIELD_NUMBER: builtins.int
    path: builtins.str
    """图片地址"""
    text: builtins.str
    """文本值"""
    label_theme: builtins.str
    """对应颜色类型"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        text: builtins.str = ...,
        label_theme: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_theme", b"label_theme", "path", b"path", "text", b"text"]) -> None: ...

global___VipLabel = VipLabel

@typing_extensions.final
class Weight(google.protobuf.message.Message):
    """提权样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """提权展示标题"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WeightItem]:
        """下拉框内容"""
    icon: builtins.str
    """icon"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        items: collections.abc.Iterable[global___WeightItem] | None = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "items", b"items", "title", b"title"]) -> None: ...

global___Weight = Weight

@typing_extensions.final
class WeightButton(google.protobuf.message.Message):
    """热门默认跳转按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JUMP_URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    jump_url: builtins.str
    title: builtins.str
    """展示文案"""
    def __init__(
        self,
        *,
        jump_url: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url", "title", b"title"]) -> None: ...

global___WeightButton = WeightButton

@typing_extensions.final
class WeightDislike(google.protobuf.message.Message):
    """提权不感兴趣"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEED_BACK_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    feed_back_type: builtins.str
    """负反馈业务类型 作为客户端调用负反馈接口的参数"""
    title: builtins.str
    """展示文案"""
    def __init__(
        self,
        *,
        feed_back_type: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feed_back_type", b"feed_back_type", "title", b"title"]) -> None: ...

global___WeightDislike = WeightDislike

@typing_extensions.final
class WeightItem(google.protobuf.message.Message):
    """提权样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    type: global___WeightType.ValueType
    """类型"""
    @property
    def button(self) -> global___WeightButton:
        """热门默认跳转按钮"""
    @property
    def dislike(self) -> global___WeightDislike:
        """提权不感兴趣"""
    def __init__(
        self,
        *,
        type: global___WeightType.ValueType = ...,
        button: global___WeightButton | None = ...,
        dislike: global___WeightDislike | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "dislike", b"dislike", "item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "dislike", b"dislike", "item", b"item", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["button", "dislike"] | None: ...

global___WeightItem = WeightItem

@typing_extensions.final
class WordNode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class WordNodeStyle(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BOLD_FIELD_NUMBER: builtins.int
        ITALIC_FIELD_NUMBER: builtins.int
        STRIKETHROUGH_FIELD_NUMBER: builtins.int
        UNDERLINE_FIELD_NUMBER: builtins.int
        bold: builtins.bool
        """"""
        italic: builtins.bool
        """"""
        strikethrough: builtins.bool
        """"""
        underline: builtins.bool
        """"""
        def __init__(
            self,
            *,
            bold: builtins.bool = ...,
            italic: builtins.bool = ...,
            strikethrough: builtins.bool = ...,
            underline: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["bold", b"bold", "italic", b"italic", "strikethrough", b"strikethrough", "underline", b"underline"]) -> None: ...

    WORDS_FIELD_NUMBER: builtins.int
    FONT_SIZE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    words: builtins.str
    """"""
    font_size: builtins.float
    """"""
    @property
    def color(self) -> global___Colors:
        """"""
    @property
    def style(self) -> global___WordNode.WordNodeStyle:
        """"""
    def __init__(
        self,
        *,
        words: builtins.str = ...,
        font_size: builtins.float = ...,
        color: global___Colors | None = ...,
        style: global___WordNode.WordNodeStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color", "style", b"style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "font_size", b"font_size", "style", b"style", "words", b"words"]) -> None: ...

global___WordNode = WordNode
